/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __PROFILER_BPF_SKEL_H__
#define __PROFILER_BPF_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct profiler_bpf {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *events;
		struct bpf_map *fentry_readings;
		struct bpf_map *accum_readings;
		struct bpf_map *counts;
		struct bpf_map *rodata;
	} maps;
	struct {
		struct bpf_program *fentry_XXX;
		struct bpf_program *fexit_XXX;
	} progs;
	struct {
		struct bpf_link *fentry_XXX;
		struct bpf_link *fexit_XXX;
	} links;
	struct profiler_bpf__rodata {
		__u32 num_cpu;
		__u32 num_metric;
	} *rodata;

#ifdef __cplusplus
	static inline struct profiler_bpf *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct profiler_bpf *open_and_load();
	static inline int load(struct profiler_bpf *skel);
	static inline int attach(struct profiler_bpf *skel);
	static inline void detach(struct profiler_bpf *skel);
	static inline void destroy(struct profiler_bpf *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
profiler_bpf__destroy(struct profiler_bpf *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
profiler_bpf__create_skeleton(struct profiler_bpf *obj);

static inline struct profiler_bpf *
profiler_bpf__open_opts(const struct bpf_object_open_opts *opts)
{
	struct profiler_bpf *obj;
	int err;

	obj = (struct profiler_bpf *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = profiler_bpf__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	profiler_bpf__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct profiler_bpf *
profiler_bpf__open(void)
{
	return profiler_bpf__open_opts(NULL);
}

static inline int
profiler_bpf__load(struct profiler_bpf *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct profiler_bpf *
profiler_bpf__open_and_load(void)
{
	struct profiler_bpf *obj;
	int err;

	obj = profiler_bpf__open();
	if (!obj)
		return NULL;
	err = profiler_bpf__load(obj);
	if (err) {
		profiler_bpf__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
profiler_bpf__attach(struct profiler_bpf *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
profiler_bpf__detach(struct profiler_bpf *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *profiler_bpf__elf_bytes(size_t *sz);

static inline int
profiler_bpf__create_skeleton(struct profiler_bpf *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "profiler_bpf";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 5;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "events";
	s->maps[0].map = &obj->maps.events;

	s->maps[1].name = "fentry_readings";
	s->maps[1].map = &obj->maps.fentry_readings;

	s->maps[2].name = "accum_readings";
	s->maps[2].map = &obj->maps.accum_readings;

	s->maps[3].name = "counts";
	s->maps[3].map = &obj->maps.counts;

	s->maps[4].name = "profiler.rodata";
	s->maps[4].map = &obj->maps.rodata;
	s->maps[4].mmaped = (void **)&obj->rodata;

	/* programs */
	s->prog_cnt = 2;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "fentry_XXX";
	s->progs[0].prog = &obj->progs.fentry_XXX;
	s->progs[0].link = &obj->links.fentry_XXX;

	s->progs[1].name = "fexit_XXX";
	s->progs[1].prog = &obj->progs.fexit_XXX;
	s->progs[1].link = &obj->links.fexit_XXX;

	s->data = (void *)profiler_bpf__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *profiler_bpf__elf_bytes(size_t *sz)
{
	*sz = 9232;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\x10\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x10\0\
\x01\x85\0\0\0\0\0\0\x08\xbf\x60\0\0\0\0\0\0\x18\x70\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x61\x17\0\0\0\0\0\0\x15\x10\0\x10\0\0\0\0\xb7\x80\0\0\0\0\0\0\xbf\x9a\0\0\0\
\0\0\0\x07\x90\0\0\xff\xff\xff\xe0\x63\xa8\xff\xc8\0\0\0\0\xbf\x2a\0\0\0\0\0\0\
\x07\x20\0\0\xff\xff\xff\xc8\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\
\0\x01\x7b\x90\0\0\0\0\0\0\x15\0\0\x1e\0\0\0\0\x61\x17\0\0\0\0\0\0\x25\x80\0\
\x03\0\0\0\x02\x07\x90\0\0\0\0\0\x08\x07\x80\0\0\0\0\0\x01\x2d\x18\xff\xf3\0\0\
\0\0\x61\x17\0\0\0\0\0\0\x15\x10\0\x17\0\0\0\0\xb7\x70\0\0\0\0\0\0\xbf\x8a\0\0\
\0\0\0\0\x07\x80\0\0\xff\xff\xff\xe0\x18\x90\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x05\0\
\0\x13\0\0\0\0\x79\x18\0\0\0\0\0\0\x79\x2a\xff\xd8\0\0\0\0\x7b\x12\0\x10\0\0\0\
\0\x79\x2a\xff\xd0\0\0\0\0\x7b\x12\0\x08\0\0\0\0\x79\x2a\xff\xc8\0\0\0\0\x7b\
\x12\0\0\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x61\
\x29\0\0\0\0\0\0\x25\x70\0\x05\0\0\0\x02\x0f\x16\0\0\0\0\0\0\x07\x80\0\0\0\0\0\
\x08\x07\x70\0\0\0\0\0\x01\xbf\x61\0\0\0\0\0\0\x2d\x27\0\x02\0\0\0\0\xb7\0\0\0\
\0\0\0\0\x95\0\0\0\0\0\0\0\xbf\x26\0\0\0\0\0\0\x67\x20\0\0\0\0\0\x20\x77\x20\0\
\0\0\0\0\x20\xbf\x3a\0\0\0\0\0\0\x07\x30\0\0\xff\xff\xff\xc8\x18\x10\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\x18\x85\0\0\0\0\0\0\x37\x67\0\0\0\0\0\0\
\x20\x77\0\0\0\0\0\0\x20\x15\0\xff\xe1\0\0\0\0\x05\0\xff\xf1\0\0\0\0\x85\0\0\0\
\0\0\0\x08\xbf\x60\0\0\0\0\0\0\xb7\x80\0\0\0\0\0\0\x63\xa8\xff\x7c\0\0\0\0\x18\
\x90\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x19\0\0\0\0\0\0\x15\x10\0\x18\0\0\0\0\xbf\
\x7a\0\0\0\0\0\0\x07\x70\0\0\xff\xff\xff\x80\x05\0\0\x05\0\0\0\0\x61\x19\0\0\0\
\0\0\0\x25\x80\0\x13\0\0\0\x02\x07\x70\0\0\0\0\0\x18\x07\x80\0\0\0\0\0\x01\x3d\
\x81\0\x10\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x21\0\0\0\0\0\0\x2f\
\x28\0\0\0\0\0\0\x0f\x26\0\0\0\0\0\0\x67\x20\0\0\0\0\0\x20\x77\x20\0\0\0\0\0\
\x20\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x37\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\
\x18\x85\0\0\0\0\0\0\x37\x67\0\0\0\0\0\0\x20\x77\0\0\0\0\0\0\x20\x15\0\xff\xec\
\0\0\0\0\x05\0\0\x16\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\x7c\
\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x01\x15\0\0\x10\0\0\0\0\
\x79\x10\0\0\0\0\0\0\x07\x10\0\0\0\0\0\x01\x7b\x01\0\0\0\0\0\0\x18\x60\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x61\x16\0\0\0\0\0\0\x15\x10\0\x09\0\0\0\0\xb7\x70\0\0\0\0\
\0\0\xbf\x8a\0\0\0\0\0\0\x07\x80\0\0\xff\xff\xff\x80\x05\0\0\x07\0\0\0\0\x61\
\x16\0\0\0\0\0\0\x25\x70\0\x03\0\0\0\x02\x07\x80\0\0\0\0\0\x18\x07\x70\0\0\0\0\
\0\x01\x2d\x17\0\x02\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x63\xa7\xff\
\xfc\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xfc\x18\x10\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x01\x15\0\xff\xf2\0\0\0\0\x79\x10\0\0\0\0\0\
\0\x15\x10\xff\xf0\0\0\0\0\x79\x18\0\0\0\0\0\0\x79\x20\0\0\0\0\0\0\x1f\x12\0\0\
\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xe0\x7b\x21\0\0\0\0\0\0\
\x79\x10\0\x08\0\0\0\0\x79\x38\0\x08\0\0\0\0\x1f\x31\0\0\0\0\0\0\x7b\x23\0\x08\
\0\0\0\0\x79\x10\0\x10\0\0\0\0\x79\x38\0\x10\0\0\0\0\x1f\x31\0\0\0\0\0\0\x7b\
\x23\0\x10\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xfc\x18\x10\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x01\x15\0\xff\xdc\0\0\0\0\xbf\x1a\0\0\
\0\0\0\0\x07\x10\0\0\xff\xff\xff\xe0\x79\x21\0\0\0\0\0\0\x79\x30\0\0\0\0\0\0\
\x0f\x32\0\0\0\0\0\0\x7b\x03\0\0\0\0\0\0\x79\x21\0\x08\0\0\0\0\x79\x30\0\x08\0\
\0\0\0\x0f\x32\0\0\0\0\0\0\x7b\x03\0\x08\0\0\0\0\x79\x11\0\x10\0\0\0\0\x79\x20\
\0\x10\0\0\0\0\x0f\x21\0\0\0\0\0\0\x7b\x02\0\x10\0\0\0\0\x05\0\xff\xcd\0\0\0\0\
\0\0\0\x01\0\0\0\x01\x44\x75\x61\x6c\x20\x42\x53\x44\x2f\x47\x50\x4c\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xeb\x9f\x01\0\0\0\0\x18\0\0\0\0\0\0\x03\x4c\
\0\0\x03\x4c\0\0\x05\x7f\0\0\0\0\x02\0\0\0\0\0\0\x03\0\0\0\x01\x01\0\0\0\0\0\0\
\x04\x01\0\0\x20\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x04\0\0\0\
\x05\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\x04\0\0\x03\0\0\0\x18\0\0\0\x19\0\0\
\0\x01\0\0\0\0\0\0\0\x1e\0\0\0\x01\0\0\0\x40\0\0\0\x27\0\0\0\x01\0\0\0\x80\0\0\
\0\x32\x0e\0\0\0\0\0\0\x05\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x08\0\0\0\0\x03\0\
\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x06\0\0\0\0\x02\0\0\0\0\0\0\x0a\0\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x18\0\0\0\0\x04\0\0\x03\0\0\0\x18\
\0\0\0\x19\0\0\0\x07\0\0\0\0\0\0\0\x1e\0\0\0\x01\0\0\0\x40\0\0\0\x27\0\0\0\x09\
\0\0\0\x80\0\0\0\x39\x0e\0\0\0\0\0\0\x0b\0\0\0\x01\0\0\0\0\x04\0\0\x03\0\0\0\
\x18\0\0\0\x19\0\0\0\x07\0\0\0\0\0\0\0\x1e\0\0\0\x01\0\0\0\x40\0\0\0\x27\0\0\0\
\x09\0\0\0\x80\0\0\0\x49\x0e\0\0\0\0\0\0\x0d\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\
\x10\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x08\0\0\0\0\x04\0\0\
\x03\0\0\0\x18\0\0\0\x19\0\0\0\x07\0\0\0\0\0\0\0\x1e\0\0\0\x01\0\0\0\x40\0\0\0\
\x27\0\0\0\x0f\0\0\0\x80\0\0\0\x58\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\0\x02\0\
\0\0\0\0\0\x14\0\0\0\x5f\x01\0\0\0\0\0\0\x08\0\0\0\x40\0\0\0\0\x0d\0\0\x01\0\0\
\0\x02\0\0\0\x72\0\0\0\x13\0\0\0\x76\x0c\0\0\x01\0\0\0\x15\0\0\0\0\x0d\0\0\x01\
\0\0\0\x02\0\0\0\x72\0\0\0\x13\0\0\x02\x31\x0c\0\0\x01\0\0\0\x17\0\0\x03\xb1\
\x04\0\0\x03\0\0\0\x18\0\0\x03\xc6\0\0\0\x1a\0\0\0\0\0\0\x03\xce\0\0\0\x1a\0\0\
\0\x40\0\0\x03\xd6\0\0\0\x1a\0\0\0\x80\0\0\x03\xde\x08\0\0\0\0\0\0\x14\0\0\0\0\
\x0a\0\0\0\0\0\0\x1c\0\0\0\0\x09\0\0\0\0\0\0\x1d\0\0\x05\x36\x08\0\0\0\0\0\0\
\x1e\0\0\x05\x3c\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\x05\x49\x0e\0\0\0\0\0\0\x1b\
\0\0\0\x01\0\0\x05\x51\x0e\0\0\0\0\0\0\x1b\0\0\0\x01\0\0\x05\x5c\x01\0\0\0\0\0\
\0\x01\x01\0\0\x08\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x21\0\0\0\x04\0\0\0\x0d\0\0\
\x05\x61\x0e\0\0\0\0\0\0\x22\0\0\0\x01\0\0\x05\x69\x0f\0\0\x04\0\0\0\0\0\0\0\
\x06\0\0\0\0\0\0\0\x18\0\0\0\x0c\0\0\0\0\0\0\0\x18\0\0\0\x0e\0\0\0\0\0\0\0\x18\
\0\0\0\x12\0\0\0\0\0\0\0\x18\0\0\x05\x6f\x0f\0\0\x02\0\0\0\0\0\0\0\x1f\0\0\0\0\
\0\0\0\x04\0\0\0\x20\0\0\0\0\0\0\0\x04\0\0\x05\x77\x0f\0\0\x01\0\0\0\0\0\0\0\
\x23\0\0\0\0\0\0\0\x0d\0\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\
\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x74\x79\x70\x65\0\x6b\x65\x79\x5f\x73\
\x69\x7a\x65\0\x76\x61\x6c\x75\x65\x5f\x73\x69\x7a\x65\0\x65\x76\x65\x6e\x74\
\x73\0\x66\x65\x6e\x74\x72\x79\x5f\x72\x65\x61\x64\x69\x6e\x67\x73\0\x61\x63\
\x63\x75\x6d\x5f\x72\x65\x61\x64\x69\x6e\x67\x73\0\x63\x6f\x75\x6e\x74\x73\0\
\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x63\
\x74\x78\0\x66\x65\x6e\x74\x72\x79\x5f\x58\x58\x58\0\x66\x65\x6e\x74\x72\x79\
\x2f\x58\x58\x58\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\
\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\
\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\
\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\
\x6f\x6f\x6c\x73\x2f\x62\x70\x66\x2f\x62\x70\x66\x74\x6f\x6f\x6c\x2f\x73\x6b\
\x65\x6c\x65\x74\x6f\x6e\x2f\x70\x72\x6f\x66\x69\x6c\x65\x72\x2e\x62\x70\x66\
\x2e\x63\0\x09\x75\x33\x32\x20\x6b\x65\x79\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\
\x74\x5f\x73\x6d\x70\x5f\x70\x72\x6f\x63\x65\x73\x73\x6f\x72\x5f\x69\x64\x28\
\x29\x3b\0\x09\x66\x6f\x72\x20\x28\x69\x20\x3d\x20\x30\x3b\x20\x69\x20\x3c\x20\
\x6e\x75\x6d\x5f\x6d\x65\x74\x72\x69\x63\x20\x26\x26\x20\x69\x20\x3c\x20\x4d\
\x41\x58\x5f\x4e\x55\x4d\x5f\x4d\x41\x54\x52\x49\x43\x53\x3b\x20\x69\x2b\x2b\
\x29\x20\x7b\0\x09\x09\x75\x33\x32\x20\x66\x6c\x61\x67\x20\x3d\x20\x69\x3b\0\
\x09\x09\x70\x74\x72\x73\x5b\x69\x5d\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\
\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x66\x65\x6e\x74\x72\
\x79\x5f\x72\x65\x61\x64\x69\x6e\x67\x73\x2c\x20\x26\x66\x6c\x61\x67\x29\x3b\0\
\x09\x09\x2a\x28\x70\x74\x72\x73\x5b\x69\x5d\x29\x20\x3d\x20\x72\x65\x61\x64\
\x69\x6e\x67\x3b\0\x09\x09\x6b\x65\x79\x20\x2b\x3d\x20\x6e\x75\x6d\x5f\x63\x70\
\x75\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x66\x65\x6e\x74\
\x72\x79\x5f\x58\x58\x58\x29\0\x09\x09\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\
\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\x5f\x72\x65\x61\x64\x5f\x76\x61\x6c\
\x75\x65\x28\x26\x65\x76\x65\x6e\x74\x73\x2c\x20\x6b\x65\x79\x2c\x20\x26\x72\
\x65\x61\x64\x69\x6e\x67\x2c\0\x09\x09\x69\x66\x20\x28\x65\x72\x72\x29\0\x66\
\x65\x78\x69\x74\x5f\x58\x58\x58\0\x66\x65\x78\x69\x74\x2f\x58\x58\x58\0\x09\
\x75\x33\x32\x20\x63\x70\x75\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\x74\x5f\x73\
\x6d\x70\x5f\x70\x72\x6f\x63\x65\x73\x73\x6f\x72\x5f\x69\x64\x28\x29\x3b\0\x09\
\x75\x33\x32\x20\x69\x2c\x20\x7a\x65\x72\x6f\x20\x3d\x20\x30\x3b\0\x09\x09\x65\
\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\
\x5f\x72\x65\x61\x64\x5f\x76\x61\x6c\x75\x65\x28\x26\x65\x76\x65\x6e\x74\x73\
\x2c\x20\x63\x70\x75\x20\x2b\x20\x69\x20\x2a\x20\x6e\x75\x6d\x5f\x63\x70\x75\
\x2c\0\x09\x63\x6f\x75\x6e\x74\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\
\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x63\x6f\x75\x6e\x74\x73\x2c\
\x20\x26\x7a\x65\x72\x6f\x29\x3b\0\x09\x69\x66\x20\x28\x63\x6f\x75\x6e\x74\x29\
\x20\x7b\0\x09\x09\x2a\x63\x6f\x75\x6e\x74\x20\x2b\x3d\x20\x31\x3b\0\x09\x09\
\x66\x6f\x72\x20\x28\x69\x20\x3d\x20\x30\x3b\x20\x69\x20\x3c\x20\x6e\x75\x6d\
\x5f\x6d\x65\x74\x72\x69\x63\x20\x26\x26\x20\x69\x20\x3c\x20\x4d\x41\x58\x5f\
\x4e\x55\x4d\x5f\x4d\x41\x54\x52\x49\x43\x53\x3b\x20\x69\x2b\x2b\x29\0\x69\x6e\
\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x66\x65\x78\x69\x74\x5f\x58\x58\
\x58\x29\0\x09\x62\x65\x66\x6f\x72\x65\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\
\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x66\x65\x6e\x74\x72\
\x79\x5f\x72\x65\x61\x64\x69\x6e\x67\x73\x2c\x20\x26\x69\x64\x29\x3b\0\x09\x69\
\x66\x20\x28\x62\x65\x66\x6f\x72\x65\x20\x26\x26\x20\x62\x65\x66\x6f\x72\x65\
\x2d\x3e\x63\x6f\x75\x6e\x74\x65\x72\x29\x20\x7b\0\x62\x70\x66\x5f\x70\x65\x72\
\x66\x5f\x65\x76\x65\x6e\x74\x5f\x76\x61\x6c\x75\x65\0\x63\x6f\x75\x6e\x74\x65\
\x72\0\x65\x6e\x61\x62\x6c\x65\x64\0\x72\x75\x6e\x6e\x69\x6e\x67\0\x5f\x5f\x75\
\x36\x34\0\x30\x3a\x30\0\x09\x09\x64\x69\x66\x66\x2e\x63\x6f\x75\x6e\x74\x65\
\x72\x20\x3d\x20\x61\x66\x74\x65\x72\x2d\x3e\x63\x6f\x75\x6e\x74\x65\x72\x20\
\x2d\x20\x62\x65\x66\x6f\x72\x65\x2d\x3e\x63\x6f\x75\x6e\x74\x65\x72\x3b\0\x30\
\x3a\x31\0\x09\x09\x64\x69\x66\x66\x2e\x65\x6e\x61\x62\x6c\x65\x64\x20\x3d\x20\
\x61\x66\x74\x65\x72\x2d\x3e\x65\x6e\x61\x62\x6c\x65\x64\x20\x2d\x20\x62\x65\
\x66\x6f\x72\x65\x2d\x3e\x65\x6e\x61\x62\x6c\x65\x64\x3b\0\x30\x3a\x32\0\x09\
\x09\x64\x69\x66\x66\x2e\x72\x75\x6e\x6e\x69\x6e\x67\x20\x3d\x20\x61\x66\x74\
\x65\x72\x2d\x3e\x72\x75\x6e\x6e\x69\x6e\x67\x20\x2d\x20\x62\x65\x66\x6f\x72\
\x65\x2d\x3e\x72\x75\x6e\x6e\x69\x6e\x67\x3b\0\x09\x09\x61\x63\x63\x75\x6d\x20\
\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\
\x65\x6d\x28\x26\x61\x63\x63\x75\x6d\x5f\x72\x65\x61\x64\x69\x6e\x67\x73\x2c\
\x20\x26\x69\x64\x29\x3b\0\x09\x09\x69\x66\x20\x28\x61\x63\x63\x75\x6d\x29\x20\
\x7b\0\x09\x09\x09\x61\x63\x63\x75\x6d\x2d\x3e\x63\x6f\x75\x6e\x74\x65\x72\x20\
\x2b\x3d\x20\x64\x69\x66\x66\x2e\x63\x6f\x75\x6e\x74\x65\x72\x3b\0\x09\x09\x09\
\x61\x63\x63\x75\x6d\x2d\x3e\x65\x6e\x61\x62\x6c\x65\x64\x20\x2b\x3d\x20\x64\
\x69\x66\x66\x2e\x65\x6e\x61\x62\x6c\x65\x64\x3b\0\x09\x09\x09\x61\x63\x63\x75\
\x6d\x2d\x3e\x72\x75\x6e\x6e\x69\x6e\x67\x20\x2b\x3d\x20\x64\x69\x66\x66\x2e\
\x72\x75\x6e\x6e\x69\x6e\x67\x3b\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\
\x6e\x65\x64\x20\x69\x6e\x74\0\x6e\x75\x6d\x5f\x63\x70\x75\0\x6e\x75\x6d\x5f\
\x6d\x65\x74\x72\x69\x63\0\x63\x68\x61\x72\0\x4c\x49\x43\x45\x4e\x53\x45\0\x2e\
\x6d\x61\x70\x73\0\x2e\x72\x6f\x64\x61\x74\x61\0\x6c\x69\x63\x65\x6e\x73\x65\0\
\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x24\0\0\0\x24\0\0\x05\x14\0\0\x05\x38\
\0\0\x01\x3c\0\0\0\x08\0\0\0\x81\0\0\0\x01\0\0\0\0\0\0\0\x16\0\0\x02\x3b\0\0\0\
\x01\0\0\0\0\0\0\0\x18\0\0\0\x10\0\0\0\x81\0\0\0\x1b\0\0\0\0\0\0\0\x8c\0\0\0\
\xfd\0\0\xac\x0c\0\0\0\x10\0\0\0\x8c\0\0\x01\x24\0\0\xbc\x12\0\0\0\x28\0\0\0\
\x8c\0\0\x01\x24\0\0\xbc\x02\0\0\0\x48\0\0\0\x8c\0\0\x01\x5f\0\0\xc0\x07\0\0\0\
\x58\0\0\0\x8c\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\x8c\0\0\x01\x6f\0\0\xc8\x0d\0\0\
\0\x78\0\0\0\x8c\0\0\x01\x6f\0\0\xc8\x0b\0\0\0\x88\0\0\0\x8c\0\0\x01\x24\0\0\
\xbc\x12\0\0\0\x90\0\0\0\x8c\0\0\x01\x24\0\0\xbc\x02\0\0\0\x98\0\0\0\x8c\0\0\0\
\0\0\0\0\0\0\0\0\xa8\0\0\0\x8c\0\0\x01\x24\0\0\xbc\x02\0\0\0\xb0\0\0\0\x8c\0\0\
\x01\x24\0\0\xdc\x12\0\0\0\xb8\0\0\0\x8c\0\0\x01\x24\0\0\xdc\x02\0\0\0\xd0\0\0\
\0\x8c\0\0\0\0\0\0\0\0\0\0\0\xf0\0\0\0\x8c\0\0\x01\xa9\0\0\xfc\x05\0\0\0\xf8\0\
\0\0\x8c\0\0\x01\xa9\0\0\xfc\x10\0\0\x01\x28\0\0\0\x8c\0\0\x01\xc1\0\x01\0\x0a\
\0\0\x01\x40\0\0\0\x8c\0\0\x01\x24\0\0\xdc\x12\0\0\x01\x48\0\0\0\x8c\0\0\x01\
\x24\0\0\xdc\x02\0\0\x01\x50\0\0\0\x8c\0\0\0\0\0\0\0\0\0\0\x01\x70\0\0\0\x8c\0\
\0\x01\x24\0\0\xdc\x02\0\0\x01\x78\0\0\0\x8c\0\0\x01\xd3\0\0\xa0\x05\0\0\x01\
\x88\0\0\0\x8c\0\0\x01\xec\0\0\xec\x2c\0\0\x01\xa8\0\0\0\x8c\0\0\0\0\0\0\0\0\0\
\0\x01\xb0\0\0\0\x8c\0\0\x01\xec\0\0\xec\x09\0\0\x01\xd0\0\0\0\x8c\0\0\x02\x26\
\0\0\xf4\x07\0\0\x01\xe0\0\0\0\x8c\0\0\x02\x26\0\0\xf4\x07\0\0\x02\x3b\0\0\0\
\x35\0\0\0\0\0\0\0\x8c\0\0\x02\x45\0\x01\x84\x0c\0\0\0\x18\0\0\0\x8c\0\0\x02\
\x6c\0\x01\x88\x09\0\0\0\x20\0\0\0\x8c\0\0\x01\x24\0\x01\x9c\x12\0\0\0\x38\0\0\
\0\x8c\0\0\x01\x24\0\x01\x9c\x02\0\0\0\x58\0\0\0\x8c\0\0\x01\x24\0\x01\x9c\x12\
\0\0\0\x60\0\0\0\x8c\0\0\x01\x24\0\x01\x9c\x02\0\0\0\x68\0\0\0\x8c\0\0\0\0\0\0\
\0\0\0\0\0\x78\0\0\0\x8c\0\0\x01\x24\0\x01\x9c\x02\0\0\0\x80\0\0\0\x8c\0\0\x02\
\x7e\0\x01\xa0\x36\0\0\0\x98\0\0\0\x8c\0\0\x02\x7e\0\x01\xa0\x34\0\0\0\xa0\0\0\
\0\x8c\0\0\x02\x7e\0\x01\xa0\x30\0\0\0\xa8\0\0\0\x8c\0\0\x02\x7e\0\x01\xa0\x2c\
\0\0\0\xb8\0\0\0\x8c\0\0\x02\x7e\0\x01\xa0\x09\0\0\0\xe0\0\0\0\x8c\0\0\x02\x26\
\0\x01\xa8\x07\0\0\0\xf0\0\0\0\x8c\0\0\x02\x26\0\x01\xa8\x07\0\0\x01\x08\0\0\0\
\x8c\0\0\0\0\0\0\0\0\0\0\x01\x10\0\0\0\x8c\0\0\x02\xbc\0\x01\xb4\x0a\0\0\x01\
\x28\0\0\0\x8c\0\0\x02\xea\0\x01\xb8\x06\0\0\x01\x30\0\0\0\x8c\0\0\x02\xf8\0\
\x01\xbc\x0a\0\0\x01\x48\0\0\0\x8c\0\0\x03\x07\0\x01\xc0\x13\0\0\x01\x60\0\0\0\
\x8c\0\0\x03\x07\0\x01\xc0\x03\0\0\x01\x88\0\0\0\x8c\0\0\x03\x07\0\x01\xc0\x13\
\0\0\x01\x90\0\0\0\x8c\0\0\x03\x07\0\x01\xc0\x03\0\0\x01\x98\0\0\0\x8c\0\0\0\0\
\0\0\0\0\0\0\x01\xa8\0\0\0\x8c\0\0\x03\x07\0\x01\xc0\x03\0\0\x01\xb0\0\0\0\x8c\
\0\0\x03\x41\0\x01\x78\x05\0\0\x01\xd0\0\0\0\x8c\0\0\0\0\0\0\0\0\0\0\x01\xd8\0\
\0\0\x8c\0\0\x03\x59\0\x01\x2c\x0b\0\0\x01\xf0\0\0\0\x8c\0\0\x03\x8f\0\x01\x34\
\x0d\0\0\x01\xf8\0\0\0\x8c\0\0\x03\x8f\0\x01\x34\x18\0\0\x02\0\0\0\0\x8c\0\0\
\x03\x8f\0\x01\x34\x06\0\0\x02\x08\0\0\0\x8c\0\0\x03\xe8\0\x01\x40\x19\0\0\x02\
\x10\0\0\0\x8c\0\0\x03\xe8\0\x01\x40\x2b\0\0\x02\x18\0\0\0\x8c\0\0\x03\xe8\0\
\x01\x40\x21\0\0\x02\x28\0\0\0\x8c\0\0\x03\xe8\0\x01\x40\x19\0\0\x02\x30\0\0\0\
\x8c\0\0\x03\xe8\0\x01\x40\x10\0\0\x02\x38\0\0\0\x8c\0\0\x04\x1f\0\x01\x44\x2b\
\0\0\x02\x40\0\0\0\x8c\0\0\x04\x1f\0\x01\x44\x19\0\0\x02\x48\0\0\0\x8c\0\0\x04\
\x1f\0\x01\x44\x21\0\0\x02\x50\0\0\0\x8c\0\0\x04\x1f\0\x01\x44\x10\0\0\x02\x58\
\0\0\0\x8c\0\0\x04\x56\0\x01\x48\x2b\0\0\x02\x60\0\0\0\x8c\0\0\x04\x56\0\x01\
\x48\x19\0\0\x02\x68\0\0\0\x8c\0\0\x04\x56\0\x01\x48\x21\0\0\x02\x70\0\0\0\x8c\
\0\0\x04\x56\0\x01\x48\x10\0\0\x02\x80\0\0\0\x8c\0\0\x03\xe8\0\x01\x40\x19\0\0\
\x02\x88\0\0\0\x8c\0\0\x04\x89\0\x01\x50\x0b\0\0\x02\xa0\0\0\0\x8c\0\0\x04\xbe\
\0\x01\x54\x07\0\0\x02\xb0\0\0\0\x8c\0\0\x04\xcd\0\x01\x58\x1b\0\0\x02\xc0\0\0\
\0\x8c\0\0\x04\xcd\0\x01\x58\x13\0\0\x02\xd8\0\0\0\x8c\0\0\x04\xf0\0\x01\x5c\
\x1b\0\0\x02\xe0\0\0\0\x8c\0\0\x04\xf0\0\x01\x5c\x13\0\0\x02\xf8\0\0\0\x8c\0\0\
\x05\x13\0\x01\x60\x1b\0\0\x03\0\0\0\0\x8c\0\0\x05\x13\0\x01\x60\x13\0\0\0\x10\
\0\0\x02\x3b\0\0\0\x13\0\0\x01\xf8\0\0\0\x19\0\0\x03\xe4\0\0\0\0\0\0\x02\x08\0\
\0\0\x19\0\0\x03\xe4\0\0\0\0\0\0\x02\x10\0\0\0\x19\0\0\x03\xe4\0\0\0\0\0\0\x02\
\x30\0\0\0\x19\0\0\x03\xe4\0\0\0\0\0\0\x02\x38\0\0\0\x19\0\0\x04\x1b\0\0\0\0\0\
\0\x02\x40\0\0\0\x19\0\0\x04\x1b\0\0\0\0\0\0\x02\x50\0\0\0\x19\0\0\x04\x1b\0\0\
\0\0\0\0\x02\x58\0\0\0\x19\0\0\x04\x52\0\0\0\0\0\0\x02\x60\0\0\0\x19\0\0\x04\
\x52\0\0\0\0\0\0\x02\x70\0\0\0\x19\0\0\x04\x52\0\0\0\0\0\0\x02\xb8\0\0\0\x19\0\
\0\x03\xe4\0\0\0\0\0\0\x02\xc0\0\0\0\x19\0\0\x03\xe4\0\0\0\0\0\0\x02\xd0\0\0\0\
\x19\0\0\x03\xe4\0\0\0\0\0\0\x02\xd8\0\0\0\x19\0\0\x04\x1b\0\0\0\0\0\0\x02\xe0\
\0\0\0\x19\0\0\x04\x1b\0\0\0\0\0\0\x02\xf0\0\0\0\x19\0\0\x04\x1b\0\0\0\0\0\0\
\x02\xf8\0\0\0\x19\0\0\x04\x52\0\0\0\0\0\0\x03\0\0\0\0\x19\0\0\x04\x52\0\0\0\0\
\0\0\x03\x10\0\0\0\x19\0\0\x04\x52\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe7\0\0\
\0\x03\0\0\0\0\0\0\0\xb0\0\0\0\0\0\0\0\0\0\0\x01\x04\0\0\0\x03\0\0\0\0\0\0\0\
\x48\0\0\0\0\0\0\0\0\0\0\x01\x13\0\0\0\x03\0\0\0\0\0\0\x01\x78\0\0\0\0\0\0\0\0\
\0\0\0\xd9\0\0\0\x03\0\0\0\0\0\0\x01\x88\0\0\0\0\0\0\0\0\0\0\0\xcb\0\0\0\x03\0\
\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xe0\0\0\0\x05\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\xee\0\0\0\
\x05\0\0\0\0\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\xfd\0\0\0\x05\0\0\0\0\0\0\0\x58\0\
\0\0\0\0\0\0\0\0\0\0\xf5\0\0\0\x05\0\0\0\0\0\0\x01\xb0\0\0\0\0\0\0\0\0\0\0\0\
\xd2\0\0\0\x05\0\0\0\0\0\0\x01\xc0\0\0\0\0\0\0\0\0\0\0\x01\x0b\0\0\0\x05\0\0\0\
\0\0\0\x01\x88\0\0\0\0\0\0\0\0\0\0\0\x88\x12\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x01\xf0\0\0\0\x65\x11\0\0\x07\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x04\0\0\0\x30\
\x11\0\0\x09\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x18\0\0\0\x01\x11\0\0\x07\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\x23\x11\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x18\0\0\0\x93\x12\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x20\0\0\0\x1c\x11\0\
\0\x09\0\0\0\0\0\0\0\x48\0\0\0\0\0\0\0\x18\0\0\0\x40\x11\0\0\x09\0\0\0\0\0\0\0\
\x30\0\0\0\0\0\0\0\x18\0\0\0\xc3\x11\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0d\
\0\0\0\0\0\0\0\x10\0\0\0\x0f\0\0\0\x01\0\0\0\0\0\0\0\x60\0\0\0\x10\0\0\0\x01\0\
\0\0\0\0\0\0\xd8\0\0\0\x0f\0\0\0\x01\0\0\0\0\0\0\x01\x28\0\0\0\x11\0\0\0\x01\0\
\0\0\0\0\0\x01\xb0\0\0\0\x12\0\0\0\x01\0\0\0\0\0\0\0\x20\0\0\0\x0f\0\0\0\x01\0\
\0\0\0\0\0\0\x80\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\xb8\0\0\0\x12\0\0\0\x01\0\0\
\0\0\0\0\x01\x10\0\0\0\x14\0\0\0\x01\0\0\0\0\0\0\x01\x48\0\0\0\x0f\0\0\0\x01\0\
\0\0\0\0\0\x01\xd8\0\0\0\x10\0\0\0\x01\0\0\0\0\0\0\x02\x88\0\0\0\x15\0\0\0\x01\
\0\0\0\0\0\0\x02\xfc\0\0\0\x12\0\0\0\x04\0\0\0\0\0\0\x03\x08\0\0\0\x10\0\0\0\
\x04\0\0\0\0\0\0\x03\x14\0\0\0\x15\0\0\0\x04\0\0\0\0\0\0\x03\x20\0\0\0\x14\0\0\
\0\x04\0\0\0\0\0\0\x03\x38\0\0\0\x11\0\0\0\x03\0\0\0\0\0\0\x03\x44\0\0\0\x0f\0\
\0\0\x03\0\0\0\0\0\0\x03\x5c\0\0\0\x16\0\0\0\x04\0\0\0\0\0\0\0\x2c\0\0\0\x01\0\
\0\0\x04\0\0\0\0\0\0\0\x3c\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\0\x50\0\0\0\x01\0\0\
\0\x04\0\0\0\0\0\0\0\x60\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\x70\0\0\0\x01\0\0\0\
\x04\0\0\0\0\0\0\0\x80\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\x90\0\0\0\x01\0\0\0\
\x04\0\0\0\0\0\0\0\xa0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\xb0\0\0\0\x01\0\0\0\
\x04\0\0\0\0\0\0\0\xc0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\xd0\0\0\0\x01\0\0\0\
\x04\0\0\0\0\0\0\0\xe0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\xf0\0\0\0\x01\0\0\0\
\x04\0\0\0\0\0\0\x01\0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x10\0\0\0\x01\0\0\0\
\x04\0\0\0\0\0\0\x01\x20\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x30\0\0\0\x01\0\0\
\0\x04\0\0\0\0\0\0\x01\x40\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x50\0\0\0\x01\0\
\0\0\x04\0\0\0\0\0\0\x01\x60\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x70\0\0\0\x01\
\0\0\0\x04\0\0\0\0\0\0\x01\x80\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\x90\0\0\0\
\x01\0\0\0\x04\0\0\0\0\0\0\x01\xa0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\xb0\0\0\
\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\xc0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\xd0\0\
\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\xe0\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x01\xf0\
\0\0\0\x01\0\0\0\x04\0\0\0\0\0\0\x02\x08\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x02\
\x18\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x02\x28\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\
\x02\x38\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x02\x48\0\0\0\x07\0\0\0\x04\0\0\0\0\0\
\0\x02\x58\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x02\x68\0\0\0\x07\0\0\0\x04\0\0\0\0\
\0\0\x02\x78\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x02\x88\0\0\0\x07\0\0\0\x04\0\0\0\
\0\0\0\x02\x98\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x02\xa8\0\0\0\x07\0\0\0\x04\0\0\
\0\0\0\0\x02\xb8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x02\xc8\0\0\0\x07\0\0\0\x04\0\
\0\0\0\0\0\x02\xd8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x02\xe8\0\0\0\x07\0\0\0\x04\
\0\0\0\0\0\0\x02\xf8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\x08\0\0\0\x07\0\0\0\
\x04\0\0\0\0\0\0\x03\x18\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\x28\0\0\0\x07\0\0\
\0\x04\0\0\0\0\0\0\x03\x38\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\x48\0\0\0\x07\0\
\0\0\x04\0\0\0\0\0\0\x03\x58\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\x68\0\0\0\x07\
\0\0\0\x04\0\0\0\0\0\0\x03\x78\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\x88\0\0\0\
\x07\0\0\0\x04\0\0\0\0\0\0\x03\x98\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\xa8\0\0\
\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\xb8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\xc8\0\
\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\xd8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\xe8\
\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x03\xf8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\
\x08\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\x18\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\
\x04\x28\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\x38\0\0\0\x07\0\0\0\x04\0\0\0\0\0\
\0\x04\x48\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\x58\0\0\0\x07\0\0\0\x04\0\0\0\0\
\0\0\x04\x68\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\x78\0\0\0\x07\0\0\0\x04\0\0\0\
\0\0\0\x04\x88\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\x98\0\0\0\x07\0\0\0\x04\0\0\
\0\0\0\0\x04\xa8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\xb8\0\0\0\x07\0\0\0\x04\0\
\0\0\0\0\0\x04\xc8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\xd8\0\0\0\x07\0\0\0\x04\
\0\0\0\0\0\0\x04\xe8\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x04\xf8\0\0\0\x07\0\0\0\
\x04\0\0\0\0\0\0\x05\x08\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\x18\0\0\0\x07\0\0\
\0\x04\0\0\0\0\0\0\x05\x28\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\x38\0\0\0\x07\0\
\0\0\x04\0\0\0\0\0\0\x05\x48\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\x64\0\0\0\x07\
\0\0\0\x04\0\0\0\0\0\0\x05\x74\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\x84\0\0\0\
\x07\0\0\0\x04\0\0\0\0\0\0\x05\x94\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\xa4\0\0\
\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\xb4\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\xc4\0\
\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\xd4\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\xe4\
\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x05\xf4\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x06\
\x04\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x06\x14\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\
\x06\x24\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x06\x34\0\0\0\x07\0\0\0\x04\0\0\0\0\0\
\0\x06\x44\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x06\x54\0\0\0\x07\0\0\0\x04\0\0\0\0\
\0\0\x06\x64\0\0\0\x07\0\0\0\x04\0\0\0\0\0\0\x06\x74\0\0\0\x07\0\0\0\x04\0\0\0\
\0\0\0\x06\x84\0\0\0\x07\0\0\0\x04\x15\x1a\x18\x16\x1d\x19\x17\x1c\x1b\0\x6e\
\x75\x6d\x5f\x63\x70\x75\0\x2e\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x2e\x42\x54\
\x46\x2e\x65\x78\x74\0\x63\x6f\x75\x6e\x74\x73\0\x65\x76\x65\x6e\x74\x73\0\x2e\
\x6d\x61\x70\x73\0\x66\x65\x6e\x74\x72\x79\x5f\x72\x65\x61\x64\x69\x6e\x67\x73\
\0\x61\x63\x63\x75\x6d\x5f\x72\x65\x61\x64\x69\x6e\x67\x73\0\x2e\x6c\x6c\x76\
\x6d\x5f\x61\x64\x64\x72\x73\x69\x67\0\x6c\x69\x63\x65\x6e\x73\x65\0\x6e\x75\
\x6d\x5f\x6d\x65\x74\x72\x69\x63\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\
\x6d\x74\x61\x62\0\x2e\x72\x6f\x64\x61\x74\x61\0\x66\x65\x6e\x74\x72\x79\x5f\
\x58\x58\x58\0\x66\x65\x78\x69\x74\x5f\x58\x58\x58\0\x2e\x72\x65\x6c\x66\x65\
\x6e\x74\x72\x79\x2f\x58\x58\x58\0\x2e\x72\x65\x6c\x66\x65\x78\x69\x74\x2f\x58\
\x58\x58\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\0\x4c\x49\x43\x45\x4e\x53\x45\0\x4c\
\x42\x42\x30\x5f\x39\0\x4c\x42\x42\x31\x5f\x38\0\x4c\x42\x42\x30\x5f\x37\0\x4c\
\x42\x42\x31\x5f\x35\0\x4c\x42\x42\x30\x5f\x35\0\x4c\x42\x42\x31\x5f\x34\0\x4c\
\x42\x42\x31\x5f\x31\x34\0\x4c\x42\x42\x31\x5f\x32\0\x4c\x42\x42\x30\x5f\x32\0\
\x4c\x42\x42\x31\x5f\x31\x32\0\x4c\x42\x42\x30\x5f\x31\x31\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\0\0\0\x03\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x1e\xf1\0\0\0\0\0\0\x01\x1b\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\
\0\0\0\0\0\0\0\xa1\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x40\0\0\0\0\0\0\x01\xf0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\
\0\x9d\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x17\x68\0\0\0\0\
\0\0\0\x50\0\0\0\x0f\0\0\0\x03\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\xb0\0\
\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x30\0\0\0\0\0\0\x03\
\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\xac\0\0\0\x09\0\0\
\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x17\xb8\0\0\0\0\0\0\0\x70\0\0\0\x0f\
\0\0\0\x05\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\x80\0\0\0\x01\0\0\0\0\0\0\
\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x05\x50\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\x5d\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x05\x58\0\0\0\0\0\0\0\x0d\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\x2a\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x05\x68\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\
\0\0\0\0\0\0\xbe\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x05\xc8\
\0\0\0\0\0\0\x08\xe3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\
\xba\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x28\0\0\0\0\0\
\0\0\x70\0\0\0\x0f\0\0\0\x0a\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\x13\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xac\0\0\0\0\0\0\x06\x94\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\x0f\0\0\0\x09\0\0\0\0\
\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x98\0\0\0\0\0\0\x06\x50\0\0\0\x0f\0\
\0\0\x0c\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\x4f\x6f\xff\x4c\x03\0\0\0\0\
\x80\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1e\xe8\0\0\0\0\0\0\0\x09\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x78\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x15\x40\0\0\0\0\0\0\x02\x28\0\0\0\x01\0\0\0\x0e\0\0\0\0\
\0\0\0\x08\0\0\0\0\0\0\0\x18";
}

#ifdef __cplusplus
struct profiler_bpf *profiler_bpf::open(const struct bpf_object_open_opts *opts) { return profiler_bpf__open_opts(opts); }
struct profiler_bpf *profiler_bpf::open_and_load() { return profiler_bpf__open_and_load(); }
int profiler_bpf::load(struct profiler_bpf *skel) { return profiler_bpf__load(skel); }
int profiler_bpf::attach(struct profiler_bpf *skel) { return profiler_bpf__attach(skel); }
void profiler_bpf::detach(struct profiler_bpf *skel) { profiler_bpf__detach(skel); }
void profiler_bpf::destroy(struct profiler_bpf *skel) { profiler_bpf__destroy(skel); }
const void *profiler_bpf::elf_bytes(size_t *sz) { return profiler_bpf__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
profiler_bpf__assert(struct profiler_bpf *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->rodata->num_cpu) == 4, "unexpected size of 'num_cpu'");
	_Static_assert(sizeof(s->rodata->num_metric) == 4, "unexpected size of 'num_metric'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __PROFILER_BPF_SKEL_H__ */
