/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __BPF_LOOP_SKEL_H__
#define __BPF_LOOP_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct bpf_loop {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *data;
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *test_prog;
		struct bpf_program *prog_null_ctx;
		struct bpf_program *prog_invalid_flags;
		struct bpf_program *prog_nested_calls;
	} progs;
	struct {
		struct bpf_link *test_prog;
		struct bpf_link *prog_null_ctx;
		struct bpf_link *prog_invalid_flags;
		struct bpf_link *prog_nested_calls;
	} links;
	struct bpf_loop__data {
		u32 stop_index;
	} *data;
	struct bpf_loop__bss {
		int pid;
		u32 nr_loops;
		int nr_loops_returned;
		int err;
		int g_output;
		u32 nested_callback_nr_loops;
	} *bss;

#ifdef __cplusplus
	static inline struct bpf_loop *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct bpf_loop *open_and_load();
	static inline int load(struct bpf_loop *skel);
	static inline int attach(struct bpf_loop *skel);
	static inline void detach(struct bpf_loop *skel);
	static inline void destroy(struct bpf_loop *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
bpf_loop__destroy(struct bpf_loop *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
bpf_loop__create_skeleton(struct bpf_loop *obj);

static inline struct bpf_loop *
bpf_loop__open_opts(const struct bpf_object_open_opts *opts)
{
	struct bpf_loop *obj;
	int err;

	obj = (struct bpf_loop *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = bpf_loop__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	bpf_loop__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct bpf_loop *
bpf_loop__open(void)
{
	return bpf_loop__open_opts(NULL);
}

static inline int
bpf_loop__load(struct bpf_loop *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct bpf_loop *
bpf_loop__open_and_load(void)
{
	struct bpf_loop *obj;
	int err;

	obj = bpf_loop__open();
	if (!obj)
		return NULL;
	err = bpf_loop__load(obj);
	if (err) {
		bpf_loop__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
bpf_loop__attach(struct bpf_loop *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
bpf_loop__detach(struct bpf_loop *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *bpf_loop__elf_bytes(size_t *sz);

static inline int
bpf_loop__create_skeleton(struct bpf_loop *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "bpf_loop";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 2;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "bpf_loop.data";
	s->maps[0].map = &obj->maps.data;
	s->maps[0].mmaped = (void **)&obj->data;

	s->maps[1].name = "bpf_loop.bss";
	s->maps[1].map = &obj->maps.bss;
	s->maps[1].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 4;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "test_prog";
	s->progs[0].prog = &obj->progs.test_prog;
	s->progs[0].link = &obj->links.test_prog;

	s->progs[1].name = "prog_null_ctx";
	s->progs[1].prog = &obj->progs.prog_null_ctx;
	s->progs[1].link = &obj->links.prog_null_ctx;

	s->progs[2].name = "prog_invalid_flags";
	s->progs[2].prog = &obj->progs.prog_invalid_flags;
	s->progs[2].link = &obj->links.prog_invalid_flags;

	s->progs[3].name = "prog_nested_calls";
	s->progs[3].prog = &obj->progs.prog_nested_calls;
	s->progs[3].link = &obj->links.prog_nested_calls;

	s->data = (void *)bpf_loop__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *bpf_loop__elf_bytes(size_t *sz)
{
	*sz = 6408;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x16\x08\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0c\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x74\x65\
\x78\x74\0\x66\x65\x6e\x74\x72\x79\x2f\x5f\x5f\x73\x33\x39\x30\x78\x5f\x73\x79\
\x73\x5f\x6e\x61\x6e\x6f\x73\x6c\x65\x65\x70\0\x6c\x69\x63\x65\x6e\x73\x65\0\
\x2e\x64\x61\x74\x61\0\x2e\x62\x73\x73\0\x62\x70\x66\x5f\x6c\x6f\x6f\x70\x2e\
\x63\0\x4c\x42\x42\x30\x5f\x34\0\x63\x61\x6c\x6c\x62\x61\x63\x6b\0\x4c\x42\x42\
\x30\x5f\x33\0\x4c\x42\x42\x31\x5f\x32\0\x4c\x42\x42\x32\x5f\x32\0\x65\x6d\x70\
\x74\x79\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\0\x4c\x42\x42\x34\x5f\x32\0\x4c\
\x42\x42\x35\x5f\x32\0\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\x62\x61\x63\
\x6b\x31\0\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\x32\0\
\x74\x65\x73\x74\x5f\x70\x72\x6f\x67\0\x70\x69\x64\0\x6e\x72\x5f\x6c\x6f\x6f\
\x70\x73\0\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\x5f\x72\x65\x74\x75\x72\x6e\x65\x64\
\0\x65\x72\x72\0\x67\x5f\x6f\x75\x74\x70\x75\x74\0\x73\x74\x6f\x70\x5f\x69\x6e\
\x64\x65\x78\0\x70\x72\x6f\x67\x5f\x6e\x75\x6c\x6c\x5f\x63\x74\x78\0\x70\x72\
\x6f\x67\x5f\x69\x6e\x76\x61\x6c\x69\x64\x5f\x66\x6c\x61\x67\x73\0\x70\x72\x6f\
\x67\x5f\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\x73\0\x6e\x65\x73\x74\x65\
\x64\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\0\
\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x2e\x74\x65\x78\x74\0\x2e\
\x72\x65\x6c\x66\x65\x6e\x74\x72\x79\x2f\x5f\x5f\x73\x33\x39\x30\x78\x5f\x73\
\x79\x73\x5f\x6e\x61\x6e\x6f\x73\x6c\x65\x65\x70\0\x2e\x42\x54\x46\0\x2e\x42\
\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x47\x04\0\xff\xf1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x03\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x52\0\0\0\x04\0\0\0\0\0\0\0\xf8\0\0\0\0\0\0\0\0\0\0\0\x59\x02\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x50\0\0\0\x62\0\0\0\x04\0\0\0\0\0\0\0\xd8\0\
\0\0\0\0\0\0\0\0\0\0\x69\0\0\0\x03\0\0\0\0\0\0\0\x48\0\0\0\0\0\0\0\0\0\0\0\x70\
\0\0\0\x04\0\0\0\0\0\0\x01\xa0\0\0\0\0\0\0\0\0\0\0\0\x77\x02\0\0\x03\0\0\0\0\0\
\0\0\x50\0\0\0\0\0\0\0\x10\0\0\0\x86\0\0\0\x04\0\0\0\0\0\0\x02\x60\0\0\0\0\0\0\
\0\0\0\0\0\x8d\0\0\0\x04\0\0\0\0\0\0\x03\x40\0\0\0\0\0\0\0\0\0\0\0\x94\x02\0\0\
\x03\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\x50\0\0\0\xa5\x02\0\0\x03\0\0\0\0\0\0\0\
\xb0\0\0\0\0\0\0\0\x78\0\0\0\xb6\x12\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\
\x08\0\0\0\xc0\x11\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xc4\x11\0\0\
\x07\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x04\0\0\0\xcd\x11\0\0\x07\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\x04\0\0\0\xdf\x11\0\0\x07\0\0\0\0\0\0\0\x0c\0\0\0\0\0\0\0\
\x04\0\0\0\xe3\x11\0\0\x07\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x04\0\0\0\xec\x11\0\
\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xf7\x12\0\0\x04\0\0\0\0\0\0\x01\
\x08\0\0\0\0\0\0\0\xa8\0\0\x01\x05\x12\0\0\x04\0\0\0\0\0\0\x01\xb0\0\0\0\0\0\0\
\0\xc0\0\0\x01\x18\x12\0\0\x04\0\0\0\0\0\0\x02\x70\0\0\0\0\0\0\0\xe0\0\0\x01\
\x2a\x11\0\0\x07\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\x04\0\0\x01\x43\x11\0\0\x05\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\xb4\0\0\0\0\0\0\x01\x18\x30\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x61\x33\0\0\0\0\0\0\xbe\x31\0\x04\0\0\0\0\x61\x32\0\0\0\0\0\0\x0c\
\x31\0\0\0\0\0\0\x63\x23\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb4\0\
\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xbf\x32\0\0\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x61\x11\0\0\0\0\0\0\x18\x20\0\0\0\0\0\xb0\0\0\0\0\0\0\0\0\xb7\x40\0\0\
\0\0\0\0\x85\0\0\0\0\0\0\xb5\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xbf\x32\0\0\0\
\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x18\x20\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\0\x85\0\0\0\0\0\0\xb5\x18\x10\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x61\x21\0\0\0\0\0\0\x0c\x20\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\
\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb4\x10\0\0\0\0\0\0\x63\xa1\xff\xf8\0\0\0\
\0\x85\0\0\0\0\0\0\x0e\x77\0\0\0\0\0\0\x20\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x61\x11\0\0\0\0\0\0\x67\x10\0\0\0\0\0\x20\xc7\x10\0\0\0\0\0\x20\x5d\x01\0\x15\
\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\xbf\x3a\0\0\0\
\0\0\0\x07\x30\0\0\xff\xff\xff\xf8\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x40\
\0\0\0\0\0\0\x85\0\0\0\0\0\0\xb5\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x10\0\
\0\0\0\0\0\x66\0\0\x04\xff\xff\xff\xff\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\
\x10\0\0\0\0\0\0\x05\0\0\x04\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\
\x2a\xff\xf8\0\0\0\0\x63\x12\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\
\x85\0\0\0\0\0\0\x0e\x77\0\0\0\0\0\0\x20\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x61\x11\0\0\0\0\0\0\x67\x10\0\0\0\0\0\x20\xc7\x10\0\0\0\0\0\x20\x5d\x01\0\x0b\
\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x18\x20\0\0\0\
\0\0\x50\0\0\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\0\x85\0\0\0\0\0\
\0\xb5\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x10\0\0\0\0\0\0\xb4\0\0\0\0\0\0\
\0\x95\0\0\0\0\0\0\0\xb4\x10\0\0\0\0\0\0\x63\xa1\xff\xf8\0\0\0\0\x85\0\0\0\0\0\
\0\x0e\x77\0\0\0\0\0\0\x20\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\
\0\0\x67\x10\0\0\0\0\0\x20\xc7\x10\0\0\0\0\0\x20\x5d\x01\0\x0c\0\0\0\0\x18\x10\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\xbf\x3a\0\0\0\0\0\0\x07\x30\0\
\0\xff\xff\xff\xf8\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\x01\
\x85\0\0\0\0\0\0\xb5\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x10\0\0\0\0\0\0\
\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb4\x60\0\0\0\0\0\0\x63\xa6\xff\xf8\0\0\0\
\0\x85\0\0\0\0\0\0\x0e\x77\0\0\0\0\0\0\x20\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x61\x11\0\0\0\0\0\0\x67\x10\0\0\0\0\0\x20\xc7\x10\0\0\0\0\0\x20\x5d\x01\0\x10\
\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x16\0\0\0\0\0\0\x18\x10\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\xbf\x3a\0\0\0\0\0\0\x07\x30\0\0\xff\
\xff\xff\xf8\x18\x20\0\0\0\0\0\x60\0\0\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\0\x85\0\0\
\0\0\0\0\xb5\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x2a\xff\xf8\0\0\0\0\x63\
\x12\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\xff\xff\xff\
\xff\0\0\0\0\0\0\0\x08\0\0\0\x14\0\0\0\x01\0\0\0\0\0\0\0\x68\0\0\0\x18\0\0\0\
\x01\0\0\0\0\0\0\0\x80\0\0\0\x02\0\0\0\x01\0\0\0\0\0\0\0\xb8\0\0\0\x18\0\0\0\
\x01\0\0\0\0\0\0\0\xd0\0\0\0\x02\0\0\0\x01\0\0\0\0\0\0\0\xf0\0\0\0\x11\0\0\0\
\x01\0\0\0\0\0\0\0\x20\0\0\0\x0f\0\0\0\x01\0\0\0\0\0\0\0\x50\0\0\0\x10\0\0\0\
\x01\0\0\0\0\0\0\0\x78\0\0\0\x02\0\0\0\x01\0\0\0\0\0\0\0\x98\0\0\0\x11\0\0\0\
\x01\0\0\0\0\0\0\0\xb8\0\0\0\x12\0\0\0\x01\0\0\0\0\0\0\0\xd8\0\0\0\x13\0\0\0\
\x01\0\0\0\0\0\0\x01\x18\0\0\0\x0f\0\0\0\x01\0\0\0\0\0\0\x01\x48\0\0\0\x10\0\0\
\0\x01\0\0\0\0\0\0\x01\x60\0\0\0\x02\0\0\0\x01\0\0\0\0\0\0\x01\x88\0\0\0\x11\0\
\0\0\x01\0\0\0\0\0\0\x01\xd0\0\0\0\x0f\0\0\0\x01\0\0\0\0\0\0\x02\0\0\0\0\x10\0\
\0\0\x01\0\0\0\0\0\0\x02\x28\0\0\0\x02\0\0\0\x01\0\0\0\0\0\0\x02\x48\0\0\0\x12\
\0\0\0\x01\0\0\0\0\0\0\x02\x90\0\0\0\x0f\0\0\0\x01\0\0\0\0\0\0\x02\xc0\0\0\0\
\x11\0\0\0\x01\0\0\0\0\0\0\x02\xd8\0\0\0\x10\0\0\0\x01\0\0\0\0\0\0\x03\0\0\0\0\
\x02\0\0\0\x01\0\0\0\0\0\0\x03\x20\0\0\0\x13\0\0\0\x01\xeb\x9f\x01\0\0\0\0\x18\
\0\0\0\0\0\0\x02\x10\0\0\x02\x10\0\0\x05\x2b\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\
\x0d\0\0\x01\0\0\0\x03\0\0\0\x01\0\0\0\x01\0\0\0\x05\x01\0\0\0\0\0\0\x04\x01\0\
\0\x20\0\0\0\x09\x0c\0\0\x01\0\0\0\x02\0\0\0\x13\x08\0\0\0\0\0\0\x06\0\0\0\x19\
\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\x0d\0\0\x02\0\0\0\x03\0\0\0\x26\0\0\0\
\x05\0\0\0\x2c\0\0\0\x01\0\0\0\x31\x0c\0\0\0\0\0\0\x07\0\0\0\x3a\x0c\0\0\x01\0\
\0\0\x02\0\0\0\x48\x0c\0\0\0\0\0\0\x07\0\0\0\x57\x0c\0\0\x01\0\0\0\x02\0\0\0\
\x6a\x0c\0\0\x01\0\0\0\x02\0\0\0\x7c\x0c\0\0\0\0\0\0\x07\0\0\0\x8d\x0c\0\0\0\0\
\0\0\x07\0\0\0\x9e\x01\0\0\0\0\0\0\x01\x01\0\0\x08\0\0\0\0\x03\0\0\0\0\0\0\0\0\
\0\0\x0f\0\0\0\x11\0\0\0\x04\0\0\0\xa3\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\xb7\
\x0e\0\0\0\0\0\0\x10\0\0\0\x01\0\0\0\xc0\x08\0\0\0\0\0\0\x05\0\0\0\xc4\x0e\0\0\
\0\0\0\0\x13\0\0\0\x01\0\0\0\xcf\x0e\0\0\0\0\0\0\x03\0\0\0\x01\0\0\0\xd3\x0e\0\
\0\0\0\0\0\x13\0\0\0\x01\0\0\0\xdc\x0e\0\0\0\0\0\0\x03\0\0\0\x01\0\0\0\xee\x0e\
\0\0\0\0\0\0\x03\0\0\0\x01\0\0\0\xf2\x0e\0\0\0\0\0\0\x03\0\0\0\x01\0\0\0\xfb\
\x0e\0\0\0\0\0\0\x13\0\0\0\x01\0\0\x04\xf5\x0f\0\0\x01\0\0\0\x04\0\0\0\x12\0\0\
\0\0\0\0\0\x04\0\0\x04\xfd\x0f\0\0\x01\0\0\0\x04\0\0\0\x14\0\0\0\0\0\0\0\x04\0\
\0\x05\x03\x0f\0\0\x06\0\0\0\x18\0\0\0\x15\0\0\0\0\0\0\0\x04\0\0\0\x16\0\0\0\
\x04\0\0\0\x04\0\0\0\x17\0\0\0\x08\0\0\0\x04\0\0\0\x18\0\0\0\x0c\0\0\0\x04\0\0\
\0\x19\0\0\0\x10\0\0\0\x04\0\0\0\x1a\0\0\0\x14\0\0\0\x04\0\x63\x74\x78\0\x69\
\x6e\x74\0\x74\x65\x73\x74\x5f\x70\x72\x6f\x67\0\x5f\x5f\x75\x33\x32\0\x75\x6e\
\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x69\x6e\x64\x65\x78\0\x64\x61\x74\
\x61\0\x63\x61\x6c\x6c\x62\x61\x63\x6b\0\x70\x72\x6f\x67\x5f\x6e\x75\x6c\x6c\
\x5f\x63\x74\x78\0\x65\x6d\x70\x74\x79\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\0\
\x70\x72\x6f\x67\x5f\x69\x6e\x76\x61\x6c\x69\x64\x5f\x66\x6c\x61\x67\x73\0\x70\
\x72\x6f\x67\x5f\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\x73\0\x6e\x65\x73\
\x74\x65\x64\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\x31\0\x6e\x65\x73\x74\x65\x64\
\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\x32\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\
\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x5f\x6c\x69\x63\
\x65\x6e\x73\x65\0\x75\x33\x32\0\x73\x74\x6f\x70\x5f\x69\x6e\x64\x65\x78\0\x70\
\x69\x64\0\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\0\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\
\x5f\x72\x65\x74\x75\x72\x6e\x65\x64\0\x65\x72\x72\0\x67\x5f\x6f\x75\x74\x70\
\x75\x74\0\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x6e\
\x72\x5f\x6c\x6f\x6f\x70\x73\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\
\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\
\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\
\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\
\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\
\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x62\x70\
\x66\x5f\x6c\x6f\x6f\x70\x2e\x63\0\x73\x74\x61\x74\x69\x63\x20\x69\x6e\x74\x20\
\x63\x61\x6c\x6c\x62\x61\x63\x6b\x28\x5f\x5f\x75\x33\x32\x20\x69\x6e\x64\x65\
\x78\x2c\x20\x76\x6f\x69\x64\x20\x2a\x64\x61\x74\x61\x29\0\x09\x69\x66\x20\x28\
\x69\x6e\x64\x65\x78\x20\x3e\x3d\x20\x73\x74\x6f\x70\x5f\x69\x6e\x64\x65\x78\
\x29\0\x09\x63\x74\x78\x2d\x3e\x6f\x75\x74\x70\x75\x74\x20\x2b\x3d\x20\x69\x6e\
\x64\x65\x78\x3b\0\x7d\0\x09\x72\x65\x74\x75\x72\x6e\x20\x30\x3b\0\x73\x74\x61\
\x74\x69\x63\x20\x69\x6e\x74\x20\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\
\x62\x61\x63\x6b\x31\x28\x5f\x5f\x75\x33\x32\x20\x69\x6e\x64\x65\x78\x2c\x20\
\x76\x6f\x69\x64\x20\x2a\x64\x61\x74\x61\x29\0\x09\x62\x70\x66\x5f\x6c\x6f\x6f\
\x70\x28\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x6e\
\x72\x5f\x6c\x6f\x6f\x70\x73\x2c\x20\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\
\x6c\x62\x61\x63\x6b\x32\x2c\x20\x64\x61\x74\x61\x2c\x20\x30\x29\x3b\0\x73\x74\
\x61\x74\x69\x63\x20\x69\x6e\x74\x20\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\
\x6c\x62\x61\x63\x6b\x32\x28\x5f\x5f\x75\x33\x32\x20\x69\x6e\x64\x65\x78\x2c\
\x20\x76\x6f\x69\x64\x20\x2a\x64\x61\x74\x61\x29\0\x09\x6e\x72\x5f\x6c\x6f\x6f\
\x70\x73\x5f\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x2b\x3d\x20\x62\x70\x66\x5f\
\x6c\x6f\x6f\x70\x28\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\x62\x61\x63\
\x6b\x5f\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\x2c\x20\x63\x61\x6c\x6c\x62\x61\x63\
\x6b\x2c\x20\x64\x61\x74\x61\x2c\x20\x30\x29\x3b\0\x69\x6e\x74\x20\x74\x65\x73\
\x74\x5f\x70\x72\x6f\x67\x28\x76\x6f\x69\x64\x20\x2a\x63\x74\x78\x29\0\x09\x73\
\x74\x72\x75\x63\x74\x20\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x63\x74\x78\x20\
\x64\x61\x74\x61\x20\x3d\x20\x7b\x7d\x3b\0\x09\x69\x66\x20\x28\x62\x70\x66\x5f\
\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x70\x69\x64\x5f\x74\x67\x69\
\x64\x28\x29\x20\x3e\x3e\x20\x33\x32\x20\x21\x3d\x20\x70\x69\x64\x29\0\x09\x6e\
\x72\x5f\x6c\x6f\x6f\x70\x73\x5f\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x3d\x20\
\x62\x70\x66\x5f\x6c\x6f\x6f\x70\x28\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\x2c\x20\
\x63\x61\x6c\x6c\x62\x61\x63\x6b\x2c\x20\x26\x64\x61\x74\x61\x2c\x20\x30\x29\
\x3b\0\x09\x69\x66\x20\x28\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\x5f\x72\x65\x74\x75\
\x72\x6e\x65\x64\x20\x3c\x20\x30\x29\0\x09\x09\x65\x72\x72\x20\x3d\x20\x6e\x72\
\x5f\x6c\x6f\x6f\x70\x73\x5f\x72\x65\x74\x75\x72\x6e\x65\x64\x3b\0\x09\x09\x67\
\x5f\x6f\x75\x74\x70\x75\x74\x20\x3d\x20\x64\x61\x74\x61\x2e\x6f\x75\x74\x70\
\x75\x74\x3b\0\x09\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\x5f\x72\x65\x74\x75\x72\x6e\
\x65\x64\x20\x3d\x20\x62\x70\x66\x5f\x6c\x6f\x6f\x70\x28\x6e\x72\x5f\x6c\x6f\
\x6f\x70\x73\x2c\x20\x65\x6d\x70\x74\x79\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\
\x2c\x20\x4e\x55\x4c\x4c\x2c\x20\x30\x29\x3b\0\x69\x6e\x74\x20\x70\x72\x6f\x67\
\x5f\x69\x6e\x76\x61\x6c\x69\x64\x5f\x66\x6c\x61\x67\x73\x28\x76\x6f\x69\x64\
\x20\x2a\x63\x74\x78\x29\0\x09\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x6c\x6f\
\x6f\x70\x28\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\x2c\x20\x63\x61\x6c\x6c\x62\x61\
\x63\x6b\x2c\x20\x26\x64\x61\x74\x61\x2c\x20\x31\x29\x3b\0\x69\x6e\x74\x20\x70\
\x72\x6f\x67\x5f\x6e\x65\x73\x74\x65\x64\x5f\x63\x61\x6c\x6c\x73\x28\x76\x6f\
\x69\x64\x20\x2a\x63\x74\x78\x29\0\x09\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\x5f\x72\
\x65\x74\x75\x72\x6e\x65\x64\x20\x3d\x20\x30\x3b\0\x09\x62\x70\x66\x5f\x6c\x6f\
\x6f\x70\x28\x6e\x72\x5f\x6c\x6f\x6f\x70\x73\x2c\x20\x6e\x65\x73\x74\x65\x64\
\x5f\x63\x61\x6c\x6c\x62\x61\x63\x6b\x31\x2c\x20\x26\x64\x61\x74\x61\x2c\x20\
\x30\x29\x3b\0\x09\x67\x5f\x6f\x75\x74\x70\x75\x74\x20\x3d\x20\x64\x61\x74\x61\
\x2e\x6f\x75\x74\x70\x75\x74\x3b\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x64\x61\
\x74\x61\0\x2e\x62\x73\x73\0\x2e\x74\x65\x78\x74\0\x66\x65\x6e\x74\x72\x79\x2f\
\x5f\x5f\x73\x33\x39\x30\x78\x5f\x73\x79\x73\x5f\x6e\x61\x6e\x6f\x73\x6c\x65\
\x65\x70\0\0\0\0\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x54\0\0\0\x54\0\0\
\x03\xf4\0\0\x04\x48\0\0\0\0\0\0\0\x08\0\0\x05\x08\0\0\0\x04\0\0\0\0\0\0\0\x08\
\0\0\0\x50\0\0\0\x0a\0\0\0\x60\0\0\0\x0d\0\0\0\xb0\0\0\0\x0e\0\0\x05\x0e\0\0\0\
\x04\0\0\0\0\0\0\0\x04\0\0\x01\x08\0\0\0\x09\0\0\x01\xb0\0\0\0\x0b\0\0\x02\x70\
\0\0\0\x0c\0\0\0\x10\0\0\x05\x08\0\0\0\x0f\0\0\0\0\0\0\x01\x14\0\0\x01\x88\0\0\
\x6c\0\0\0\0\x08\0\0\x01\x14\0\0\x01\xb5\0\0\x7c\x0f\0\0\0\x20\0\0\x01\x14\0\0\
\x01\xb5\0\0\x7c\x06\0\0\0\x28\0\0\x01\x14\0\0\x01\xcf\0\0\x88\x0e\0\0\0\x48\0\
\0\x01\x14\0\0\x01\xe6\0\0\x94\x01\0\0\0\x50\0\0\x01\x14\0\0\x01\xe8\0\0\xa4\
\x02\0\0\0\x60\0\0\x01\x14\0\0\x01\xf3\0\0\xcc\0\0\0\0\x68\0\0\x01\x14\0\0\x02\
\x28\0\0\xd4\x0b\0\0\0\x80\0\0\x01\x14\0\0\x02\x28\0\0\xd4\x02\0\0\0\xa0\0\0\
\x01\x14\0\0\x01\xe8\0\0\xd8\x02\0\0\0\xb0\0\0\x01\x14\0\0\x02\x68\0\0\xb0\0\0\
\0\0\xb8\0\0\x01\x14\0\0\x02\x9d\0\0\xb8\x20\0\0\0\xd0\0\0\x01\x14\0\0\x02\x9d\
\0\0\xb8\x17\0\0\0\xf0\0\0\x01\x14\0\0\x02\x9d\0\0\xb8\x14\0\0\x01\x18\0\0\x01\
\x14\0\0\x01\xe8\0\0\xc0\x02\0\0\x05\x0e\0\0\0\x2f\0\0\0\0\0\0\x01\x14\0\0\x02\
\xea\0\0\xe8\0\0\0\0\x08\0\0\x01\x14\0\0\x03\x03\0\0\xf0\x16\0\0\0\x10\0\0\x01\
\x14\0\0\x03\x23\0\0\xf8\x06\0\0\0\x18\0\0\x01\x14\0\0\x03\x23\0\0\xf8\x21\0\0\
\0\x20\0\0\x01\x14\0\0\x03\x23\0\0\xf8\x2a\0\0\0\x48\0\0\x01\x14\0\0\x03\x23\0\
\0\xf8\x06\0\0\0\x50\0\0\x01\x14\0\0\x03\x51\0\x01\x04\x1f\0\0\0\x78\0\0\x01\
\x14\0\0\x03\x51\0\x01\x04\x16\0\0\0\x98\0\0\x01\x14\0\0\x03\x51\0\x01\x04\x14\
\0\0\0\xb0\0\0\x01\x14\0\0\x03\x8e\0\x01\x0c\x06\0\0\0\xb8\0\0\x01\x14\0\0\x03\
\xaa\0\x01\x10\x07\0\0\0\xd8\0\0\x01\x14\0\0\x03\xc5\0\x01\x18\x0c\0\0\0\xe8\0\
\0\x01\x14\0\0\x03\xc5\0\x01\x18\x13\0\0\0\xf0\0\0\x01\x14\0\0\x03\xc5\0\x01\
\x18\x0c\0\0\0\xf8\0\0\x01\x14\0\0\x01\xe6\0\x01\x24\x01\0\0\x01\x08\0\0\x01\
\x14\0\0\x03\x23\0\x01\x38\x06\0\0\x01\x10\0\0\x01\x14\0\0\x03\x23\0\x01\x38\
\x21\0\0\x01\x18\0\0\x01\x14\0\0\x03\x23\0\x01\x38\x2a\0\0\x01\x40\0\0\x01\x14\
\0\0\x03\x23\0\x01\x38\x06\0\0\x01\x48\0\0\x01\x14\0\0\x03\xdf\0\x01\x44\x1f\0\
\0\x01\x60\0\0\x01\x14\0\0\x03\xdf\0\x01\x44\x16\0\0\x01\x88\0\0\x01\x14\0\0\
\x03\xdf\0\x01\x44\x14\0\0\x01\xa0\0\0\x01\x14\0\0\x01\xe6\0\x01\x50\x01\0\0\
\x01\xb0\0\0\x01\x14\0\0\x04\x21\0\x01\x5c\0\0\0\x01\xb8\0\0\x01\x14\0\0\x03\
\x03\0\x01\x64\x16\0\0\x01\xc0\0\0\x01\x14\0\0\x03\x23\0\x01\x6c\x06\0\0\x01\
\xc8\0\0\x01\x14\0\0\x03\x23\0\x01\x6c\x21\0\0\x01\xd0\0\0\x01\x14\0\0\x03\x23\
\0\x01\x6c\x2a\0\0\x01\xf8\0\0\x01\x14\0\0\x03\x23\0\x01\x6c\x06\0\0\x02\0\0\0\
\x01\x14\0\0\x04\x43\0\x01\x78\x11\0\0\x02\x28\0\0\x01\x14\0\0\x04\x43\0\x01\
\x78\x08\0\0\x02\x48\0\0\x01\x14\0\0\x04\x43\0\x01\x78\x06\0\0\x02\x60\0\0\x01\
\x14\0\0\x01\xe6\0\x01\x84\x01\0\0\x02\x70\0\0\x01\x14\0\0\x04\x72\0\x01\x90\0\
\0\0\x02\x78\0\0\x01\x14\0\0\x03\x03\0\x01\x98\x16\0\0\x02\x80\0\0\x01\x14\0\0\
\x03\x23\0\x01\xa0\x06\0\0\x02\x88\0\0\x01\x14\0\0\x03\x23\0\x01\xa0\x21\0\0\
\x02\x90\0\0\x01\x14\0\0\x03\x23\0\x01\xa0\x2a\0\0\x02\xb8\0\0\x01\x14\0\0\x03\
\x23\0\x01\xa0\x06\0\0\x02\xc0\0\0\x01\x14\0\0\x04\x93\0\x01\xac\x14\0\0\x02\
\xd8\0\0\x01\x14\0\0\x04\xab\0\x01\xb0\x0b\0\0\x02\xf8\0\0\x01\x14\0\0\x04\x93\
\0\x01\xac\x14\0\0\x03\0\0\0\x01\x14\0\0\x04\xab\0\x01\xb0\x02\0\0\x03\x20\0\0\
\x01\x14\0\0\x04\xdc\0\x01\xb8\x0b\0\0\x03\x30\0\0\x01\x14\0\0\x04\xdc\0\x01\
\xb8\x12\0\0\x03\x38\0\0\x01\x14\0\0\x04\xdc\0\x01\xb8\x0b\0\0\x03\x40\0\0\x01\
\x14\0\0\x01\xe6\0\x01\xc4\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\
\0\0\0\0\x01\x85\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\
\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\xc8\0\0\0\0\0\0\x02\
\x70\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\
\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x38\0\0\0\0\0\0\x01\x28\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x17\0\0\0\x01\0\0\0\0\0\0\
\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x05\x60\0\0\0\0\0\0\x03\x50\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x34\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x08\xb0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\x3c\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x08\xb4\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\
\0\0\0\0\0\0\x42\0\0\0\x08\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\
\xb8\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\
\x01\x4c\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\xb8\0\0\0\
\0\0\0\0\x60\0\0\0\x02\0\0\0\x03\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\
\x56\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\x18\0\0\0\0\0\
\0\x01\x30\0\0\0\x02\0\0\0\x04\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\x77\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x48\0\0\0\0\0\0\x07\
\x53\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x01\x7c\0\0\0\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\xa0\0\0\0\0\0\0\x04\x68\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct bpf_loop *bpf_loop::open(const struct bpf_object_open_opts *opts) { return bpf_loop__open_opts(opts); }
struct bpf_loop *bpf_loop::open_and_load() { return bpf_loop__open_and_load(); }
int bpf_loop::load(struct bpf_loop *skel) { return bpf_loop__load(skel); }
int bpf_loop::attach(struct bpf_loop *skel) { return bpf_loop__attach(skel); }
void bpf_loop::detach(struct bpf_loop *skel) { bpf_loop__detach(skel); }
void bpf_loop::destroy(struct bpf_loop *skel) { bpf_loop__destroy(skel); }
const void *bpf_loop::elf_bytes(size_t *sz) { return bpf_loop__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
bpf_loop__assert(struct bpf_loop *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->data->stop_index) == 4, "unexpected size of 'stop_index'");
	_Static_assert(sizeof(s->bss->pid) == 4, "unexpected size of 'pid'");
	_Static_assert(sizeof(s->bss->nr_loops) == 4, "unexpected size of 'nr_loops'");
	_Static_assert(sizeof(s->bss->nr_loops_returned) == 4, "unexpected size of 'nr_loops_returned'");
	_Static_assert(sizeof(s->bss->err) == 4, "unexpected size of 'err'");
	_Static_assert(sizeof(s->bss->g_output) == 4, "unexpected size of 'g_output'");
	_Static_assert(sizeof(s->bss->nested_callback_nr_loops) == 4, "unexpected size of 'nested_callback_nr_loops'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __BPF_LOOP_SKEL_H__ */
