/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __LINKED_FUNCS_SKEL_H__
#define __LINKED_FUNCS_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct linked_funcs {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *bss;
		struct bpf_map *rodata;
	} maps;
	struct {
		struct bpf_program *handler1;
		struct bpf_program *handler2;
	} progs;
	struct {
		struct bpf_link *handler1;
		struct bpf_link *handler2;
	} links;
	struct linked_funcs__bss {
		int output_val1;
		int output_ctx1;
		int output_weak1;
		char __pad0[4];
		long syscall_id;
		int output_val2;
		int output_ctx2;
		int output_weak2;
	} *bss;
	struct linked_funcs__rodata {
		int my_tid;
	} *rodata;

#ifdef __cplusplus
	static inline struct linked_funcs *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct linked_funcs *open_and_load();
	static inline int load(struct linked_funcs *skel);
	static inline int attach(struct linked_funcs *skel);
	static inline void detach(struct linked_funcs *skel);
	static inline void destroy(struct linked_funcs *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
linked_funcs__destroy(struct linked_funcs *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
linked_funcs__create_skeleton(struct linked_funcs *obj);

static inline struct linked_funcs *
linked_funcs__open_opts(const struct bpf_object_open_opts *opts)
{
	struct linked_funcs *obj;
	int err;

	obj = (struct linked_funcs *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = linked_funcs__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	linked_funcs__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct linked_funcs *
linked_funcs__open(void)
{
	return linked_funcs__open_opts(NULL);
}

static inline int
linked_funcs__load(struct linked_funcs *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct linked_funcs *
linked_funcs__open_and_load(void)
{
	struct linked_funcs *obj;
	int err;

	obj = linked_funcs__open();
	if (!obj)
		return NULL;
	err = linked_funcs__load(obj);
	if (err) {
		linked_funcs__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
linked_funcs__attach(struct linked_funcs *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
linked_funcs__detach(struct linked_funcs *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *linked_funcs__elf_bytes(size_t *sz);

static inline int
linked_funcs__create_skeleton(struct linked_funcs *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "linked_funcs";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 2;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "linked_f.bss";
	s->maps[0].map = &obj->maps.bss;
	s->maps[0].mmaped = (void **)&obj->bss;

	s->maps[1].name = "linked_f.rodata";
	s->maps[1].map = &obj->maps.rodata;
	s->maps[1].mmaped = (void **)&obj->rodata;

	/* programs */
	s->prog_cnt = 2;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "handler1";
	s->progs[0].prog = &obj->progs.handler1;
	s->progs[0].link = &obj->links.handler1;

	s->progs[1].name = "handler2";
	s->progs[1].prog = &obj->progs.handler2;
	s->progs[1].link = &obj->links.handler2;

	s->data = (void *)linked_funcs__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *linked_funcs__elf_bytes(size_t *sz)
{
	*sz = 5536;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x12\xa0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0c\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x74\x65\
\x78\x74\0\x72\x61\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\x72\0\
\x2e\x62\x73\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x6f\x64\x61\x74\x61\0\
\x6c\x69\x6e\x6b\x65\x64\x5f\x66\x75\x6e\x63\x73\x31\x2e\x63\0\x4c\x42\x42\x33\
\x5f\x33\0\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x31\0\x6f\
\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x31\0\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\
\x74\x5f\x63\x74\x78\x31\0\x6f\x75\x74\x70\x75\x74\x5f\x63\x74\x78\x31\0\x73\
\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x77\x65\x61\x6b\0\x6f\x75\x74\x70\x75\
\x74\x5f\x77\x65\x61\x6b\x31\0\x68\x61\x6e\x64\x6c\x65\x72\x31\0\x6d\x79\x5f\
\x74\x69\x64\0\x73\x79\x73\x63\x61\x6c\x6c\x5f\x69\x64\0\x73\x65\x74\x5f\x6f\
\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x32\0\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\
\x74\x5f\x63\x74\x78\x32\0\x4c\x49\x43\x45\x4e\x53\x45\0\x6c\x69\x6e\x6b\x65\
\x64\x5f\x66\x75\x6e\x63\x73\x32\x2e\x63\0\x73\x75\x62\x70\x72\x6f\x67\0\x4c\
\x42\x42\x34\x5f\x33\0\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x32\0\x6f\x75\
\x74\x70\x75\x74\x5f\x63\x74\x78\x32\0\x6f\x75\x74\x70\x75\x74\x5f\x77\x65\x61\
\x6b\x32\0\x68\x61\x6e\x64\x6c\x65\x72\x32\0\x2e\x72\x65\x6c\x2e\x74\x65\x78\
\x74\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\
\x65\x72\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3d\x04\0\xff\xf1\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\
\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x4d\0\0\0\x04\0\0\0\0\0\0\0\x88\
\0\0\0\0\0\0\0\0\0\0\0\x54\x12\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\0\
\x64\x11\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\x70\x12\x02\0\x03\0\0\
\0\0\0\0\0\x30\0\0\0\0\0\0\0\x28\0\0\0\x80\x11\0\0\x05\0\0\0\0\0\0\0\x04\0\0\0\
\0\0\0\0\x04\0\0\0\x8c\x22\0\0\x03\0\0\0\0\0\0\0\x58\0\0\0\0\0\0\0\x28\0\0\0\
\x9c\x11\0\0\x05\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x04\0\0\0\xa9\x12\0\0\x04\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x98\0\0\0\xb2\x21\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x04\0\0\0\xb9\x21\0\0\x05\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x08\0\0\0\xc4\
\x12\0\0\x03\0\0\0\0\0\0\0\x80\0\0\0\0\0\0\0\x50\0\0\0\xd4\x12\x02\0\x03\0\0\0\
\0\0\0\0\xe8\0\0\0\0\0\0\0\x28\0\0\0\xe4\x11\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x04\0\0\0\xec\x04\0\xff\xf1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xfc\x02\
\0\0\x03\0\0\0\0\0\0\0\xd0\0\0\0\0\0\0\0\x18\0\0\x01\x04\0\0\0\x04\0\0\0\0\0\0\
\x01\x20\0\0\0\0\0\0\0\0\0\0\x01\x0b\x11\0\0\x05\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\
\0\x04\0\0\x01\x17\x11\0\0\x05\0\0\0\0\0\0\0\x1c\0\0\0\0\0\0\0\x04\0\0\x01\x23\
\x11\0\0\x05\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x04\0\0\x01\x30\x12\0\0\x04\0\0\0\
\0\0\0\0\x98\0\0\0\0\0\0\0\x98\xbc\x01\0\0\0\0\0\0\x64\x10\0\0\0\0\0\x01\x18\
\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x21\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x11\
\0\x08\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x21\0\0\0\0\0\0\x95\0\0\
\0\0\0\0\0\xbc\x01\0\0\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x10\0\0\
\0\0\0\0\x95\0\0\0\0\0\0\0\xbc\x61\0\0\0\0\0\0\x85\x01\0\0\0\0\0\x08\x0c\x06\0\
\0\0\0\0\0\x64\0\0\0\0\0\0\x01\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x10\0\0\
\0\0\0\0\x64\x60\0\0\0\0\0\x01\xbc\x06\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xbc\x01\0\
\0\0\0\0\0\x64\0\0\0\0\0\0\x01\x95\0\0\0\0\0\0\0\x79\x11\0\x08\0\0\0\0\x18\x20\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x21\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xbc\x01\0\0\
\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x10\0\0\0\0\0\0\x64\0\0\0\0\0\
\0\x01\x95\0\0\0\0\0\0\0\xbf\x61\0\0\0\0\0\0\x79\x76\0\x08\0\0\0\0\x18\x10\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x61\x81\0\0\0\0\0\0\x85\0\0\0\0\0\0\x0e\x5e\x80\0\x0a\
\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x11\0\0\0\0\0\0\x5d\x17\0\x06\
\0\0\0\0\xb4\x10\0\0\0\0\x03\xe8\x85\x01\0\0\xff\xff\xff\xff\xbf\x16\0\0\0\0\0\
\0\x85\x01\0\0\xff\xff\xff\xff\xb4\x10\0\0\0\0\0\x2a\x85\x01\0\0\xff\xff\xff\
\xff\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xbf\x61\0\0\0\0\0\0\x79\x76\0\x08\0\0\
\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x81\0\0\0\0\0\0\x85\0\0\0\0\0\0\
\x0e\x5e\x80\0\x0a\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x11\0\0\0\0\
\0\0\x5d\x17\0\x06\0\0\0\0\xb4\x10\0\0\0\0\x07\xd0\x85\x01\0\0\xff\xff\xff\xff\
\xbf\x16\0\0\0\0\0\0\x85\x01\0\0\xff\xff\xff\xff\xb4\x10\0\0\0\0\0\x2a\x85\x01\
\0\0\xff\xff\xff\xff\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x10\0\0\0\x06\0\0\0\x01\0\0\0\0\0\0\0\x38\0\0\0\
\x08\0\0\0\x01\0\0\0\0\0\0\0\x60\0\0\0\x0a\0\0\0\x01\0\0\0\0\0\0\0\xa0\0\0\0\
\x14\0\0\0\x01\0\0\0\0\0\0\0\xf0\0\0\0\x15\0\0\0\x01\0\0\0\0\0\0\x01\x18\0\0\0\
\x16\0\0\0\x01\0\0\0\0\0\0\0\x10\0\0\0\x0c\0\0\0\x01\0\0\0\0\0\0\0\x38\0\0\0\
\x0d\0\0\0\x01\0\0\0\0\0\0\0\x60\0\0\0\x0e\0\0\0\x0a\0\0\0\0\0\0\0\x70\0\0\0\
\x0f\0\0\0\x0a\0\0\0\0\0\0\0\x80\0\0\0\x09\0\0\0\x0a\0\0\0\0\0\0\0\xa8\0\0\0\
\x0c\0\0\0\x01\0\0\0\0\0\0\0\xd0\0\0\0\x0d\0\0\0\x01\0\0\0\0\0\0\0\xf8\0\0\0\
\x05\0\0\0\x0a\0\0\0\0\0\0\x01\x08\0\0\0\x07\0\0\0\x0a\0\0\0\0\0\0\x01\x18\0\0\
\0\x09\0\0\0\x0a\xeb\x9f\x01\0\0\0\0\x18\0\0\0\0\0\0\x02\x88\0\0\x02\x88\0\0\
\x05\x48\0\0\0\x01\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\0\x0d\0\0\x01\0\0\0\
\x01\0\0\0\x05\0\0\0\x01\0\0\0\x07\x0c\0\0\x01\0\0\0\x02\0\0\0\0\x02\0\0\0\0\0\
\0\x05\0\0\0\x17\x08\0\0\0\0\0\0\x06\0\0\0\x1d\x01\0\0\0\0\0\0\x08\0\0\0\x40\0\
\0\0\0\x0d\0\0\x01\0\0\0\0\0\0\0\x30\0\0\0\x04\0\0\0\x34\x0c\0\0\x01\0\0\0\x07\
\0\0\0\x44\x0c\0\0\x01\0\0\0\x02\0\0\0\0\x02\0\0\0\0\0\0\x06\0\0\0\0\x0d\0\0\
\x01\0\0\0\x01\0\0\0\x30\0\0\0\x0a\0\0\0\x54\x0c\0\0\x01\0\0\0\x0b\0\0\0\x5d\
\x0c\0\0\x01\0\0\0\x02\0\0\0\x6d\x0c\0\0\x01\0\0\0\x07\0\0\0\x7d\x0e\0\0\0\0\0\
\0\x01\0\0\0\x01\0\0\0\x89\x0e\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\x95\x0e\0\0\0\0\
\0\0\x01\0\0\0\x01\0\0\0\xa2\x01\0\0\0\0\0\0\x01\x01\0\0\x08\0\0\0\0\x03\0\0\0\
\0\0\0\0\0\0\0\x12\0\0\0\x14\0\0\0\x04\0\0\0\xa7\x01\0\0\0\0\0\0\x04\0\0\0\x20\
\0\0\0\xbb\x0e\0\0\0\0\0\0\x13\0\0\0\x01\0\0\0\0\x0a\0\0\0\0\0\0\x17\0\0\0\0\
\x09\0\0\0\0\0\0\x01\0\0\0\xc3\x0e\0\0\0\0\0\0\x16\0\0\0\x01\0\0\0\xca\x01\0\0\
\0\0\0\0\x08\x01\0\0\x40\0\0\0\xcf\x0e\0\0\0\0\0\0\x19\0\0\0\x01\0\0\0\xda\x0c\
\0\0\0\0\0\0\x02\0\0\0\xe2\x0c\0\0\x01\0\0\0\x0b\0\0\0\0\x0d\0\0\x01\0\0\0\x01\
\0\0\0\0\0\0\0\x01\0\0\0\0\x0d\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xeb\x0e\
\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\xf7\x0e\0\0\0\0\0\0\x01\0\0\0\x01\0\0\x01\x03\
\x0e\0\0\0\0\0\0\x01\0\0\0\x01\0\0\x05\x1c\x0f\0\0\x07\0\0\0\x30\0\0\0\x0f\0\0\
\0\0\0\0\0\x04\0\0\0\x10\0\0\0\x04\0\0\0\x04\0\0\0\x11\0\0\0\x08\0\0\0\x04\0\0\
\0\x1a\0\0\0\x10\0\0\0\x08\0\0\0\x1f\0\0\0\x18\0\0\0\x04\0\0\0\x20\0\0\0\x1c\0\
\0\0\x04\0\0\0\x21\0\0\0\x20\0\0\0\x04\0\0\x05\x21\x0f\0\0\x01\0\0\0\x04\0\0\0\
\x15\0\0\0\0\0\0\0\x04\0\0\x05\x29\x0f\0\0\x01\0\0\0\x08\0\0\0\x18\0\0\0\0\0\0\
\0\x04\0\x69\x6e\x74\0\x78\0\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x76\
\x61\x6c\x31\0\x5f\x5f\x75\x36\x34\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\
\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x63\x74\x78\0\x73\x65\x74\x5f\x6f\x75\x74\
\x70\x75\x74\x5f\x63\x74\x78\x31\0\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\
\x77\x65\x61\x6b\0\x68\x61\x6e\x64\x6c\x65\x72\x31\0\x73\x65\x74\x5f\x6f\x75\
\x74\x70\x75\x74\x5f\x76\x61\x6c\x32\0\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\
\x5f\x63\x74\x78\x32\0\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x31\0\x6f\x75\
\x74\x70\x75\x74\x5f\x63\x74\x78\x31\0\x6f\x75\x74\x70\x75\x74\x5f\x77\x65\x61\
\x6b\x31\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\
\x5f\x54\x59\x50\x45\x5f\x5f\0\x4c\x49\x43\x45\x4e\x53\x45\0\x6d\x79\x5f\x74\
\x69\x64\0\x6c\x6f\x6e\x67\0\x73\x79\x73\x63\x61\x6c\x6c\x5f\x69\x64\0\x73\x75\
\x62\x70\x72\x6f\x67\0\x68\x61\x6e\x64\x6c\x65\x72\x32\0\x6f\x75\x74\x70\x75\
\x74\x5f\x76\x61\x6c\x32\0\x6f\x75\x74\x70\x75\x74\x5f\x63\x74\x78\x32\0\x6f\
\x75\x74\x70\x75\x74\x5f\x77\x65\x61\x6b\x32\0\x2f\x62\x75\x69\x6c\x64\x64\x69\
\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\
\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\x69\
\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2e\
\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\
\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\
\x73\x2f\x6c\x69\x6e\x6b\x65\x64\x5f\x66\x75\x6e\x63\x73\x31\x2e\x63\0\x69\x6e\
\x74\x20\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x31\x28\x69\
\x6e\x74\x20\x78\x29\0\x09\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x31\x20\x3d\
\x20\x78\x20\x2b\x20\x73\x75\x62\x70\x72\x6f\x67\x28\x78\x29\x3b\0\x09\x72\x65\
\x74\x75\x72\x6e\x20\x78\x3b\0\x09\x6f\x75\x74\x70\x75\x74\x5f\x63\x74\x78\x31\
\x20\x3d\x20\x63\x74\x78\x5b\x31\x5d\x3b\x20\x2f\x2a\x20\x6c\x6f\x6e\x67\x20\
\x69\x64\x2c\x20\x73\x61\x6d\x65\x20\x61\x73\x20\x69\x6e\x20\x42\x50\x46\x5f\
\x50\x52\x4f\x47\x20\x62\x65\x6c\x6f\x77\x20\x2a\x2f\0\x7d\0\x5f\x5f\x77\x65\
\x61\x6b\x20\x69\x6e\x74\x20\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x77\
\x65\x61\x6b\x28\x69\x6e\x74\x20\x78\x29\0\x09\x6f\x75\x74\x70\x75\x74\x5f\x77\
\x65\x61\x6b\x31\x20\x3d\x20\x78\x3b\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\
\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\
\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\
\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2e\x73\x33\
\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\
\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\
\x6c\x69\x6e\x6b\x65\x64\x5f\x66\x75\x6e\x63\x73\x32\x2e\x63\0\x69\x6e\x74\x20\
\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x32\x28\x69\x6e\x74\
\x20\x78\x29\0\x09\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x32\x20\x3d\x20\x32\
\x20\x2a\x20\x78\x20\x2b\x20\x32\x20\x2a\x20\x73\x75\x62\x70\x72\x6f\x67\x28\
\x78\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x32\x20\x2a\x20\x78\x3b\0\x73\
\x74\x61\x74\x69\x63\x20\x5f\x5f\x6e\x6f\x69\x6e\x6c\x69\x6e\x65\x20\x69\x6e\
\x74\x20\x73\x75\x62\x70\x72\x6f\x67\x28\x69\x6e\x74\x20\x78\x29\0\x09\x72\x65\
\x74\x75\x72\x6e\x20\x78\x20\x2a\x20\x32\x3b\0\x09\x6f\x75\x74\x70\x75\x74\x5f\
\x63\x74\x78\x32\x20\x3d\x20\x63\x74\x78\x5b\x31\x5d\x3b\x20\x2f\x2a\x20\x6c\
\x6f\x6e\x67\x20\x69\x64\x2c\x20\x73\x61\x6d\x65\x20\x61\x73\x20\x69\x6e\x20\
\x42\x50\x46\x5f\x50\x52\x4f\x47\x20\x62\x65\x6c\x6f\x77\x20\x2a\x2f\0\x09\x6f\
\x75\x74\x70\x75\x74\x5f\x77\x65\x61\x6b\x32\x20\x3d\x20\x78\x3b\0\x69\x6e\x74\
\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\x72\x31\x2c\
\x20\x73\x74\x72\x75\x63\x74\x20\x70\x74\x5f\x72\x65\x67\x73\x20\x2a\x72\x65\
\x67\x73\x2c\x20\x6c\x6f\x6e\x67\x20\x69\x64\x29\0\x09\x69\x66\x20\x28\x6d\x79\
\x5f\x74\x69\x64\x20\x21\x3d\x20\x28\x75\x33\x32\x29\x62\x70\x66\x5f\x67\x65\
\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x70\x69\x64\x5f\x74\x67\x69\x64\x28\
\x29\x20\x7c\x7c\x20\x69\x64\x20\x21\x3d\x20\x73\x79\x73\x63\x61\x6c\x6c\x5f\
\x69\x64\x29\0\x09\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x32\
\x28\x31\x30\x30\x30\x29\x3b\0\x09\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\
\x63\x74\x78\x32\x28\x63\x74\x78\x29\x3b\x20\x2f\x2a\x20\x63\x74\x78\x20\x64\
\x65\x66\x69\x6e\x69\x74\x69\x6f\x6e\x20\x69\x73\x20\x68\x69\x64\x64\x65\x6e\
\x20\x69\x6e\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x20\x6d\x61\x63\x72\x6f\x20\
\x2a\x2f\0\x09\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x77\x65\x61\x6b\x28\
\x34\x32\x29\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\
\x6e\x64\x6c\x65\x72\x32\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x70\x74\x5f\x72\
\x65\x67\x73\x20\x2a\x72\x65\x67\x73\x2c\x20\x6c\x6f\x6e\x67\x20\x69\x64\x29\0\
\x09\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x76\x61\x6c\x31\x28\x32\x30\
\x30\x30\x29\x3b\0\x09\x73\x65\x74\x5f\x6f\x75\x74\x70\x75\x74\x5f\x63\x74\x78\
\x31\x28\x63\x74\x78\x29\x3b\x20\x2f\x2a\x20\x63\x74\x78\x20\x64\x65\x66\x69\
\x6e\x69\x74\x69\x6f\x6e\x20\x69\x73\x20\x68\x69\x64\x64\x65\x6e\x20\x69\x6e\
\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x20\x6d\x61\x63\x72\x6f\x20\x2a\x2f\0\x2e\
\x62\x73\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x6f\x64\x61\x74\x61\0\x2e\
\x74\x65\x78\x74\0\x72\x61\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\
\x72\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x5c\0\0\0\x5c\0\0\x02\xd4\0\0\x03\
\x30\0\0\0\0\0\0\0\x08\0\0\x05\x31\0\0\0\x07\0\0\0\0\0\0\0\x03\0\0\0\x30\0\0\0\
\x08\0\0\0\x58\0\0\0\x09\0\0\0\x80\0\0\0\x0d\0\0\0\xd0\0\0\0\x1b\0\0\0\xe8\0\0\
\0\x0e\0\0\x01\x10\0\0\0\x09\0\0\x05\x37\0\0\0\x02\0\0\0\0\0\0\0\x0c\0\0\0\x98\
\0\0\0\x1c\0\0\0\x10\0\0\x05\x31\0\0\0\x1a\0\0\0\0\0\0\x01\x10\0\0\x01\x89\0\0\
\x60\0\0\0\0\x08\0\0\x01\x10\0\0\x01\xa4\0\0\x68\x12\0\0\0\x10\0\0\x01\x10\0\0\
\x01\xa4\0\0\x68\x0e\0\0\0\x28\0\0\x01\x10\0\0\x01\xc3\0\0\x6c\x02\0\0\0\x30\0\
\0\x01\x10\0\0\x01\xce\0\0\xa4\x10\0\0\0\x38\0\0\x01\x10\0\0\x01\xce\0\0\xa4\
\x0e\0\0\0\x50\0\0\x01\x10\0\0\x02\x0e\0\0\xa8\x01\0\0\0\x58\0\0\x01\x10\0\0\
\x02\x10\0\0\xb4\0\0\0\0\x60\0\0\x01\x10\0\0\x02\x32\0\0\xbc\x0f\0\0\0\x78\0\0\
\x01\x10\0\0\x01\xc3\0\0\xc0\x02\0\0\0\x80\0\0\x02\x45\0\0\x02\xbe\0\0\x60\0\0\
\0\0\x88\0\0\x02\x45\0\0\x02\xd9\0\0\x68\x1c\0\0\0\x90\0\0\x02\x45\0\0\x02\xd9\
\0\0\x68\x16\0\0\0\xa0\0\0\x02\x45\0\0\x02\xd9\0\0\x68\x0e\0\0\0\xb8\0\0\x02\
\x45\0\0\x02\xd9\0\0\x68\x12\0\0\0\xc0\0\0\x02\x45\0\0\x03\0\0\0\x6c\x02\0\0\0\
\xd0\0\0\x02\x45\0\0\x03\x0f\0\0\x44\0\0\0\0\xd8\0\0\x02\x45\0\0\x03\x34\0\0\
\x50\x0b\0\0\0\xe0\0\0\x02\x45\0\0\x03\x34\0\0\x50\x02\0\0\0\xe8\0\0\x02\x45\0\
\0\x03\x43\0\0\xa4\x10\0\0\0\xf0\0\0\x02\x45\0\0\x03\x43\0\0\xa4\x0e\0\0\x01\
\x08\0\0\x02\x45\0\0\x02\x0e\0\0\xa8\x01\0\0\x01\x10\0\0\x02\x45\0\0\x02\x10\0\
\0\xb4\0\0\0\x01\x18\0\0\x02\x45\0\0\x03\x83\0\0\xbc\x0f\0\0\x01\x30\0\0\x02\
\x45\0\0\x03\0\0\0\xc0\x0b\0\0\x01\x38\0\0\x02\x45\0\0\x03\0\0\0\xc0\x02\0\0\
\x05\x37\0\0\0\x12\0\0\0\0\0\0\x01\x10\0\0\x03\x96\0\0\xe4\0\0\0\0\x08\0\0\x01\
\x10\0\0\x03\x96\0\0\xe4\x05\0\0\0\x10\0\0\x01\x10\0\0\x03\xcc\0\0\xec\x06\0\0\
\0\x28\0\0\x01\x10\0\0\x03\xcc\0\0\xec\x15\0\0\0\x30\0\0\x01\x10\0\0\x03\xcc\0\
\0\xec\x30\0\0\0\x58\0\0\x01\x10\0\0\x04\x10\0\0\xf8\x02\0\0\0\x68\0\0\x01\x10\
\0\0\x04\x28\0\0\xfc\x02\0\0\0\x78\0\0\x01\x10\0\0\x04\x70\0\x01\x10\x02\0\0\0\
\x88\0\0\x01\x10\0\0\x03\x96\0\0\xe4\x05\0\0\0\x98\0\0\x02\x45\0\0\x04\x86\0\0\
\xe4\0\0\0\0\xa0\0\0\x02\x45\0\0\x04\x86\0\0\xe4\x05\0\0\0\xa8\0\0\x02\x45\0\0\
\x03\xcc\0\0\xec\x06\0\0\0\xc0\0\0\x02\x45\0\0\x03\xcc\0\0\xec\x15\0\0\0\xc8\0\
\0\x02\x45\0\0\x03\xcc\0\0\xec\x30\0\0\0\xf0\0\0\x02\x45\0\0\x04\xbc\0\0\xf8\
\x02\0\0\x01\0\0\0\x02\x45\0\0\x04\xd4\0\0\xfc\x02\0\0\x01\x10\0\0\x02\x45\0\0\
\x04\x70\0\x01\x10\x02\0\0\x01\x20\0\0\x02\x45\0\0\x04\x86\0\0\xe4\x05\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\
\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\x01\x66\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x01\xa8\0\0\0\0\0\0\x02\x40\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x03\xe8\0\0\0\0\0\0\x01\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\
\0\0\0\0\0\0\0\0\x17\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x05\x28\0\0\0\0\0\0\x01\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\
\0\0\0\x28\0\0\0\x08\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x06\x58\0\0\
\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x2d\0\0\
\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x06\x58\0\0\0\0\0\0\0\x04\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x35\0\0\0\x01\0\0\0\0\
\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x06\x5c\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\x01\x39\0\0\0\x09\0\0\0\0\0\0\0\x40\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x06\x68\0\0\0\0\0\0\0\x60\0\0\0\x02\0\0\0\x03\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\x43\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x06\xc8\0\0\0\0\0\0\0\xa0\0\0\0\x02\0\0\0\x04\0\0\0\0\0\0\
\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\x58\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x07\x68\0\0\0\0\0\0\x07\xe8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0\0\0\x01\x5d\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x0f\x50\0\0\0\0\0\0\x03\x50\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct linked_funcs *linked_funcs::open(const struct bpf_object_open_opts *opts) { return linked_funcs__open_opts(opts); }
struct linked_funcs *linked_funcs::open_and_load() { return linked_funcs__open_and_load(); }
int linked_funcs::load(struct linked_funcs *skel) { return linked_funcs__load(skel); }
int linked_funcs::attach(struct linked_funcs *skel) { return linked_funcs__attach(skel); }
void linked_funcs::detach(struct linked_funcs *skel) { linked_funcs__detach(skel); }
void linked_funcs::destroy(struct linked_funcs *skel) { linked_funcs__destroy(skel); }
const void *linked_funcs::elf_bytes(size_t *sz) { return linked_funcs__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
linked_funcs__assert(struct linked_funcs *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->output_val1) == 4, "unexpected size of 'output_val1'");
	_Static_assert(sizeof(s->bss->output_ctx1) == 4, "unexpected size of 'output_ctx1'");
	_Static_assert(sizeof(s->bss->output_weak1) == 4, "unexpected size of 'output_weak1'");
	_Static_assert(sizeof(s->bss->syscall_id) == 8, "unexpected size of 'syscall_id'");
	_Static_assert(sizeof(s->bss->output_val2) == 4, "unexpected size of 'output_val2'");
	_Static_assert(sizeof(s->bss->output_ctx2) == 4, "unexpected size of 'output_ctx2'");
	_Static_assert(sizeof(s->bss->output_weak2) == 4, "unexpected size of 'output_weak2'");
	_Static_assert(sizeof(s->rodata->my_tid) == 4, "unexpected size of 'my_tid'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __LINKED_FUNCS_SKEL_H__ */
