/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __IMA_SKEL_H__
#define __IMA_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct ima {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *ringbuf;
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *bprm_committed_creds;
		struct bpf_program *bprm_creds_for_exec;
		struct bpf_program *kernel_read_file;
	} progs;
	struct {
		struct bpf_link *bprm_committed_creds;
		struct bpf_link *bprm_creds_for_exec;
		struct bpf_link *kernel_read_file;
	} links;
	struct ima__bss {
		u32 monitored_pid;
		bool use_ima_file_hash;
		bool enable_bprm_creds_for_exec;
		bool enable_kernel_read_file;
		bool test_deny;
	} *bss;

#ifdef __cplusplus
	static inline struct ima *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct ima *open_and_load();
	static inline int load(struct ima *skel);
	static inline int attach(struct ima *skel);
	static inline void detach(struct ima *skel);
	static inline void destroy(struct ima *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
ima__destroy(struct ima *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
ima__create_skeleton(struct ima *obj);

static inline struct ima *
ima__open_opts(const struct bpf_object_open_opts *opts)
{
	struct ima *obj;
	int err;

	obj = (struct ima *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = ima__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	ima__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct ima *
ima__open(void)
{
	return ima__open_opts(NULL);
}

static inline int
ima__load(struct ima *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct ima *
ima__open_and_load(void)
{
	struct ima *obj;
	int err;

	obj = ima__open();
	if (!obj)
		return NULL;
	err = ima__load(obj);
	if (err) {
		ima__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
ima__attach(struct ima *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
ima__detach(struct ima *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *ima__elf_bytes(size_t *sz);

static inline int
ima__create_skeleton(struct ima *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "ima";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 2;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "ringbuf";
	s->maps[0].map = &obj->maps.ringbuf;

	s->maps[1].name = "ima.bss";
	s->maps[1].map = &obj->maps.bss;
	s->maps[1].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 3;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "bprm_committed_creds";
	s->progs[0].prog = &obj->progs.bprm_committed_creds;
	s->progs[0].link = &obj->links.bprm_committed_creds;

	s->progs[1].name = "bprm_creds_for_exec";
	s->progs[1].prog = &obj->progs.bprm_creds_for_exec;
	s->progs[1].link = &obj->links.bprm_creds_for_exec;

	s->progs[2].name = "kernel_read_file";
	s->progs[2].prog = &obj->progs.kernel_read_file;
	s->progs[2].link = &obj->links.kernel_read_file;

	s->data = (void *)ima__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *ima__elf_bytes(size_t *sz)
{
	*sz = 9776;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\xb0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0e\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x6c\x73\x6d\
\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\
\x72\x65\x64\x73\0\x6c\x73\x6d\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\x72\x65\x64\
\x73\x5f\x66\x6f\x72\x5f\x65\x78\x65\x63\0\x6c\x73\x6d\x2e\x73\x2f\x6b\x65\x72\
\x6e\x65\x6c\x5f\x72\x65\x61\x64\x5f\x66\x69\x6c\x65\0\x2e\x62\x73\x73\0\x6c\
\x69\x63\x65\x6e\x73\x65\0\x2e\x6d\x61\x70\x73\0\x69\x6d\x61\x2e\x63\0\x4c\x42\
\x42\x30\x5f\x38\0\x4c\x42\x42\x30\x5f\x33\0\x4c\x42\x42\x30\x5f\x34\0\x4c\x42\
\x42\x31\x5f\x39\0\x4c\x42\x42\x31\x5f\x34\0\x4c\x42\x42\x31\x5f\x35\0\x4c\x42\
\x42\x32\x5f\x31\x33\0\x4c\x42\x42\x32\x5f\x35\0\x4c\x42\x42\x32\x5f\x38\0\x4c\
\x42\x42\x32\x5f\x39\0\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\
\x5f\x63\x72\x65\x64\x73\0\x6d\x6f\x6e\x69\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\
\0\x75\x73\x65\x5f\x69\x6d\x61\x5f\x66\x69\x6c\x65\x5f\x68\x61\x73\x68\0\x72\
\x69\x6e\x67\x62\x75\x66\0\x62\x70\x72\x6d\x5f\x63\x72\x65\x64\x73\x5f\x66\x6f\
\x72\x5f\x65\x78\x65\x63\0\x65\x6e\x61\x62\x6c\x65\x5f\x62\x70\x72\x6d\x5f\x63\
\x72\x65\x64\x73\x5f\x66\x6f\x72\x5f\x65\x78\x65\x63\0\x6b\x65\x72\x6e\x65\x6c\
\x5f\x72\x65\x61\x64\x5f\x66\x69\x6c\x65\0\x65\x6e\x61\x62\x6c\x65\x5f\x6b\x65\
\x72\x6e\x65\x6c\x5f\x72\x65\x61\x64\x5f\x66\x69\x6c\x65\0\x74\x65\x73\x74\x5f\
\x64\x65\x6e\x79\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x6c\x73\
\x6d\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\
\x63\x72\x65\x64\x73\0\x2e\x72\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\x62\x70\x72\x6d\
\x5f\x63\x72\x65\x64\x73\x5f\x66\x6f\x72\x5f\x65\x78\x65\x63\0\x2e\x72\x65\x6c\
\x6c\x73\x6d\x2e\x73\x2f\x6b\x65\x72\x6e\x65\x6c\x5f\x72\x65\x61\x64\x5f\x66\
\x69\x6c\x65\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\x04\0\xff\xf1\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x76\0\0\0\x03\0\0\0\0\0\0\x01\x50\0\0\0\0\0\0\0\0\0\0\0\x7d\0\0\0\x03\0\0\
\0\0\0\0\0\xa0\0\0\0\0\0\0\0\0\0\0\0\x84\0\0\0\x03\0\0\0\0\0\0\0\xc8\0\0\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x8b\0\0\0\x04\
\0\0\0\0\0\0\x01\x70\0\0\0\0\0\0\0\0\0\0\0\x92\0\0\0\x04\0\0\0\0\0\0\0\xc0\0\0\
\0\0\0\0\0\0\0\0\0\x99\0\0\0\x04\0\0\0\0\0\0\0\xe8\0\0\0\0\0\0\0\0\0\0\0\0\x03\
\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\0\0\0\x05\0\0\0\0\0\0\x01\
\xf0\0\0\0\0\0\0\0\0\0\0\0\xa8\0\0\0\x05\0\0\0\0\0\0\0\xc0\0\0\0\0\0\0\0\0\0\0\
\0\xaf\0\0\0\x05\0\0\0\0\0\0\x01\x40\0\0\0\0\0\0\0\0\0\0\0\xb6\0\0\0\x05\0\0\0\
\0\0\0\x01\x68\0\0\0\0\0\0\0\0\0\0\0\xbd\x12\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x01\x58\0\0\0\xd2\x11\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xe0\
\x11\0\0\x06\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x01\0\0\0\xf2\x11\0\0\x08\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x10\0\0\0\xfa\x12\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x01\x80\0\0\x01\x0e\x11\0\0\x06\0\0\0\0\0\0\0\x05\0\0\0\0\0\0\0\x01\0\0\x01\
\x29\x12\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x01\x3a\x11\0\0\x06\0\0\
\0\0\0\0\0\x06\0\0\0\0\0\0\0\x01\0\0\x01\x52\x11\0\0\x06\0\0\0\0\0\0\0\x07\0\0\
\0\0\0\0\0\x01\0\0\x01\x5c\x11\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x79\
\x11\0\0\0\0\0\0\x79\x61\0\x40\0\0\0\0\xb7\x10\0\0\0\0\0\0\x7b\xa1\xff\xf8\0\0\
\0\0\x85\0\0\0\0\0\0\x0e\x77\0\0\0\0\0\0\x20\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x61\x11\0\0\0\0\0\0\x5d\x10\0\x20\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x71\x11\0\0\0\0\0\0\x55\x10\0\x06\0\0\0\0\x79\x16\0\x20\0\0\0\0\xbf\x2a\0\0\
\0\0\0\0\x07\x20\0\0\xff\xff\xff\xf8\xb7\x30\0\0\0\0\0\x08\x85\0\0\0\0\0\0\xa1\
\x05\0\0\x05\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xf8\xbf\x16\0\
\0\0\0\0\0\xb7\x30\0\0\0\0\0\x08\x85\0\0\0\0\0\0\xc1\x18\x10\0\0\x80\0\0\0\0\0\
\0\0\0\0\0\0\x5f\x01\0\0\0\0\0\0\x55\0\0\x0d\0\0\0\0\x79\x1a\xff\xf8\0\0\0\0\
\x15\x10\0\x0b\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\
\x08\xb7\x30\0\0\0\0\0\0\x85\0\0\0\0\0\0\x83\x15\0\0\x05\0\0\0\0\x79\x1a\xff\
\xf8\0\0\0\0\x7b\x01\0\0\0\0\0\0\xbf\x10\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\0\x85\0\
\0\0\0\0\0\x84\x95\0\0\0\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x22\0\
\0\0\0\0\0\x15\x20\0\x2a\0\0\0\0\x79\x11\0\0\0\0\0\0\x79\x61\0\x40\0\0\0\0\xb7\
\x10\0\0\0\0\0\0\x7b\xa1\xff\xf8\0\0\0\0\x85\0\0\0\0\0\0\x0e\x77\0\0\0\0\0\0\
\x20\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x5d\x10\0\x20\0\0\
\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x11\0\0\0\0\0\0\x55\x10\0\x06\0\0\
\0\0\x79\x16\0\x20\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xf8\xb7\
\x30\0\0\0\0\0\x08\x85\0\0\0\0\0\0\xa1\x05\0\0\x05\0\0\0\0\xbf\x2a\0\0\0\0\0\0\
\x07\x20\0\0\xff\xff\xff\xf8\xbf\x16\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\x08\x85\0\0\
\0\0\0\0\xc1\x18\x10\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\x5f\x01\0\0\0\0\0\0\x55\0\0\
\x0d\0\0\0\0\x79\x1a\xff\xf8\0\0\0\0\x15\x10\0\x0b\0\0\0\0\x18\x10\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x08\xb7\x30\0\0\0\0\0\0\x85\0\0\0\0\0\0\x83\
\x15\0\0\x05\0\0\0\0\x79\x1a\xff\xf8\0\0\0\0\x7b\x01\0\0\0\0\0\0\xbf\x10\0\0\0\
\0\0\0\xb7\x20\0\0\0\0\0\0\x85\0\0\0\0\0\0\x84\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\
\0\0\xb7\x60\0\0\0\0\0\0\x79\x21\0\x08\0\0\0\0\x67\x20\0\0\0\0\0\x20\x77\x20\0\
\0\0\0\0\x20\x55\x20\0\x39\0\0\0\x05\x79\x21\0\x10\0\0\0\0\x15\x20\0\x37\0\0\0\
\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x22\0\0\0\0\0\0\x15\x20\0\x33\0\0\0\
\0\x79\x71\0\0\0\0\0\0\x85\0\0\0\0\0\0\x0e\x77\0\0\0\0\0\0\x20\x18\x80\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x61\x18\0\0\0\0\0\0\x5d\x10\0\x06\0\0\0\0\x18\x60\0\0\xff\
\xff\xff\xff\0\0\0\0\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x11\0\0\0\
\0\0\0\x55\x10\0\x26\0\0\0\0\xb7\x60\0\0\0\0\0\0\x7b\xa6\xff\xf8\0\0\0\0\x85\0\
\0\0\0\0\0\x0e\x77\0\0\0\0\0\0\x20\x61\x18\0\0\0\0\0\0\x5d\x10\0\x20\0\0\0\0\
\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x11\0\0\0\0\0\0\x55\x10\0\x06\0\0\0\0\
\x79\x17\0\x20\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xf8\xb7\x30\
\0\0\0\0\0\x08\x85\0\0\0\0\0\0\xa1\x05\0\0\x05\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\
\x20\0\0\xff\xff\xff\xf8\xbf\x17\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\x08\x85\0\0\0\0\
\0\0\xc1\x18\x10\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\x5f\x01\0\0\0\0\0\0\x55\0\0\x0d\
\0\0\0\0\x79\x1a\xff\xf8\0\0\0\0\x15\x10\0\x0b\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x08\xb7\x30\0\0\0\0\0\0\x85\0\0\0\0\0\0\x83\x15\
\0\0\x05\0\0\0\0\x79\x1a\xff\xf8\0\0\0\0\x7b\x01\0\0\0\0\0\0\xbf\x10\0\0\0\0\0\
\0\xb7\x20\0\0\0\0\0\0\x85\0\0\0\0\0\0\x84\xbf\x06\0\0\0\0\0\0\x95\0\0\0\0\0\0\
\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\
\0\x10\0\0\0\x01\0\0\0\0\0\0\0\x50\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\xf8\0\0\0\
\x12\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x14\0\0\0\x01\0\0\0\0\0\0\0\x50\0\0\0\x10\
\0\0\0\x01\0\0\0\0\0\0\0\x70\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\x01\x18\0\0\0\x12\
\0\0\0\x01\0\0\0\0\0\0\0\x38\0\0\0\x16\0\0\0\x01\0\0\0\0\0\0\0\x70\0\0\0\x10\0\
\0\0\x01\0\0\0\0\0\0\0\xa0\0\0\0\x17\0\0\0\x01\0\0\0\0\0\0\0\xf0\0\0\0\x11\0\0\
\0\x01\0\0\0\0\0\0\x01\x98\0\0\0\x12\0\0\0\x01\xeb\x9f\x01\0\0\0\0\x18\0\0\0\0\
\0\0\x0a\x18\0\0\x0a\x18\0\0\x09\x06\0\0\0\0\x02\0\0\0\0\0\0\x03\0\0\0\x01\x01\
\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\
\0\x1b\0\0\0\x05\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\x02\0\0\0\0\0\0\x06\0\0\
\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\x10\0\0\0\0\0\x04\0\0\x02\0\0\0\
\x10\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\0\x1e\0\0\0\x05\0\0\0\x40\0\0\0\x2a\x0e\0\
\0\0\0\0\0\x07\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x0a\0\0\0\x32\x01\0\0\0\0\0\0\
\x08\0\0\0\x40\0\0\0\0\x0d\0\0\x01\0\0\0\0\0\0\0\x45\0\0\0\x09\0\0\0\x49\x0c\0\
\0\x01\0\0\0\x0b\0\0\0\x5e\x84\0\0\x1a\0\0\x01\xa0\0\0\0\x6b\0\0\0\x0e\0\0\0\0\
\0\0\0\x6f\0\0\0\x0f\0\0\0\x40\0\0\0\x79\0\0\0\x10\0\0\0\x80\0\0\0\x7c\0\0\0\
\x0f\0\0\0\xc0\0\0\0\x7e\0\0\0\x0f\0\0\x01\0\0\0\0\x85\0\0\0\x11\x01\0\x01\x40\
\0\0\0\x91\0\0\0\x11\x01\0\x01\x41\0\0\0\x9e\0\0\0\x11\x01\0\x01\x42\0\0\0\xa9\
\0\0\0\x11\x01\0\x01\x43\0\0\0\xbc\0\0\0\x12\0\0\x01\x80\0\0\0\xc7\0\0\0\x12\0\
\0\x01\xc0\0\0\0\xd3\0\0\0\x12\0\0\x02\0\0\0\0\xd8\0\0\0\x4d\0\0\x02\x40\0\0\0\
\xdd\0\0\0\x02\0\0\x02\x80\0\0\0\xe4\0\0\0\x11\0\0\x02\xa0\0\0\0\xee\0\0\0\x02\
\0\0\x02\xc0\0\0\0\xf3\0\0\0\x02\0\0\x02\xe0\0\0\0\xf8\0\0\0\x4e\0\0\x03\0\0\0\
\x01\x01\0\0\0\x4e\0\0\x03\x40\0\0\x01\x08\0\0\0\x4e\0\0\x03\x80\0\0\x01\x0f\0\
\0\0\x11\0\0\x03\xc0\0\0\x01\x1c\0\0\0\x02\0\0\x03\xe0\0\0\x01\x23\0\0\0\x0f\0\
\0\x04\0\0\0\x01\x2a\0\0\0\x0f\0\0\x04\x40\0\0\x01\x2f\0\0\0\x51\0\0\x04\x80\0\
\0\x01\x3a\0\0\0\x53\0\0\x05\0\0\0\0\0\x02\0\0\0\0\0\0\x60\0\0\x01\x3e\x01\0\0\
\0\0\0\0\x08\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x61\0\0\x01\x4c\x01\0\0\0\0\0\0\
\x04\0\0\0\x20\0\0\0\0\x02\0\0\0\0\0\0\x13\0\0\0\xd3\x04\0\0\x14\0\0\0\xe8\0\0\
\x01\x59\0\0\0\x14\0\0\0\0\0\0\x01\x5d\0\0\0\x1b\0\0\0\x80\0\0\x01\x64\0\0\0\
\x1e\0\0\x01\0\0\0\x01\x6c\0\0\0\x1f\0\0\x01\x40\0\0\x01\x71\0\0\0\x21\0\0\x01\
\x80\0\0\x01\x78\0\0\0\x27\0\0\x01\xc0\0\0\x01\x80\0\0\0\x11\0\0\x02\0\0\0\x01\
\x88\0\0\0\x2d\0\0\x02\x20\0\0\x01\x8f\0\0\0\x2e\0\0\x02\x40\0\0\x01\x9a\0\0\0\
\x35\0\0\x03\x40\0\0\x01\xa0\0\0\0\x37\0\0\x03\x80\0\0\x01\xa8\0\0\0\x42\0\0\
\x04\x80\0\0\x01\xaf\0\0\0\x44\0\0\x04\xc0\0\0\x01\xb4\0\0\0\x45\0\0\x05\xc0\0\
\0\x01\xbe\0\0\0\x47\0\0\x06\0\0\0\x01\xc9\0\0\0\x47\0\0\x06\x40\0\0\x01\xd6\0\
\0\0\x48\0\0\x06\x80\0\0\x01\xdb\0\0\0\x49\0\0\x06\xc0\0\0\x01\xe5\0\0\0\x4a\0\
\0\x07\0\0\0\x01\xee\0\0\0\x4a\0\0\x07\x20\0\0\0\0\x05\0\0\x02\0\0\0\x10\0\0\
\x01\xf7\0\0\0\x15\0\0\0\0\0\0\x02\0\0\0\0\x17\0\0\0\0\0\0\x02\x0b\x04\0\0\x01\
\0\0\0\x08\0\0\x02\x16\0\0\0\x16\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\x15\0\0\x02\
\x1b\x04\0\0\x02\0\0\0\x10\0\0\x02\x16\0\0\0\x18\0\0\0\0\0\0\x02\x29\0\0\0\x19\
\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x17\0\0\0\0\x02\0\0\0\0\0\0\x1a\0\0\0\0\x0d\
\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\x02\x2e\x04\0\0\x02\0\0\0\x10\0\0\x02\
\x33\0\0\0\x1c\0\0\0\0\0\0\x02\x37\0\0\0\x1d\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\
\x62\0\0\0\0\x02\0\0\0\0\0\0\x63\0\0\0\0\x02\0\0\0\0\0\0\x64\0\0\0\0\x02\0\0\0\
\0\0\0\x20\0\0\0\0\x0a\0\0\0\0\0\0\x67\0\0\x02\x3e\x08\0\0\0\0\0\0\x22\0\0\x02\
\x49\x04\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\x23\0\0\0\0\0\0\0\0\x05\0\0\x01\0\0\0\
\x04\0\0\x02\x52\0\0\0\x24\0\0\0\0\0\0\x02\x58\x04\0\0\x01\0\0\0\x04\0\0\x02\
\x65\0\0\0\x25\0\0\0\0\0\0\x02\x6e\x08\0\0\0\0\0\0\x26\0\0\0\0\x04\0\0\x01\0\0\
\0\x04\0\0\x02\x7e\0\0\0\x02\0\0\0\0\0\0\x02\x83\x08\0\0\0\0\0\0\x28\0\0\x02\
\x91\x08\0\0\0\0\0\0\x29\0\0\0\0\x04\0\0\x01\0\0\0\x08\0\0\x02\x9c\0\0\0\x2a\0\
\0\0\0\0\0\x02\xa4\x08\0\0\0\0\0\0\x2b\0\0\x02\xa8\x08\0\0\0\0\0\0\x2c\0\0\x02\
\xae\x01\0\0\0\0\0\0\x08\x01\0\0\x40\0\0\x02\xb8\x08\0\0\0\0\0\0\x11\0\0\x02\
\xc0\x04\0\0\x04\0\0\0\x20\0\0\x02\xc6\0\0\0\x27\0\0\0\0\0\0\x02\xcc\0\0\0\x2f\
\0\0\0\x40\0\0\x02\xd6\0\0\0\x30\0\0\0\x60\0\0\x02\xda\0\0\0\x33\0\0\0\x80\0\0\
\x02\xe4\x08\0\0\0\0\0\0\x24\0\0\x02\xf3\x04\0\0\x01\0\0\0\x04\0\0\x03\x09\0\0\
\0\x31\0\0\0\0\0\0\x03\x0e\x08\0\0\0\0\0\0\x32\0\0\0\0\x04\0\0\x01\0\0\0\x04\0\
\0\x02\x9c\0\0\0\x02\0\0\0\0\0\0\x03\x17\x04\0\0\x02\0\0\0\x10\0\0\x02\x16\0\0\
\0\x34\0\0\0\0\0\0\x03\x21\0\0\0\x34\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x33\0\0\
\x03\x26\x08\0\0\0\0\0\0\x36\0\0\x03\x2d\x08\0\0\0\0\0\0\x2c\0\0\x03\x3d\x04\0\
\0\x06\0\0\0\x20\0\0\x02\x7e\0\0\0\x38\0\0\0\0\0\0\x03\x49\0\0\0\x3c\0\0\0\x40\
\0\0\x03\x4d\0\0\0\x3d\0\0\0\x80\0\0\x03\x56\0\0\0\x3e\0\0\0\xa0\0\0\x03\x5a\0\
\0\0\x3e\0\0\0\xc0\0\0\x03\x5f\0\0\0\x02\0\0\0\xe0\0\0\x03\x66\x08\0\0\0\0\0\0\
\x39\0\0\0\0\x04\0\0\x01\0\0\0\x08\0\0\x02\x65\0\0\0\x3a\0\0\0\0\0\0\x03\x6f\
\x08\0\0\0\0\0\0\x3b\0\0\0\0\x04\0\0\x02\0\0\0\x08\0\0\x03\x7d\0\0\0\x02\0\0\0\
\0\0\0\x03\x82\0\0\0\x25\0\0\0\x20\0\0\0\0\x02\0\0\0\0\0\0\x69\0\0\x03\x4d\x06\
\0\0\x05\0\0\0\x04\0\0\x03\x87\0\0\0\0\0\0\x03\x93\0\0\0\x01\0\0\x03\xa0\0\0\0\
\x02\0\0\x03\xad\0\0\0\x03\0\0\x03\xb9\0\0\0\x04\0\0\x03\xc5\x08\0\0\0\0\0\0\
\x3f\0\0\0\0\x04\0\0\x01\0\0\0\x04\0\0\x03\xcc\0\0\0\x40\0\0\0\0\0\0\x03\xd0\
\x08\0\0\0\0\0\0\x41\0\0\x03\xd6\x08\0\0\0\0\0\0\x11\0\0\0\0\x02\0\0\0\0\0\0\
\x43\0\0\0\0\x0a\0\0\0\0\0\0\x68\0\0\x03\xe7\x04\0\0\x06\0\0\0\x20\0\0\x03\xf5\
\0\0\0\x0f\0\0\0\0\0\0\x03\xfb\0\0\0\x11\0\0\0\x40\0\0\x04\0\0\0\0\x11\0\0\0\
\x60\0\0\x04\x0b\0\0\0\x11\0\0\0\x80\0\0\x04\x14\0\0\0\x11\0\0\0\xa0\0\0\x04\
\x1e\0\0\0\x35\0\0\0\xc0\0\0\x04\x27\x08\0\0\0\0\0\0\x46\0\0\x04\x2b\x08\0\0\0\
\0\0\0\x0a\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\x66\0\0\0\0\x02\0\
\0\0\0\0\0\x65\0\0\x04\x31\x08\0\0\0\0\0\0\x4b\0\0\x04\x3a\x08\0\0\0\0\0\0\x4c\
\0\0\x04\x3e\x08\0\0\0\0\0\0\x11\0\0\0\0\x02\0\0\0\0\0\0\x68\0\0\0\0\x02\0\0\0\
\0\0\0\x4f\0\0\0\0\x0a\0\0\0\0\0\0\x50\0\0\x04\x44\x01\0\0\0\0\0\0\x01\x01\0\0\
\x08\0\0\x04\x49\x04\0\0\x02\0\0\0\x10\0\0\x04\x50\0\0\0\x52\0\0\0\0\0\0\x04\
\x59\0\0\0\x52\0\0\0\x40\0\0\x04\x62\x08\0\0\0\0\0\0\x0f\0\0\0\0\x03\0\0\0\0\0\
\0\0\0\0\0\x50\0\0\0\x04\0\0\x01\0\0\0\0\0\x0d\0\0\x01\0\0\0\x02\0\0\0\x45\0\0\
\0\x09\0\0\x04\x73\x0c\0\0\x01\0\0\0\x54\0\0\x04\x87\x0c\0\0\x01\0\0\0\x54\0\0\
\x04\x98\x0e\0\0\0\0\0\0\x4b\0\0\0\x01\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x50\0\0\
\0\x04\0\0\0\x04\0\0\x04\xa6\x0e\0\0\0\0\0\0\x58\0\0\0\x01\0\0\x04\xaf\x08\0\0\
\0\0\0\0\x5b\0\0\x04\xb4\x01\0\0\0\0\0\0\x01\x04\0\0\x08\0\0\x04\xba\x0e\0\0\0\
\0\0\0\x5a\0\0\0\x01\0\0\x04\xcc\x0e\0\0\0\0\0\0\x5a\0\0\0\x01\0\0\x04\xe7\x0e\
\0\0\0\0\0\0\x5a\0\0\0\x01\0\0\x04\xff\x0e\0\0\0\0\0\0\x5a\0\0\0\x01\0\0\x05\
\x09\x07\0\0\0\0\0\0\0\0\0\x05\x18\x07\0\0\0\0\0\0\0\0\0\x05\x22\x07\0\0\0\0\0\
\0\0\0\0\x02\x37\x07\0\0\0\0\0\0\0\0\0\x05\x2b\x07\0\0\0\0\0\0\0\0\0\x05\x31\
\x07\0\0\0\0\0\0\0\0\0\x05\x3f\x07\0\0\0\0\0\0\0\0\0\x05\x4a\x07\0\0\0\0\0\0\0\
\0\0\0\xd8\x07\0\0\0\0\0\0\0\0\0\x03\x49\x07\0\0\0\0\0\0\0\0\0\x08\xa7\x0f\0\0\
\x05\0\0\0\x08\0\0\0\x57\0\0\0\0\0\0\0\x04\0\0\0\x5c\0\0\0\x04\0\0\0\x01\0\0\0\
\x5d\0\0\0\x05\0\0\0\x01\0\0\0\x5e\0\0\0\x06\0\0\0\x01\0\0\0\x5f\0\0\0\x07\0\0\
\0\x01\0\0\x08\xac\x0f\0\0\x01\0\0\0\x04\0\0\0\x59\0\0\0\0\0\0\0\x04\0\0\x08\
\xb4\x0f\0\0\x01\0\0\0\x10\0\0\0\x08\0\0\0\0\0\0\0\x10\0\x69\x6e\x74\0\x5f\x5f\
\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x74\x79\
\x70\x65\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\0\x72\x69\x6e\x67\x62\
\x75\x66\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\
\x67\0\x63\x74\x78\0\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\
\x5f\x63\x72\x65\x64\x73\0\x6c\x69\x6e\x75\x78\x5f\x62\x69\x6e\x70\x72\x6d\0\
\x76\x6d\x61\0\x76\x6d\x61\x5f\x70\x61\x67\x65\x73\0\x6d\x6d\0\x70\0\x61\x72\
\x67\x6d\x69\x6e\0\x68\x61\x76\x65\x5f\x65\x78\x65\x63\x66\x64\0\x65\x78\x65\
\x63\x66\x64\x5f\x63\x72\x65\x64\x73\0\x73\x65\x63\x75\x72\x65\x65\x78\x65\x63\
\0\x70\x6f\x69\x6e\x74\x5f\x6f\x66\x5f\x6e\x6f\x5f\x72\x65\x74\x75\x72\x6e\0\
\x65\x78\x65\x63\x75\x74\x61\x62\x6c\x65\0\x69\x6e\x74\x65\x72\x70\x72\x65\x74\
\x65\x72\0\x66\x69\x6c\x65\0\x63\x72\x65\x64\0\x75\x6e\x73\x61\x66\x65\0\x70\
\x65\x72\x5f\x63\x6c\x65\x61\x72\0\x61\x72\x67\x63\0\x65\x6e\x76\x63\0\x66\x69\
\x6c\x65\x6e\x61\x6d\x65\0\x69\x6e\x74\x65\x72\x70\0\x66\x64\x70\x61\x74\x68\0\
\x69\x6e\x74\x65\x72\x70\x5f\x66\x6c\x61\x67\x73\0\x65\x78\x65\x63\x66\x64\0\
\x6c\x6f\x61\x64\x65\x72\0\x65\x78\x65\x63\0\x72\x6c\x69\x6d\x5f\x73\x74\x61\
\x63\x6b\0\x62\x75\x66\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\0\
\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x66\x5f\x75\0\x66\x5f\x70\
\x61\x74\x68\0\x66\x5f\x69\x6e\x6f\x64\x65\0\x66\x5f\x6f\x70\0\x66\x5f\x6c\x6f\
\x63\x6b\0\x66\x5f\x63\x6f\x75\x6e\x74\0\x66\x5f\x66\x6c\x61\x67\x73\0\x66\x5f\
\x6d\x6f\x64\x65\0\x66\x5f\x70\x6f\x73\x5f\x6c\x6f\x63\x6b\0\x66\x5f\x70\x6f\
\x73\0\x66\x5f\x6f\x77\x6e\x65\x72\0\x66\x5f\x63\x72\x65\x64\0\x66\x5f\x72\x61\
\0\x66\x5f\x76\x65\x72\x73\x69\x6f\x6e\0\x66\x5f\x73\x65\x63\x75\x72\x69\x74\
\x79\0\x70\x72\x69\x76\x61\x74\x65\x5f\x64\x61\x74\x61\0\x66\x5f\x65\x70\0\x66\
\x5f\x6d\x61\x70\x70\x69\x6e\x67\0\x66\x5f\x77\x62\x5f\x65\x72\x72\0\x66\x5f\
\x73\x62\x5f\x65\x72\x72\0\x66\x75\x5f\x6c\x6c\x69\x73\x74\0\x66\x75\x5f\x72\
\x63\x75\x68\x65\x61\x64\0\x6c\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\0\x6e\x65\
\x78\x74\0\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x68\x65\x61\x64\0\x66\x75\x6e\
\x63\0\x70\x61\x74\x68\0\x6d\x6e\x74\0\x64\x65\x6e\x74\x72\x79\0\x73\x70\x69\
\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\x72\x6c\x6f\
\x63\x6b\0\x72\x61\x77\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\x72\x61\x77\x5f\
\x6c\x6f\x63\x6b\0\x61\x72\x63\x68\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\
\0\x6c\x6f\x63\x6b\0\x61\x74\x6f\x6d\x69\x63\x5f\x6c\x6f\x6e\x67\x5f\x74\0\x61\
\x74\x6f\x6d\x69\x63\x36\x34\x5f\x74\0\x63\x6f\x75\x6e\x74\x65\x72\0\x73\x36\
\x34\0\x5f\x5f\x73\x36\x34\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x66\x6d\x6f\
\x64\x65\x5f\x74\0\x6d\x75\x74\x65\x78\0\x6f\x77\x6e\x65\x72\0\x77\x61\x69\x74\
\x5f\x6c\x6f\x63\x6b\0\x6f\x73\x71\0\x77\x61\x69\x74\x5f\x6c\x69\x73\x74\0\x72\
\x61\x77\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x6f\x70\x74\x69\x6d\x69\
\x73\x74\x69\x63\x5f\x73\x70\x69\x6e\x5f\x71\x75\x65\x75\x65\0\x74\x61\x69\x6c\
\0\x61\x74\x6f\x6d\x69\x63\x5f\x74\0\x6c\x69\x73\x74\x5f\x68\x65\x61\x64\0\x70\
\x72\x65\x76\0\x6c\x6f\x66\x66\x5f\x74\0\x5f\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\
\x6c\x6f\x66\x66\x5f\x74\0\x66\x6f\x77\x6e\x5f\x73\x74\x72\x75\x63\x74\0\x70\
\x69\x64\0\x70\x69\x64\x5f\x74\x79\x70\x65\0\x75\x69\x64\0\x65\x75\x69\x64\0\
\x73\x69\x67\x6e\x75\x6d\0\x72\x77\x6c\x6f\x63\x6b\x5f\x74\0\x61\x72\x63\x68\
\x5f\x72\x77\x6c\x6f\x63\x6b\x5f\x74\0\x63\x6e\x74\x73\0\x77\x61\x69\x74\0\x50\
\x49\x44\x54\x59\x50\x45\x5f\x50\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x54\
\x47\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x50\x47\x49\x44\0\x50\x49\x44\
\x54\x59\x50\x45\x5f\x53\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x4d\x41\x58\
\0\x6b\x75\x69\x64\x5f\x74\0\x76\x61\x6c\0\x75\x69\x64\x5f\x74\0\x5f\x5f\x6b\
\x65\x72\x6e\x65\x6c\x5f\x75\x69\x64\x33\x32\x5f\x74\0\x66\x69\x6c\x65\x5f\x72\
\x61\x5f\x73\x74\x61\x74\x65\0\x73\x74\x61\x72\x74\0\x73\x69\x7a\x65\0\x61\x73\
\x79\x6e\x63\x5f\x73\x69\x7a\x65\0\x72\x61\x5f\x70\x61\x67\x65\x73\0\x6d\x6d\
\x61\x70\x5f\x6d\x69\x73\x73\0\x70\x72\x65\x76\x5f\x70\x6f\x73\0\x75\x36\x34\0\
\x5f\x5f\x75\x36\x34\0\x65\x72\x72\x73\x65\x71\x5f\x74\0\x75\x33\x32\0\x5f\x5f\
\x75\x33\x32\0\x63\x68\x61\x72\0\x72\x6c\x69\x6d\x69\x74\0\x72\x6c\x69\x6d\x5f\
\x63\x75\x72\0\x72\x6c\x69\x6d\x5f\x6d\x61\x78\0\x5f\x5f\x6b\x65\x72\x6e\x65\
\x6c\x5f\x75\x6c\x6f\x6e\x67\x5f\x74\0\x62\x70\x72\x6d\x5f\x63\x72\x65\x64\x73\
\x5f\x66\x6f\x72\x5f\x65\x78\x65\x63\0\x6b\x65\x72\x6e\x65\x6c\x5f\x72\x65\x61\
\x64\x5f\x66\x69\x6c\x65\0\x6d\x6f\x6e\x69\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\
\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x62\x6f\x6f\x6c\0\x5f\x42\x6f\x6f\x6c\0\
\x75\x73\x65\x5f\x69\x6d\x61\x5f\x66\x69\x6c\x65\x5f\x68\x61\x73\x68\0\x65\x6e\
\x61\x62\x6c\x65\x5f\x62\x70\x72\x6d\x5f\x63\x72\x65\x64\x73\x5f\x66\x6f\x72\
\x5f\x65\x78\x65\x63\0\x65\x6e\x61\x62\x6c\x65\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\
\x72\x65\x61\x64\x5f\x66\x69\x6c\x65\0\x74\x65\x73\x74\x5f\x64\x65\x6e\x79\0\
\x76\x6d\x5f\x61\x72\x65\x61\x5f\x73\x74\x72\x75\x63\x74\0\x6d\x6d\x5f\x73\x74\
\x72\x75\x63\x74\0\x76\x66\x73\x6d\x6f\x75\x6e\x74\0\x69\x6e\x6f\x64\x65\0\x61\
\x64\x64\x72\x65\x73\x73\x5f\x73\x70\x61\x63\x65\0\x68\x6c\x69\x73\x74\x5f\x68\
\x65\x61\x64\0\x66\x69\x6c\x65\x5f\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x73\0\
\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\
\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\
\x34\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\
\x32\x31\x34\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\
\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\
\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x69\x6d\x61\x2e\x63\0\x76\x6f\x69\x64\
\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\
\x69\x74\x74\x65\x64\x5f\x63\x72\x65\x64\x73\x2c\x20\x73\x74\x72\x75\x63\x74\
\x20\x6c\x69\x6e\x75\x78\x5f\x62\x69\x6e\x70\x72\x6d\x20\x2a\x62\x70\x72\x6d\
\x29\0\x09\x69\x6d\x61\x5f\x74\x65\x73\x74\x5f\x63\x6f\x6d\x6d\x6f\x6e\x28\x62\
\x70\x72\x6d\x2d\x3e\x66\x69\x6c\x65\x29\x3b\0\x09\x75\x36\x34\x20\x69\x6d\x61\
\x5f\x68\x61\x73\x68\x20\x3d\x20\x30\x3b\0\x09\x70\x69\x64\x20\x3d\x20\x62\x70\
\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x70\x69\x64\x5f\x74\
\x67\x69\x64\x28\x29\x20\x3e\x3e\x20\x33\x32\x3b\0\x09\x69\x66\x20\x28\x70\x69\
\x64\x20\x3d\x3d\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\x29\
\x20\x7b\0\x09\x09\x69\x66\x20\x28\x21\x75\x73\x65\x5f\x69\x6d\x61\x5f\x66\x69\
\x6c\x65\x5f\x68\x61\x73\x68\x29\0\x09\x09\x09\x72\x65\x74\x20\x3d\x20\x62\x70\
\x66\x5f\x69\x6d\x61\x5f\x69\x6e\x6f\x64\x65\x5f\x68\x61\x73\x68\x28\x66\x69\
\x6c\x65\x2d\x3e\x66\x5f\x69\x6e\x6f\x64\x65\x2c\x20\x26\x69\x6d\x61\x5f\x68\
\x61\x73\x68\x2c\0\x09\x09\x09\x72\x65\x74\x20\x3d\x20\x62\x70\x66\x5f\x69\x6d\
\x61\x5f\x66\x69\x6c\x65\x5f\x68\x61\x73\x68\x28\x66\x69\x6c\x65\x2c\x20\x26\
\x69\x6d\x61\x5f\x68\x61\x73\x68\x2c\0\x09\x09\x69\x66\x20\x28\x72\x65\x74\x20\
\x3c\x20\x30\x20\x7c\x7c\x20\x69\x6d\x61\x5f\x68\x61\x73\x68\x20\x3d\x3d\x20\
\x30\x29\0\x09\x09\x73\x61\x6d\x70\x6c\x65\x20\x3d\x20\x62\x70\x66\x5f\x72\x69\
\x6e\x67\x62\x75\x66\x5f\x72\x65\x73\x65\x72\x76\x65\x28\x26\x72\x69\x6e\x67\
\x62\x75\x66\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\x75\x36\x34\x29\x2c\x20\x30\
\x29\x3b\0\x09\x09\x69\x66\x20\x28\x21\x73\x61\x6d\x70\x6c\x65\x29\0\x09\x09\
\x2a\x73\x61\x6d\x70\x6c\x65\x20\x3d\x20\x69\x6d\x61\x5f\x68\x61\x73\x68\x3b\0\
\x09\x09\x62\x70\x66\x5f\x72\x69\x6e\x67\x62\x75\x66\x5f\x73\x75\x62\x6d\x69\
\x74\x28\x73\x61\x6d\x70\x6c\x65\x2c\x20\x30\x29\x3b\0\x09\x69\x66\x20\x28\x21\
\x65\x6e\x61\x62\x6c\x65\x5f\x62\x70\x72\x6d\x5f\x63\x72\x65\x64\x73\x5f\x66\
\x6f\x72\x5f\x65\x78\x65\x63\x29\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\
\x47\x28\x62\x70\x72\x6d\x5f\x63\x72\x65\x64\x73\x5f\x66\x6f\x72\x5f\x65\x78\
\x65\x63\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x6c\x69\x6e\x75\x78\x5f\x62\x69\
\x6e\x70\x72\x6d\x20\x2a\x62\x70\x72\x6d\x29\0\x69\x6e\x74\x20\x42\x50\x46\x5f\
\x50\x52\x4f\x47\x28\x6b\x65\x72\x6e\x65\x6c\x5f\x72\x65\x61\x64\x5f\x66\x69\
\x6c\x65\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x66\x69\x6c\x65\x20\x2a\x66\x69\
\x6c\x65\x2c\x20\x65\x6e\x75\x6d\x20\x6b\x65\x72\x6e\x65\x6c\x5f\x72\x65\x61\
\x64\x5f\x66\x69\x6c\x65\x5f\x69\x64\x20\x69\x64\x2c\0\x09\x69\x66\x20\x28\x21\
\x65\x6e\x61\x62\x6c\x65\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x72\x65\x61\x64\x5f\
\x66\x69\x6c\x65\x29\0\x09\x69\x66\x20\x28\x70\x69\x64\x20\x3d\x3d\x20\x6d\x6f\
\x6e\x69\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\x20\x26\x26\x20\x74\x65\x73\x74\
\x5f\x64\x65\x6e\x79\x29\0\x09\x69\x66\x20\x28\x72\x65\x74\x20\x3c\x20\x30\x29\
\0\x30\x3a\x31\x31\0\x30\x3a\x32\0\x2e\x62\x73\x73\0\x6c\x69\x63\x65\x6e\x73\
\x65\0\x2e\x6d\x61\x70\x73\0\x6c\x73\x6d\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\
\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\x72\x65\x64\x73\0\x6c\x73\x6d\x2e\x73\
\x2f\x62\x70\x72\x6d\x5f\x63\x72\x65\x64\x73\x5f\x66\x6f\x72\x5f\x65\x78\x65\
\x63\0\x6c\x73\x6d\x2e\x73\x2f\x6b\x65\x72\x6e\x65\x6c\x5f\x72\x65\x61\x64\x5f\
\x66\x69\x6c\x65\0\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x34\0\0\0\x34\0\0\
\x04\x9c\0\0\x04\xd0\0\0\0\x6c\0\0\0\x08\0\0\x08\xba\0\0\0\x01\0\0\0\0\0\0\0\
\x0c\0\0\x08\xd5\0\0\0\x01\0\0\0\0\0\0\0\x55\0\0\x08\xef\0\0\0\x01\0\0\0\0\0\0\
\0\x56\0\0\0\x10\0\0\x08\xba\0\0\0\x15\0\0\0\0\0\0\x05\x5a\0\0\x05\xc9\0\x01\
\x0c\x06\0\0\0\x08\0\0\x05\x5a\0\0\x06\x08\0\x01\x14\x18\0\0\0\x18\0\0\x05\x5a\
\0\0\x06\x26\0\0\x70\x06\0\0\0\x20\0\0\x05\x5a\0\0\x06\x39\0\0\x84\x08\0\0\0\
\x28\0\0\x05\x5a\0\0\x06\x39\0\0\x84\x23\0\0\0\x30\0\0\x05\x5a\0\0\x06\x62\0\0\
\x88\x0d\0\0\0\x48\0\0\x05\x5a\0\0\x06\x62\0\0\x88\x06\0\0\0\x50\0\0\x05\x5a\0\
\0\x06\x7f\0\0\x8c\x08\0\0\0\x68\0\0\x05\x5a\0\0\x06\x7f\0\0\x8c\x07\0\0\0\x70\
\0\0\x05\x5a\0\0\x06\x99\0\0\x90\x23\0\0\0\x88\0\0\x05\x5a\0\0\x06\x99\0\0\x90\
\x0a\0\0\0\xa8\0\0\x05\x5a\0\0\0\0\0\0\0\0\0\0\0\xb0\0\0\x05\x5a\0\0\x06\xcf\0\
\0\x9c\x0a\0\0\0\xd8\0\0\x05\x5a\0\0\x06\xfb\0\0\xa4\x0b\0\0\0\xe0\0\0\x05\x5a\
\0\0\x06\xfb\0\0\xa4\x0f\0\0\0\xf8\0\0\x05\x5a\0\0\x07\x1b\0\0\xb0\x0c\0\0\x01\
\x20\0\0\x05\x5a\0\0\x07\x55\0\0\xb4\x07\0\0\x01\x28\0\0\x05\x5a\0\0\x07\x64\0\
\0\xc0\x0d\0\0\x01\x30\0\0\x05\x5a\0\0\x07\x64\0\0\xc0\x0b\0\0\x01\x38\0\0\x05\
\x5a\0\0\x07\x7a\0\0\xc4\x03\0\0\x01\x50\0\0\x05\x5a\0\0\x05\xc9\0\x01\x0c\x06\
\0\0\x08\xd5\0\0\0\x17\0\0\0\0\0\0\x05\x5a\0\0\x07\x9b\0\x01\x2c\x07\0\0\0\x18\
\0\0\x05\x5a\0\0\x07\x9b\0\x01\x2c\x06\0\0\0\x20\0\0\x05\x5a\0\0\x07\xbd\0\x01\
\x24\x05\0\0\0\x28\0\0\x05\x5a\0\0\x06\x08\0\x01\x38\x18\0\0\0\x38\0\0\x05\x5a\
\0\0\x06\x26\0\0\x70\x06\0\0\0\x40\0\0\x05\x5a\0\0\x06\x39\0\0\x84\x08\0\0\0\
\x48\0\0\x05\x5a\0\0\x06\x39\0\0\x84\x23\0\0\0\x50\0\0\x05\x5a\0\0\x06\x62\0\0\
\x88\x0d\0\0\0\x68\0\0\x05\x5a\0\0\x06\x62\0\0\x88\x06\0\0\0\x70\0\0\x05\x5a\0\
\0\x06\x7f\0\0\x8c\x08\0\0\0\x88\0\0\x05\x5a\0\0\x06\x7f\0\0\x8c\x07\0\0\0\x90\
\0\0\x05\x5a\0\0\x06\x99\0\0\x90\x23\0\0\0\xa8\0\0\x05\x5a\0\0\x06\x99\0\0\x90\
\x0a\0\0\0\xc8\0\0\x05\x5a\0\0\0\0\0\0\0\0\0\0\0\xd0\0\0\x05\x5a\0\0\x06\xcf\0\
\0\x9c\x0a\0\0\0\xf8\0\0\x05\x5a\0\0\x06\xfb\0\0\xa4\x0b\0\0\x01\0\0\0\x05\x5a\
\0\0\x06\xfb\0\0\xa4\x0f\0\0\x01\x18\0\0\x05\x5a\0\0\x07\x1b\0\0\xb0\x0c\0\0\
\x01\x40\0\0\x05\x5a\0\0\x07\x55\0\0\xb4\x07\0\0\x01\x48\0\0\x05\x5a\0\0\x07\
\x64\0\0\xc0\x0d\0\0\x01\x50\0\0\x05\x5a\0\0\x07\x64\0\0\xc0\x0b\0\0\x01\x58\0\
\0\x05\x5a\0\0\x07\x7a\0\0\xc4\x03\0\0\x01\x70\0\0\x05\x5a\0\0\x07\xbd\0\x01\
\x24\x05\0\0\x08\xef\0\0\0\x1c\0\0\0\0\0\0\x05\x5a\0\0\x07\xfa\0\x01\x4c\0\0\0\
\0\x08\0\0\x05\x5a\0\0\x07\xfa\0\x01\x4c\x05\0\0\0\x20\0\0\x05\x5a\0\0\x08\x49\
\0\x01\x60\x06\0\0\0\x28\0\0\x05\x5a\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\x05\x5a\0\0\
\x08\x49\0\x01\x60\x06\0\0\0\x60\0\0\x05\x5a\0\0\x06\x39\0\0\xec\x08\0\0\0\x68\
\0\0\x05\x5a\0\0\x06\x39\0\0\xec\x23\0\0\0\x70\0\0\x05\x5a\0\0\x08\x68\0\0\xf0\
\x0d\0\0\0\x88\0\0\x05\x5a\0\0\x08\x90\0\x01\x88\x06\0\0\0\xc8\0\0\x05\x5a\0\0\
\x06\x26\0\0\x70\x06\0\0\0\xd0\0\0\x05\x5a\0\0\x06\x39\0\0\x84\x08\0\0\0\xd8\0\
\0\x05\x5a\0\0\x06\x39\0\0\x84\x23\0\0\0\xe0\0\0\x05\x5a\0\0\x06\x62\0\0\x88\
\x0d\0\0\0\xe8\0\0\x05\x5a\0\0\x06\x62\0\0\x88\x06\0\0\0\xf0\0\0\x05\x5a\0\0\
\x06\x7f\0\0\x8c\x08\0\0\x01\x08\0\0\x05\x5a\0\0\x06\x7f\0\0\x8c\x07\0\0\x01\
\x10\0\0\x05\x5a\0\0\x06\x99\0\0\x90\x23\0\0\x01\x28\0\0\x05\x5a\0\0\x06\x99\0\
\0\x90\x0a\0\0\x01\x48\0\0\x05\x5a\0\0\0\0\0\0\0\0\0\0\x01\x50\0\0\x05\x5a\0\0\
\x06\xcf\0\0\x9c\x0a\0\0\x01\x78\0\0\x05\x5a\0\0\x06\xfb\0\0\xa4\x0b\0\0\x01\
\x80\0\0\x05\x5a\0\0\x06\xfb\0\0\xa4\x0f\0\0\x01\x98\0\0\x05\x5a\0\0\x07\x1b\0\
\0\xb0\x0c\0\0\x01\xc0\0\0\x05\x5a\0\0\x07\x55\0\0\xb4\x07\0\0\x01\xc8\0\0\x05\
\x5a\0\0\x07\x64\0\0\xc0\x0d\0\0\x01\xd0\0\0\x05\x5a\0\0\x07\x64\0\0\xc0\x0b\0\
\0\x01\xd8\0\0\x05\x5a\0\0\x07\x7a\0\0\xc4\x03\0\0\x01\xf0\0\0\x05\x5a\0\0\x07\
\xfa\0\x01\x4c\x05\0\0\0\x10\0\0\x08\xba\0\0\0\x02\0\0\0\x08\0\0\0\x0d\0\0\x08\
\x9e\0\0\0\0\0\0\0\x70\0\0\0\x13\0\0\x08\xa3\0\0\0\0\0\0\x08\xd5\0\0\0\x02\0\0\
\0\x28\0\0\0\x0d\0\0\x08\x9e\0\0\0\0\0\0\0\x90\0\0\0\x13\0\0\x08\xa3\0\0\0\0\0\
\0\x08\xef\0\0\0\x01\0\0\x01\x10\0\0\0\x13\0\0\x08\xa3\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\
\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\x01\xcb\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x02\x10\0\0\0\0\0\0\x02\x58\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x04\x68\0\0\0\0\0\0\x01\x58\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\
\0\0\0\0\0\0\0\0\x2c\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x05\xc0\0\0\0\0\0\0\x01\x80\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\
\0\0\0\x46\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\x40\0\0\
\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x5d\0\0\
\0\x08\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\x40\0\0\0\0\0\0\0\x08\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\x62\0\0\0\x01\0\0\0\0\
\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\x40\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x6a\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x09\x48\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x08\0\0\0\0\0\0\0\0\0\0\x01\x65\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x09\x58\0\0\0\0\0\0\0\x30\0\0\0\x02\0\0\0\x03\0\0\0\0\0\0\0\x08\0\
\0\0\0\0\0\0\x10\0\0\x01\x84\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x09\x88\0\0\0\0\0\0\0\x40\0\0\0\x02\0\0\0\x04\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\x10\0\0\x01\xa2\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x09\xc8\0\0\0\0\0\0\0\x50\0\0\0\x02\0\0\0\x05\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x10\0\0\x01\xbd\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x18\
\0\0\0\0\0\0\x13\x36\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x01\
\xc2\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1d\x50\0\0\0\0\0\0\
\x05\x5c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct ima *ima::open(const struct bpf_object_open_opts *opts) { return ima__open_opts(opts); }
struct ima *ima::open_and_load() { return ima__open_and_load(); }
int ima::load(struct ima *skel) { return ima__load(skel); }
int ima::attach(struct ima *skel) { return ima__attach(skel); }
void ima::detach(struct ima *skel) { ima__detach(skel); }
void ima::destroy(struct ima *skel) { ima__destroy(skel); }
const void *ima::elf_bytes(size_t *sz) { return ima__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
ima__assert(struct ima *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->monitored_pid) == 4, "unexpected size of 'monitored_pid'");
	_Static_assert(sizeof(s->bss->use_ima_file_hash) == 1, "unexpected size of 'use_ima_file_hash'");
	_Static_assert(sizeof(s->bss->enable_bprm_creds_for_exec) == 1, "unexpected size of 'enable_bprm_creds_for_exec'");
	_Static_assert(sizeof(s->bss->enable_kernel_read_file) == 1, "unexpected size of 'enable_kernel_read_file'");
	_Static_assert(sizeof(s->bss->test_deny) == 1, "unexpected size of 'test_deny'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __IMA_SKEL_H__ */
