/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __KFREE_SKB_SKEL_H__
#define __KFREE_SKB_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct kfree_skb {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *perf_buf_map;
		struct bpf_map *bss;
		struct bpf_map *rodata;
	} maps;
	struct {
		struct bpf_program *trace_kfree_skb;
		struct bpf_program *fentry_eth_type_trans;
		struct bpf_program *fexit_eth_type_trans;
	} progs;
	struct {
		struct bpf_link *trace_kfree_skb;
		struct bpf_link *fentry_eth_type_trans;
		struct bpf_link *fexit_eth_type_trans;
	} links;
	struct kfree_skb__bss {
		struct {
			_Bool fentry_test_ok;
			_Bool fexit_test_ok;
		} result;
	} *bss;
	struct kfree_skb__rodata {
	} *rodata;

#ifdef __cplusplus
	static inline struct kfree_skb *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct kfree_skb *open_and_load();
	static inline int load(struct kfree_skb *skel);
	static inline int attach(struct kfree_skb *skel);
	static inline void detach(struct kfree_skb *skel);
	static inline void destroy(struct kfree_skb *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
kfree_skb__destroy(struct kfree_skb *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
kfree_skb__create_skeleton(struct kfree_skb *obj);

static inline struct kfree_skb *
kfree_skb__open_opts(const struct bpf_object_open_opts *opts)
{
	struct kfree_skb *obj;
	int err;

	obj = (struct kfree_skb *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = kfree_skb__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	kfree_skb__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct kfree_skb *
kfree_skb__open(void)
{
	return kfree_skb__open_opts(NULL);
}

static inline int
kfree_skb__load(struct kfree_skb *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct kfree_skb *
kfree_skb__open_and_load(void)
{
	struct kfree_skb *obj;
	int err;

	obj = kfree_skb__open();
	if (!obj)
		return NULL;
	err = kfree_skb__load(obj);
	if (err) {
		kfree_skb__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
kfree_skb__attach(struct kfree_skb *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
kfree_skb__detach(struct kfree_skb *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *kfree_skb__elf_bytes(size_t *sz);

static inline int
kfree_skb__create_skeleton(struct kfree_skb *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "kfree_skb";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 3;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "perf_buf_map";
	s->maps[0].map = &obj->maps.perf_buf_map;

	s->maps[1].name = "kfree_sk.bss";
	s->maps[1].map = &obj->maps.bss;
	s->maps[1].mmaped = (void **)&obj->bss;

	s->maps[2].name = "kfree_sk.rodata";
	s->maps[2].map = &obj->maps.rodata;
	s->maps[2].mmaped = (void **)&obj->rodata;

	/* programs */
	s->prog_cnt = 3;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "trace_kfree_skb";
	s->progs[0].prog = &obj->progs.trace_kfree_skb;
	s->progs[0].link = &obj->links.trace_kfree_skb;

	s->progs[1].name = "fentry_eth_type_trans";
	s->progs[1].prog = &obj->progs.fentry_eth_type_trans;
	s->progs[1].link = &obj->links.fentry_eth_type_trans;

	s->progs[2].name = "fexit_eth_type_trans";
	s->progs[2].prog = &obj->progs.fexit_eth_type_trans;
	s->progs[2].link = &obj->links.fexit_eth_type_trans;

	s->data = (void *)kfree_skb__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *kfree_skb__elf_bytes(size_t *sz)
{
	*sz = 7552;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x19\xc0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0f\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x74\x70\x5f\
\x62\x74\x66\x2f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\0\x66\x65\x6e\x74\x72\x79\
\x2f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x66\x65\x78\x69\
\x74\x2f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x6c\x69\x63\
\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x6d\x61\x70\x73\0\x2e\x72\x6f\x64\x61\
\x74\x61\0\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x63\0\x5f\x5f\x5f\x5f\x74\
\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\
\x66\x6d\x74\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\
\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\x2e\x31\0\x5f\x5f\x5f\x5f\x74\x72\
\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\
\x6d\x74\x2e\x32\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\
\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\x2e\x33\0\x5f\x5f\x5f\x5f\x74\
\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\
\x66\x6d\x74\x2e\x34\0\x4c\x42\x42\x30\x5f\x34\0\x4c\x42\x42\x31\x5f\x33\0\x4c\
\x42\x42\x32\x5f\x34\0\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\
\x62\0\x70\x65\x72\x66\x5f\x62\x75\x66\x5f\x6d\x61\x70\0\x66\x65\x6e\x74\x72\
\x79\x5f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x72\x65\x73\
\x75\x6c\x74\0\x66\x65\x78\x69\x74\x5f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\
\x72\x61\x6e\x73\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x74\x70\
\x5f\x62\x74\x66\x2f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\0\x2e\x72\x65\x6c\x66\
\x65\x6e\x74\x72\x79\x2f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\
\x73\0\x2e\x72\x65\x6c\x66\x65\x78\x69\x74\x2f\x65\x74\x68\x5f\x74\x79\x70\x65\
\x5f\x74\x72\x61\x6e\x73\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x68\x04\0\xff\
\xf1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x74\x01\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1d\0\0\0\x90\
\x01\0\0\x09\0\0\0\0\0\0\0\x1d\0\0\0\0\0\0\0\x22\0\0\0\xae\x01\0\0\x09\0\0\0\0\
\0\0\0\x3f\0\0\0\0\0\0\0\x17\0\0\0\xcc\x01\0\0\x09\0\0\0\0\0\0\0\x56\0\0\0\0\0\
\0\0\x27\0\0\0\xea\x01\0\0\x09\0\0\0\0\0\0\0\x7d\0\0\0\0\0\0\0\x14\0\0\x01\x08\
\0\0\0\x03\0\0\0\0\0\0\x02\xb8\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x04\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x01\x0f\0\0\0\x04\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\0\0\
\0\0\0\x03\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x16\0\0\0\x05\0\0\0\
\0\0\0\0\x88\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x01\x1d\x12\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\xc8\0\0\x01\x2d\x11\
\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\x01\x3a\x12\0\0\x04\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x70\0\0\x01\x50\x11\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x02\0\0\x01\x57\x12\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x98\0\0\x01\x6c\x11\
\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x79\x61\0\0\0\0\0\0\xb7\x10\0\0\0\0\
\0\0\x63\xa1\xff\xf8\0\0\0\0\x79\x16\0\x10\0\0\0\0\x79\x21\0\x08\0\0\0\0\xb7\
\x30\0\0\0\0\0\x28\x61\x46\0\x18\0\0\0\0\x7b\xa4\xff\xd0\0\0\0\0\x79\x96\0\x20\
\0\0\0\0\xbf\x46\0\0\0\0\0\0\x0f\x43\0\0\0\0\0\0\x79\x82\0\0\0\0\0\0\x79\x28\0\
\x08\0\0\0\0\x7b\xa2\xff\xc8\0\0\0\0\x61\x71\0\0\0\0\0\0\x63\xa7\xff\xf0\0\0\0\
\0\x71\x14\0\x08\0\0\0\0\x7b\xa1\xff\xe0\0\0\0\0\x73\xa1\xff\xf8\0\0\0\0\x61\
\x14\0\x08\0\0\0\0\x7b\xa1\xff\xd8\0\0\0\0\x63\xa1\xff\xf4\0\0\0\0\xb7\x10\0\0\
\0\0\0\x28\xbf\x36\0\0\0\0\0\0\x0f\x31\0\0\0\0\0\0\xbf\x1a\0\0\0\0\0\0\x07\x10\
\0\0\xff\xff\xff\xef\xb7\x20\0\0\0\0\0\x01\x85\0\0\0\0\0\0\x71\x71\x1a\xff\xef\
\0\0\0\0\x57\x10\0\0\0\0\0\x07\x73\xa1\xff\xef\0\0\0\0\xbf\x1a\0\0\0\0\0\0\x07\
\x10\0\0\xff\xff\xff\xfe\xbf\x39\0\0\0\0\0\0\x07\x30\0\0\0\0\0\x0c\xb7\x20\0\0\
\0\0\0\x02\x85\0\0\0\0\0\0\x71\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x20\0\0\
\0\0\0\x1d\xbf\x38\0\0\0\0\0\0\x79\x4a\xff\xc8\0\0\0\0\x85\0\0\0\0\0\0\x06\x61\
\x36\0\0\0\0\0\0\x71\x5a\xff\xef\0\0\0\0\x67\x50\0\0\0\0\0\x38\xc7\x50\0\0\0\0\
\0\x38\x18\x10\0\0\0\0\0\x1d\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x22\x79\x8a\xff\
\xd0\0\0\0\0\xbf\x48\0\0\0\0\0\0\x85\0\0\0\0\0\0\x06\x69\x36\0\x0c\0\0\0\0\x18\
\x10\0\0\0\0\0\x3f\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x17\x85\0\0\0\0\0\0\x06\
\x69\x5a\xff\xfe\0\0\0\0\x18\x10\0\0\0\0\0\x56\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\
\0\x27\xbf\x37\0\0\0\0\0\0\xbf\x49\0\0\0\0\0\0\x85\0\0\0\0\0\0\x06\x18\x10\0\0\
\0\0\0\x7d\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x14\x79\x3a\xff\xe0\0\0\0\0\x79\
\x4a\xff\xd8\0\0\0\0\x85\0\0\0\0\0\0\x06\x55\x80\0\x0e\0\0\0\x01\x69\x1a\xff\
\xfe\0\0\0\0\x55\x10\0\x0c\0\0\x86\xdd\x67\x70\0\0\0\0\0\x20\x77\x70\0\0\0\0\0\
\x20\x55\x70\0\x09\0\0\0\x01\xbf\x4a\0\0\0\0\0\0\x07\x40\0\0\xff\xff\xff\xf0\
\xbf\x16\0\0\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x30\0\0\xff\xff\
\xff\xff\0\0\0\0\0\0\0\x48\xb7\x50\0\0\0\0\0\x0c\x85\0\0\0\0\0\0\x6f\xb7\0\0\0\
\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x21\0\0\0\0\0\0\x79\x11\0\x08\0\0\0\0\x61\x11\0\
\0\0\0\0\0\x61\x22\0\0\0\0\0\0\x55\x20\0\x07\0\0\0\x4a\x67\x10\0\0\0\0\0\x20\
\x77\x10\0\0\0\0\0\x20\x55\x10\0\x04\0\0\0\x01\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\xb7\x20\0\0\0\0\0\x01\x73\x12\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\
\0\0\x79\x31\0\0\0\0\0\0\x79\x21\0\x08\0\0\0\0\x61\x22\0\0\0\0\0\0\x61\x33\0\0\
\0\0\0\0\x79\x11\0\x10\0\0\0\0\x57\x10\0\0\0\0\xff\xff\x55\x10\0\x0a\0\0\x86\
\xdd\x67\x30\0\0\0\0\0\x20\x77\x30\0\0\0\0\0\x20\x55\x30\0\x07\0\0\0\x3c\x67\
\x20\0\0\0\0\0\x20\x77\x20\0\0\0\0\0\x20\x55\x20\0\x04\0\0\0\x01\x18\x10\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x01\x73\x12\0\x01\0\0\0\0\xb7\0\0\0\0\
\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x72\x63\x75\x68\x65\x61\x64\x2e\x6e\x65\x78\x74\x20\x25\x6c\
\x6c\x78\x20\x66\x75\x6e\x63\x20\x25\x6c\x6c\x78\x0a\0\x73\x6b\x62\x2d\x3e\x6c\
\x65\x6e\x20\x25\x64\x20\x75\x73\x65\x72\x73\x20\x25\x64\x20\x70\x6b\x74\x5f\
\x74\x79\x70\x65\x20\x25\x78\x0a\0\x73\x6b\x62\x2d\x3e\x71\x75\x65\x75\x65\x5f\
\x6d\x61\x70\x70\x69\x6e\x67\x20\x25\x64\x0a\0\x64\x65\x76\x2d\x3e\x69\x66\x69\
\x6e\x64\x65\x78\x20\x25\x64\x20\x64\x61\x74\x61\x20\x25\x6c\x6c\x78\x20\x70\
\x6b\x74\x5f\x64\x61\x74\x61\x20\x25\x78\x0a\0\x63\x62\x38\x5f\x30\x3a\x25\x78\
\x20\x63\x62\x33\x32\x5f\x30\x3a\x25\x78\x0a\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\
\x30\0\0\0\x0d\0\0\0\x01\0\0\0\0\0\0\x01\x80\0\0\0\x0d\0\0\0\x01\0\0\0\0\0\0\
\x01\xb8\0\0\0\x0d\0\0\0\x01\0\0\0\0\0\0\x01\xe0\0\0\0\x0d\0\0\0\x01\0\0\0\0\0\
\0\x02\x10\0\0\0\x0d\0\0\0\x01\0\0\0\0\0\0\x02\x88\0\0\0\x0f\0\0\0\x01\0\0\0\0\
\0\0\0\x40\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x68\0\0\0\x11\0\0\0\x01\xeb\x9f\
\x01\0\0\0\0\x18\0\0\0\0\0\0\x04\xac\0\0\x04\xac\0\0\x07\xef\0\0\0\0\x02\0\0\0\
\0\0\0\x03\0\0\0\x01\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\0\x03\0\0\0\0\0\0\0\
\0\0\0\x02\0\0\0\x04\0\0\0\x04\0\0\0\x05\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\
\x02\0\0\0\0\0\0\x02\0\0\0\0\x04\0\0\x03\0\0\0\x18\0\0\0\x19\0\0\0\x01\0\0\0\0\
\0\0\0\x1e\0\0\0\x05\0\0\0\x40\0\0\0\x22\0\0\0\x05\0\0\0\x80\0\0\0\x28\x0e\0\0\
\0\0\0\0\x06\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x09\0\0\0\x35\x01\0\0\0\0\0\0\
\x08\0\0\0\x40\0\0\0\0\x0d\0\0\x01\0\0\0\x02\0\0\0\x48\0\0\0\x08\0\0\0\x4c\x0c\
\0\0\x01\0\0\0\x0a\0\0\0\x5c\x04\0\0\x0a\0\0\0\x58\0\0\0\x64\0\0\0\x0d\0\0\0\0\
\0\0\0\x68\0\0\0\x0d\0\0\0\x20\0\0\0\x71\0\0\0\x0e\0\0\0\x40\0\0\0\x79\0\0\0\
\x0e\0\0\0\x50\0\0\0\x81\0\0\0\x0e\0\0\0\x60\0\0\0\x8f\0\0\0\x10\0\0\0\x80\0\0\
\0\x93\0\0\0\x11\0\0\0\xc0\0\0\0\x99\0\0\0\x15\0\0\x01\0\0\0\0\x9e\0\0\0\x18\0\
\0\x01\x40\0\0\0\xb0\0\0\0\x19\0\0\x01\x40\0\0\0\xb3\x01\0\0\0\0\0\0\x04\0\0\0\
\x20\0\0\0\xc0\x08\0\0\0\0\0\0\x0f\0\0\0\xc6\x01\0\0\0\0\0\0\x02\0\0\0\x10\0\0\
\0\0\x02\0\0\0\0\0\0\x1a\0\0\0\xd5\x08\0\0\0\0\0\0\x12\0\0\0\xe0\x04\0\0\x01\0\
\0\0\x04\0\0\0\xf0\0\0\0\x13\0\0\0\0\0\0\0\xf5\x08\0\0\0\0\0\0\x14\0\0\0\0\x04\
\0\0\x01\0\0\0\x04\0\0\0\xfe\0\0\0\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\x16\0\0\
\x01\x06\x01\0\0\0\0\0\0\x01\0\0\0\x08\0\0\x01\x14\x01\0\0\0\0\0\0\x01\x01\0\0\
\x08\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x17\0\0\0\x04\0\0\0\0\0\0\0\0\x03\0\0\0\0\
\0\0\0\0\0\0\x17\0\0\0\x04\0\0\0\x30\0\0\x01\x19\x04\0\0\x02\0\0\0\x10\0\0\x01\
\x24\0\0\0\x02\0\0\0\0\0\0\x01\x2c\0\0\0\x1b\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\
\x1c\0\0\x01\x34\x04\0\0\x01\0\0\0\x10\0\0\x01\x40\0\0\0\x1d\0\0\0\0\0\0\x01\
\x48\x04\0\0\x02\0\0\0\x10\0\0\x01\x56\0\0\0\x1e\0\0\0\0\0\0\x01\x5b\0\0\0\x1f\
\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x1d\0\0\0\0\x02\0\0\0\0\0\0\x20\0\0\0\0\x0d\
\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x1e\0\0\x01\x60\x0c\0\0\x01\0\0\0\x0a\0\0\x01\
\x76\x0c\0\0\x01\0\0\0\x0a\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x17\0\0\0\x04\0\0\0\
\x04\0\0\x01\x8b\x0e\0\0\0\0\0\0\x23\0\0\0\x01\0\0\0\0\x04\0\0\x02\0\0\0\x02\0\
\0\x01\x94\0\0\0\x26\0\0\0\0\0\0\x01\xa3\0\0\0\x26\0\0\0\x08\0\0\x01\xb1\x01\0\
\0\0\0\0\0\x01\x04\0\0\x08\0\0\x01\xb7\x0e\0\0\0\0\0\0\x25\0\0\0\x01\0\0\0\0\
\x0a\0\0\0\0\0\0\x17\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x28\0\0\0\x04\0\0\0\x1d\0\
\0\x01\xbe\x0e\0\0\0\0\0\0\x29\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x28\0\0\
\0\x04\0\0\0\x22\0\0\x01\xda\x0e\0\0\0\0\0\0\x2b\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\
\0\0\0\0\0\x28\0\0\0\x04\0\0\0\x17\0\0\x01\xf8\x0e\0\0\0\0\0\0\x2d\0\0\0\0\0\0\
\0\0\x03\0\0\0\0\0\0\0\0\0\0\x28\0\0\0\x04\0\0\0\x27\0\0\x02\x16\x0e\0\0\0\0\0\
\0\x2f\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x28\0\0\0\x04\0\0\0\x14\0\0\x02\
\x34\x0e\0\0\0\0\0\0\x31\0\0\0\0\0\0\x07\x98\x0f\0\0\x01\0\0\0\x04\0\0\0\x24\0\
\0\0\0\0\0\0\x04\0\0\x07\xa0\x0f\0\0\x01\0\0\0\x02\0\0\0\x27\0\0\0\0\0\0\0\x02\
\0\0\x07\xa5\x0f\0\0\x01\0\0\0\x18\0\0\0\x07\0\0\0\0\0\0\0\x18\0\0\x07\xab\x0f\
\0\0\x05\0\0\0\x91\0\0\0\x2a\0\0\0\0\0\0\0\x1d\0\0\0\x2c\0\0\0\x1d\0\0\0\x22\0\
\0\0\x2e\0\0\0\x3f\0\0\0\x17\0\0\0\x30\0\0\0\x56\0\0\0\x27\0\0\0\x32\0\0\0\x7d\
\0\0\0\x14\0\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\
\x54\x59\x50\x45\x5f\x5f\0\x74\x79\x70\x65\0\x6b\x65\x79\0\x76\x61\x6c\x75\x65\
\0\x70\x65\x72\x66\x5f\x62\x75\x66\x5f\x6d\x61\x70\0\x75\x6e\x73\x69\x67\x6e\
\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x63\x74\x78\0\x74\x72\x61\
\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\0\x73\x6b\x5f\x62\x75\x66\x66\
\0\x6c\x65\x6e\0\x64\x61\x74\x61\x5f\x6c\x65\x6e\0\x6d\x61\x63\x5f\x6c\x65\x6e\
\0\x68\x64\x72\x5f\x6c\x65\x6e\0\x71\x75\x65\x75\x65\x5f\x6d\x61\x70\x70\x69\
\x6e\x67\0\x64\x65\x76\0\x75\x73\x65\x72\x73\0\x64\x61\x74\x61\0\x5f\x5f\x70\
\x6b\x74\x5f\x74\x79\x70\x65\x5f\x6f\x66\x66\x73\x65\x74\0\x63\x62\0\x75\x6e\
\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x75\x31\x36\0\x75\x6e\x73\
\x69\x67\x6e\x65\x64\x20\x73\x68\x6f\x72\x74\0\x72\x65\x66\x63\x6f\x75\x6e\x74\
\x5f\x74\0\x72\x65\x66\x63\x6f\x75\x6e\x74\x5f\x73\x74\x72\x75\x63\x74\0\x72\
\x65\x66\x73\0\x61\x74\x6f\x6d\x69\x63\x5f\x74\0\x63\x6f\x75\x6e\x74\x65\x72\0\
\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x63\x68\x61\x72\0\x63\x68\x61\x72\0\x6e\
\x65\x74\x5f\x64\x65\x76\x69\x63\x65\0\x69\x66\x69\x6e\x64\x65\x78\0\x69\x66\
\x61\x6c\x69\x61\x73\0\x64\x65\x76\x5f\x69\x66\x61\x6c\x69\x61\x73\0\x72\x63\
\x75\x68\x65\x61\x64\0\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x68\x65\x61\x64\0\
\x6e\x65\x78\x74\0\x66\x75\x6e\x63\0\x66\x65\x6e\x74\x72\x79\x5f\x65\x74\x68\
\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x66\x65\x78\x69\x74\x5f\x65\x74\
\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\0\x5f\x6c\x69\x63\x65\x6e\x73\
\x65\0\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\x5f\x6f\x6b\0\x66\x65\x78\
\x69\x74\x5f\x74\x65\x73\x74\x5f\x6f\x6b\0\x5f\x42\x6f\x6f\x6c\0\x72\x65\x73\
\x75\x6c\x74\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\
\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\
\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\
\x2e\x31\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\
\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\x2e\x32\0\x5f\x5f\x5f\x5f\x74\x72\x61\
\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\
\x74\x2e\x33\0\x5f\x5f\x5f\x5f\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\x65\x5f\
\x73\x6b\x62\x2e\x5f\x5f\x5f\x5f\x66\x6d\x74\x2e\x34\0\x2f\x62\x75\x69\x6c\x64\
\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\
\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\
\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\
\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\
\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\
\x6f\x67\x73\x2f\x6b\x66\x72\x65\x65\x5f\x73\x6b\x62\x2e\x63\0\x69\x6e\x74\x20\
\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x74\x72\x61\x63\x65\x5f\x6b\x66\x72\x65\
\x65\x5f\x73\x6b\x62\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6b\x5f\x62\x75\
\x66\x66\x20\x2a\x73\x6b\x62\x2c\x20\x76\x6f\x69\x64\x20\x2a\x6c\x6f\x63\x61\
\x74\x69\x6f\x6e\x29\0\x09\x73\x74\x72\x75\x63\x74\x20\x6d\x65\x74\x61\x20\x6d\
\x65\x74\x61\x20\x3d\x20\x7b\x7d\x3b\0\x09\x09\x64\x65\x76\x20\x3d\x20\x73\x6b\
\x62\x2d\x3e\x64\x65\x76\x3b\0\x09\x09\x70\x74\x72\x20\x3d\x20\x64\x65\x76\x2d\
\x3e\x69\x66\x61\x6c\x69\x61\x73\x2d\x3e\x72\x63\x75\x68\x65\x61\x64\x2e\x6e\
\x65\x78\x74\x3b\0\x09\x62\x70\x66\x5f\x70\x72\x69\x6e\x74\x6b\x28\x22\x73\x6b\
\x62\x2d\x3e\x6c\x65\x6e\x20\x25\x64\x20\x75\x73\x65\x72\x73\x20\x25\x64\x20\
\x70\x6b\x74\x5f\x74\x79\x70\x65\x20\x25\x78\x5c\x6e\x22\x2c\0\x09\x09\x64\x61\
\x74\x61\x20\x3d\x20\x73\x6b\x62\x2d\x3e\x64\x61\x74\x61\x3b\0\x09\x09\x66\x75\
\x6e\x63\x20\x3d\x20\x70\x74\x72\x2d\x3e\x66\x75\x6e\x63\x3b\0\x09\x62\x70\x66\
\x5f\x70\x72\x69\x6e\x74\x6b\x28\x22\x64\x65\x76\x2d\x3e\x69\x66\x69\x6e\x64\
\x65\x78\x20\x25\x64\x20\x64\x61\x74\x61\x20\x25\x6c\x6c\x78\x20\x70\x6b\x74\
\x5f\x64\x61\x74\x61\x20\x25\x78\x5c\x6e\x22\x2c\0\x09\x6d\x65\x74\x61\x2e\x69\
\x66\x69\x6e\x64\x65\x78\x20\x3d\x20\x5f\x28\x64\x65\x76\x2d\x3e\x69\x66\x69\
\x6e\x64\x65\x78\x29\x3b\0\x09\x6d\x65\x74\x61\x2e\x63\x62\x38\x5f\x30\x20\x3d\
\x20\x63\x62\x38\x5b\x38\x5d\x3b\0\x09\x62\x70\x66\x5f\x70\x72\x69\x6e\x74\x6b\
\x28\x22\x63\x62\x38\x5f\x30\x3a\x25\x78\x20\x63\x62\x33\x32\x5f\x30\x3a\x25\
\x78\x5c\x6e\x22\x2c\x20\x6d\x65\x74\x61\x2e\x63\x62\x38\x5f\x30\x2c\x20\x6d\
\x65\x74\x61\x2e\x63\x62\x33\x32\x5f\x30\x29\x3b\0\x09\x6d\x65\x74\x61\x2e\x63\
\x62\x33\x32\x5f\x30\x20\x3d\x20\x63\x62\x33\x32\x5b\x32\x5d\x3b\0\x09\x62\x70\
\x66\x5f\x70\x72\x6f\x62\x65\x5f\x72\x65\x61\x64\x5f\x6b\x65\x72\x6e\x65\x6c\
\x28\x26\x70\x6b\x74\x5f\x74\x79\x70\x65\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\
\x70\x6b\x74\x5f\x74\x79\x70\x65\x29\x2c\x20\x5f\x28\x26\x73\x6b\x62\x2d\x3e\
\x5f\x5f\x70\x6b\x74\x5f\x74\x79\x70\x65\x5f\x6f\x66\x66\x73\x65\x74\x29\x29\
\x3b\0\x09\x70\x6b\x74\x5f\x74\x79\x70\x65\x20\x26\x3d\x20\x37\x3b\0\x09\x62\
\x70\x66\x5f\x70\x72\x6f\x62\x65\x5f\x72\x65\x61\x64\x5f\x6b\x65\x72\x6e\x65\
\x6c\x28\x26\x70\x6b\x74\x5f\x64\x61\x74\x61\x2c\x20\x73\x69\x7a\x65\x6f\x66\
\x28\x70\x6b\x74\x5f\x64\x61\x74\x61\x29\x2c\x20\x64\x61\x74\x61\x20\x2b\x20\
\x31\x32\x29\x3b\0\x09\x62\x70\x66\x5f\x70\x72\x69\x6e\x74\x6b\x28\x22\x72\x63\
\x75\x68\x65\x61\x64\x2e\x6e\x65\x78\x74\x20\x25\x6c\x6c\x78\x20\x66\x75\x6e\
\x63\x20\x25\x6c\x6c\x78\x5c\x6e\x22\x2c\x20\x70\x74\x72\x2c\x20\x66\x75\x6e\
\x63\x29\x3b\0\x09\x62\x70\x66\x5f\x70\x72\x69\x6e\x74\x6b\x28\x22\x73\x6b\x62\
\x2d\x3e\x71\x75\x65\x75\x65\x5f\x6d\x61\x70\x70\x69\x6e\x67\x20\x25\x64\x5c\
\x6e\x22\x2c\x20\x5f\x28\x73\x6b\x62\x2d\x3e\x71\x75\x65\x75\x65\x5f\x6d\x61\
\x70\x70\x69\x6e\x67\x29\x29\x3b\0\x09\x69\x66\x20\x28\x75\x73\x65\x72\x73\x20\
\x21\x3d\x20\x31\x20\x7c\x7c\x20\x70\x6b\x74\x5f\x64\x61\x74\x61\x20\x21\x3d\
\x20\x62\x70\x66\x5f\x68\x74\x6f\x6e\x73\x28\x30\x78\x38\x36\x64\x64\x29\x20\
\x7c\x7c\x20\x6d\x65\x74\x61\x2e\x69\x66\x69\x6e\x64\x65\x78\x20\x21\x3d\x20\
\x31\x29\0\x09\x62\x70\x66\x5f\x73\x6b\x62\x5f\x6f\x75\x74\x70\x75\x74\x28\x73\
\x6b\x62\x2c\x20\x26\x70\x65\x72\x66\x5f\x62\x75\x66\x5f\x6d\x61\x70\x2c\x20\
\x28\x37\x32\x75\x6c\x6c\x20\x3c\x3c\x20\x33\x32\x29\x20\x7c\x20\x42\x50\x46\
\x5f\x46\x5f\x43\x55\x52\x52\x45\x4e\x54\x5f\x43\x50\x55\x2c\0\x69\x6e\x74\x20\
\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x66\x65\x6e\x74\x72\x79\x5f\x65\x74\x68\
\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\x2c\x20\x73\x74\x72\x75\x63\x74\
\x20\x73\x6b\x5f\x62\x75\x66\x66\x20\x2a\x73\x6b\x62\x2c\x20\x73\x74\x72\x75\
\x63\x74\x20\x6e\x65\x74\x5f\x64\x65\x76\x69\x63\x65\x20\x2a\x64\x65\x76\x2c\0\
\x09\x69\x66\x20\x28\x6c\x65\x6e\x20\x21\x3d\x20\x37\x34\x20\x7c\x7c\x20\x69\
\x66\x69\x6e\x64\x65\x78\x20\x21\x3d\x20\x31\x29\0\x09\x09\x6c\x65\x6e\x20\x3d\
\x20\x73\x6b\x62\x2d\x3e\x6c\x65\x6e\x3b\0\x09\x72\x65\x73\x75\x6c\x74\x2e\x66\
\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\x5f\x6f\x6b\x20\x3d\x20\x74\x72\x75\
\x65\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x66\x65\x78\x69\
\x74\x5f\x65\x74\x68\x5f\x74\x79\x70\x65\x5f\x74\x72\x61\x6e\x73\x2c\x20\x73\
\x74\x72\x75\x63\x74\x20\x73\x6b\x5f\x62\x75\x66\x66\x20\x2a\x73\x6b\x62\x2c\
\x20\x73\x74\x72\x75\x63\x74\x20\x6e\x65\x74\x5f\x64\x65\x76\x69\x63\x65\x20\
\x2a\x64\x65\x76\x2c\0\x09\x69\x66\x20\x28\x6c\x65\x6e\x20\x21\x3d\x20\x36\x30\
\x20\x7c\x7c\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x21\x3d\x20\x62\x70\x66\
\x5f\x68\x74\x6f\x6e\x73\x28\x30\x78\x38\x36\x64\x64\x29\x20\x7c\x7c\x20\x69\
\x66\x69\x6e\x64\x65\x78\x20\x21\x3d\x20\x31\x29\0\x09\x72\x65\x73\x75\x6c\x74\
\x2e\x66\x65\x78\x69\x74\x5f\x74\x65\x73\x74\x5f\x6f\x6b\x20\x3d\x20\x74\x72\
\x75\x65\x3b\0\x30\x3a\x35\0\x30\x3a\x31\0\x30\x3a\x39\0\x30\x3a\x36\x3a\x30\
\x3a\x30\0\x30\x3a\x37\0\x30\x3a\x30\x3a\x30\0\x30\x3a\x30\0\x30\x3a\x38\0\x30\
\x3a\x34\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x6d\x61\x70\x73\
\0\x2e\x72\x6f\x64\x61\x74\x61\0\x74\x70\x5f\x62\x74\x66\x2f\x6b\x66\x72\x65\
\x65\x5f\x73\x6b\x62\0\x66\x65\x6e\x74\x72\x79\x2f\x65\x74\x68\x5f\x74\x79\x70\
\x65\x5f\x74\x72\x61\x6e\x73\0\x66\x65\x78\x69\x74\x2f\x65\x74\x68\x5f\x74\x79\
\x70\x65\x5f\x74\x72\x61\x6e\x73\0\0\0\0\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\
\0\0\x34\0\0\0\x34\0\0\x02\xac\0\0\x02\xe0\0\0\x01\x0c\0\0\0\x08\0\0\x07\xb3\0\
\0\0\x01\0\0\0\0\0\0\0\x0b\0\0\x07\xc4\0\0\0\x01\0\0\0\0\0\0\0\x21\0\0\x07\xda\
\0\0\0\x01\0\0\0\0\0\0\0\x22\0\0\0\x10\0\0\x07\xb3\0\0\0\x1c\0\0\0\0\0\0\x02\
\x52\0\0\x02\xc7\0\0\xf4\x05\0\0\0\x10\0\0\x02\x52\0\0\x03\x0a\0\x01\x14\x0e\0\
\0\0\x18\0\0\x02\x52\0\0\x03\x22\0\x01\x34\x0e\0\0\0\x20\0\0\x02\x52\0\0\x03\
\x34\0\x01\x38\x0e\0\0\0\x30\0\0\x02\x52\0\0\x03\x58\0\x01\x7c\x02\0\0\0\x38\0\
\0\x02\x52\0\0\x03\x8a\0\x01\x30\x0f\0\0\0\x58\0\0\x02\x52\0\0\x03\x34\0\x01\
\x38\x1f\0\0\0\x60\0\0\x02\x52\0\0\x03\x9e\0\x01\x3c\x0f\0\0\0\x68\0\0\x02\x52\
\0\0\x03\xb2\0\x01\x88\x02\0\0\0\x78\0\0\x02\x52\0\0\x03\xe9\0\x01\x50\x0f\0\0\
\0\x80\0\0\x02\x52\0\0\x04\x0a\0\x01\x54\x0f\0\0\0\x88\0\0\x02\x52\0\0\x04\x0a\
\0\x01\x54\x0d\0\0\0\x98\0\0\x02\x52\0\0\x04\x20\0\x01\x90\x02\0\0\0\xa0\0\0\
\x02\x52\0\0\x04\x5e\0\x01\x58\x0e\0\0\0\xd0\0\0\x02\x52\0\0\0\0\0\0\0\0\0\0\0\
\xd8\0\0\x02\x52\0\0\x04\x76\0\x01\x60\x02\0\0\0\xe8\0\0\x02\x52\0\0\x04\xc7\0\
\x01\x64\x0b\0\0\x01\x08\0\0\x02\x52\0\0\0\0\0\0\0\0\0\0\x01\x10\0\0\x02\x52\0\
\0\x04\xd7\0\x01\x70\x3a\0\0\x01\x20\0\0\x02\x52\0\0\x04\xd7\0\x01\x70\x02\0\0\
\x01\x30\0\0\x02\x52\0\0\x05\x17\0\x01\x78\x02\0\0\x01\x60\0\0\x02\x52\0\0\x03\
\x58\0\x01\x7c\x02\0\0\x01\xb0\0\0\x02\x52\0\0\x05\x50\0\x01\x84\x02\0\0\x01\
\xd8\0\0\x02\x52\0\0\x03\xb2\0\x01\x88\x02\0\0\x02\x10\0\0\x02\x52\0\0\x04\x20\
\0\x01\x90\x02\0\0\x02\x40\0\0\x02\x52\0\0\x05\x8f\0\x01\x98\x11\0\0\x02\x78\0\
\0\x02\x52\0\0\x05\xd6\0\x01\xac\x02\0\0\x02\xb8\0\0\x02\x52\0\0\x02\xc7\0\0\
\xf4\x05\0\0\x07\xc4\0\0\0\x06\0\0\0\0\0\0\x02\x52\0\0\x06\x1d\0\x01\xd8\x05\0\
\0\0\x10\0\0\x02\x52\0\0\x06\x6e\0\x02\x04\x10\0\0\0\x18\0\0\x02\x52\0\0\x06\
\x8e\0\x01\xf0\x0e\0\0\0\x20\0\0\x02\x52\0\0\x06\x6e\0\x02\x04\x10\0\0\0\x40\0\
\0\x02\x52\0\0\x06\xa0\0\x02\x0c\x18\0\0\0\x60\0\0\x02\x52\0\0\x06\x1d\0\x01\
\xd8\x05\0\0\x07\xda\0\0\0\x07\0\0\0\0\0\0\x02\x52\0\0\x06\xbf\0\x02\x20\x05\0\
\0\0\x10\0\0\x02\x52\0\0\x07\x0f\0\x02\x54\x10\0\0\0\x20\0\0\x02\x52\0\0\x06\
\xbf\0\x02\x20\x05\0\0\0\x28\0\0\x02\x52\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\x02\x52\
\0\0\x07\x0f\0\x02\x54\x10\0\0\0\x68\0\0\x02\x52\0\0\x07\x50\0\x02\x5c\x17\0\0\
\0\x88\0\0\x02\x52\0\0\x06\xbf\0\x02\x20\x05\0\0\0\x10\0\0\x07\xb3\0\0\0\x0b\0\
\0\0\x18\0\0\0\x0c\0\0\x07\x6e\0\0\0\0\0\0\0\x20\0\0\0\x1a\0\0\x07\x72\0\0\0\0\
\0\0\0\x28\0\0\0\x0c\0\0\x07\x76\0\0\0\0\0\0\0\x30\0\0\0\x0c\0\0\x07\x7a\0\0\0\
\0\0\0\0\x40\0\0\0\x0c\0\0\x07\x82\0\0\0\0\0\0\0\x58\0\0\0\x1c\0\0\x07\x86\0\0\
\0\0\0\0\0\x60\0\0\0\x1d\0\0\x07\x72\0\0\0\0\0\0\0\x70\0\0\0\x1a\0\0\x07\x8c\0\
\0\0\0\0\0\0\xb0\0\0\0\x0c\0\0\x07\x90\0\0\0\0\0\0\x01\x60\0\0\0\x0c\0\0\x07\
\x8c\0\0\0\0\0\0\x01\xb0\0\0\0\x0c\0\0\x07\x94\0\0\0\0\0\0\x07\xc4\0\0\0\x02\0\
\0\0\x10\0\0\0\x1a\0\0\x07\x8c\0\0\0\0\0\0\0\x18\0\0\0\x0c\0\0\x07\x8c\0\0\0\0\
\0\0\x07\xda\0\0\0\x02\0\0\0\x10\0\0\0\x1a\0\0\x07\x8c\0\0\0\0\0\0\0\x18\0\0\0\
\x0c\0\0\x07\x8c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\
\0\0\0\0\0\x01\xcb\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\
\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x10\0\0\0\0\0\0\x01\
\xe0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\
\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\xf0\0\0\0\0\0\0\x02\xc8\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x01\0\0\0\0\0\0\
\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x06\xb8\0\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x38\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x07\x28\0\0\0\0\0\0\0\x98\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\0\0\0\0\x4d\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x07\xc0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\x55\0\0\0\x08\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\
\xc4\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\
\x5a\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\xc8\0\0\0\0\0\
\0\0\x18\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\x01\
\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\xe0\0\0\0\0\0\0\0\x91\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x01\x75\0\0\0\x09\0\0\0\0\0\0\
\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x78\0\0\0\0\0\0\0\x60\0\0\0\x02\0\0\0\
\x03\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\x8a\0\0\0\x09\0\0\0\0\0\0\0\
\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\xd8\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x04\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\xa4\0\0\0\x09\0\0\0\0\0\0\0\x40\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\xe8\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x05\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\xbd\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x08\xf8\0\0\0\0\0\0\x0c\xb3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\0\0\0\x01\xc2\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x15\xb0\0\0\0\0\0\0\x04\x0c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\0";
}

#ifdef __cplusplus
struct kfree_skb *kfree_skb::open(const struct bpf_object_open_opts *opts) { return kfree_skb__open_opts(opts); }
struct kfree_skb *kfree_skb::open_and_load() { return kfree_skb__open_and_load(); }
int kfree_skb::load(struct kfree_skb *skel) { return kfree_skb__load(skel); }
int kfree_skb::attach(struct kfree_skb *skel) { return kfree_skb__attach(skel); }
void kfree_skb::detach(struct kfree_skb *skel) { kfree_skb__detach(skel); }
void kfree_skb::destroy(struct kfree_skb *skel) { kfree_skb__destroy(skel); }
const void *kfree_skb::elf_bytes(size_t *sz) { return kfree_skb__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
kfree_skb__assert(struct kfree_skb *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->result) == 2, "unexpected size of 'result'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __KFREE_SKB_SKEL_H__ */
