/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TEST_ATTACH_PROBE_SKEL_H__
#define __TEST_ATTACH_PROBE_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct test_attach_probe {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *handle_kprobe;
		struct bpf_program *handle_kretprobe;
		struct bpf_program *handle_uprobe;
		struct bpf_program *handle_uretprobe;
	} progs;
	struct {
		struct bpf_link *handle_kprobe;
		struct bpf_link *handle_kretprobe;
		struct bpf_link *handle_uprobe;
		struct bpf_link *handle_uretprobe;
	} links;
	struct test_attach_probe__bss {
		int kprobe_res;
		int kretprobe_res;
		int uprobe_res;
		int uretprobe_res;
	} *bss;

#ifdef __cplusplus
	static inline struct test_attach_probe *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct test_attach_probe *open_and_load();
	static inline int load(struct test_attach_probe *skel);
	static inline int attach(struct test_attach_probe *skel);
	static inline void detach(struct test_attach_probe *skel);
	static inline void destroy(struct test_attach_probe *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
test_attach_probe__destroy(struct test_attach_probe *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_attach_probe__create_skeleton(struct test_attach_probe *obj);

static inline struct test_attach_probe *
test_attach_probe__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_attach_probe *obj;
	int err;

	obj = (struct test_attach_probe *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = test_attach_probe__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	test_attach_probe__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct test_attach_probe *
test_attach_probe__open(void)
{
	return test_attach_probe__open_opts(NULL);
}

static inline int
test_attach_probe__load(struct test_attach_probe *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_attach_probe *
test_attach_probe__open_and_load(void)
{
	struct test_attach_probe *obj;
	int err;

	obj = test_attach_probe__open();
	if (!obj)
		return NULL;
	err = test_attach_probe__load(obj);
	if (err) {
		test_attach_probe__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
test_attach_probe__attach(struct test_attach_probe *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_attach_probe__detach(struct test_attach_probe *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *test_attach_probe__elf_bytes(size_t *sz);

static inline int
test_attach_probe__create_skeleton(struct test_attach_probe *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "test_attach_probe";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 1;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "test_att.bss";
	s->maps[0].map = &obj->maps.bss;
	s->maps[0].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 4;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "handle_kprobe";
	s->progs[0].prog = &obj->progs.handle_kprobe;
	s->progs[0].link = &obj->links.handle_kprobe;

	s->progs[1].name = "handle_kretprobe";
	s->progs[1].prog = &obj->progs.handle_kretprobe;
	s->progs[1].link = &obj->links.handle_kretprobe;

	s->progs[2].name = "handle_uprobe";
	s->progs[2].prog = &obj->progs.handle_uprobe;
	s->progs[2].link = &obj->links.handle_uprobe;

	s->progs[3].name = "handle_uretprobe";
	s->progs[3].prog = &obj->progs.handle_uretprobe;
	s->progs[3].link = &obj->links.handle_uretprobe;

	s->data = (void *)test_attach_probe__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *test_attach_probe__elf_bytes(size_t *sz)
{
	*sz = 3160;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x98\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0f\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x6b\x70\x72\
\x6f\x62\x65\x2f\x73\x79\x73\x5f\x6e\x61\x6e\x6f\x73\x6c\x65\x65\x70\0\x6b\x72\
\x65\x74\x70\x72\x6f\x62\x65\x2f\x73\x79\x73\x5f\x6e\x61\x6e\x6f\x73\x6c\x65\
\x65\x70\0\x75\x70\x72\x6f\x62\x65\x2f\x74\x72\x69\x67\x67\x65\x72\x5f\x66\x75\
\x6e\x63\0\x75\x72\x65\x74\x70\x72\x6f\x62\x65\x2f\x74\x72\x69\x67\x67\x65\x72\
\x5f\x66\x75\x6e\x63\0\x2e\x62\x73\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x74\x65\
\x73\x74\x5f\x61\x74\x74\x61\x63\x68\x5f\x70\x72\x6f\x62\x65\x2e\x63\0\x68\x61\
\x6e\x64\x6c\x65\x5f\x6b\x70\x72\x6f\x62\x65\0\x6b\x70\x72\x6f\x62\x65\x5f\x72\
\x65\x73\0\x68\x61\x6e\x64\x6c\x65\x5f\x6b\x72\x65\x74\x70\x72\x6f\x62\x65\0\
\x6b\x72\x65\x74\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\0\x68\x61\x6e\x64\x6c\x65\
\x5f\x75\x70\x72\x6f\x62\x65\0\x75\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\0\x68\
\x61\x6e\x64\x6c\x65\x5f\x75\x72\x65\x74\x70\x72\x6f\x62\x65\0\x75\x72\x65\x74\
\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\
\x72\x65\x6c\x6b\x70\x72\x6f\x62\x65\x2f\x73\x79\x73\x5f\x6e\x61\x6e\x6f\x73\
\x6c\x65\x65\x70\0\x2e\x72\x65\x6c\x6b\x72\x65\x74\x70\x72\x6f\x62\x65\x2f\x73\
\x79\x73\x5f\x6e\x61\x6e\x6f\x73\x6c\x65\x65\x70\0\x2e\x72\x65\x6c\x75\x70\x72\
\x6f\x62\x65\x2f\x74\x72\x69\x67\x67\x65\x72\x5f\x66\x75\x6e\x63\0\x2e\x72\x65\
\x6c\x75\x72\x65\x74\x70\x72\x6f\x62\x65\x2f\x74\x72\x69\x67\x67\x65\x72\x5f\
\x66\x75\x6e\x63\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x76\x04\0\xff\xf1\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x05\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x8a\x12\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\0\x98\x11\0\
\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xa3\x12\0\0\x04\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x30\0\0\0\xb4\x11\0\0\x07\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x04\0\
\0\0\xc2\x12\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\0\xd0\x11\0\0\x07\0\
\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x04\0\0\0\xdb\x12\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x30\0\0\0\xec\x11\0\0\x07\0\0\0\0\0\0\0\x0c\0\0\0\0\0\0\0\x04\0\0\0\
\xfa\x11\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x18\x10\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xb7\x20\0\0\0\0\0\x01\x63\x12\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\
\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x02\x63\x12\0\0\
\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xb7\x20\0\0\0\0\0\x03\x63\x12\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\
\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x04\x63\x12\0\0\0\0\0\
\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x07\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\
\x0b\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x0d\0\0\0\x01\xeb\x9f\x01\0\0\0\0\x18\0\0\
\0\0\0\0\x01\x48\0\0\x01\x48\0\0\x01\xfe\0\0\0\0\x02\0\0\0\0\0\0\x02\0\0\0\x01\
\x07\0\0\0\0\0\0\0\0\0\0\0\x0d\0\0\x01\0\0\0\x04\0\0\0\x09\0\0\0\x01\0\0\0\x0d\
\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\x11\x0c\0\0\x01\0\0\0\x03\0\0\0\x1f\x0c\
\0\0\x01\0\0\0\x03\0\0\0\x30\x0c\0\0\x01\0\0\0\x03\0\0\0\x3e\x0c\0\0\x01\0\0\0\
\x03\0\0\0\x4f\x0e\0\0\0\0\0\0\x04\0\0\0\x01\0\0\0\x5a\x0e\0\0\0\0\0\0\x04\0\0\
\0\x01\0\0\0\x68\x0e\0\0\0\0\0\0\x04\0\0\0\x01\0\0\0\x73\x0e\0\0\0\0\0\0\x04\0\
\0\0\x01\0\0\0\x81\x01\0\0\0\0\0\0\x01\x01\0\0\x08\0\0\0\0\x03\0\0\0\0\0\0\0\0\
\0\0\x0d\0\0\0\x0f\0\0\0\x04\0\0\0\x86\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\x9a\
\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x01\x99\x0f\0\0\x04\0\0\0\x10\0\0\0\x09\0\0\
\0\0\0\0\0\x04\0\0\0\x0a\0\0\0\x04\0\0\0\x04\0\0\0\x0b\0\0\0\x08\0\0\0\x04\0\0\
\0\x0c\0\0\0\x0c\0\0\0\x04\0\0\x01\x9e\x0f\0\0\x01\0\0\0\x04\0\0\0\x10\0\0\0\0\
\0\0\0\x04\0\x70\x74\x5f\x72\x65\x67\x73\0\x63\x74\x78\0\x69\x6e\x74\0\x68\x61\
\x6e\x64\x6c\x65\x5f\x6b\x70\x72\x6f\x62\x65\0\x68\x61\x6e\x64\x6c\x65\x5f\x6b\
\x72\x65\x74\x70\x72\x6f\x62\x65\0\x68\x61\x6e\x64\x6c\x65\x5f\x75\x70\x72\x6f\
\x62\x65\0\x68\x61\x6e\x64\x6c\x65\x5f\x75\x72\x65\x74\x70\x72\x6f\x62\x65\0\
\x6b\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\0\x6b\x72\x65\x74\x70\x72\x6f\x62\x65\
\x5f\x72\x65\x73\0\x75\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\0\x75\x72\x65\x74\
\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\
\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x5f\x6c\x69\x63\x65\
\x6e\x73\x65\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\
\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\
\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\
\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\
\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\
\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x74\x65\x73\x74\x5f\x61\
\x74\x74\x61\x63\x68\x5f\x70\x72\x6f\x62\x65\x2e\x63\0\x09\x6b\x70\x72\x6f\x62\
\x65\x5f\x72\x65\x73\x20\x3d\x20\x31\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x30\
\x3b\0\x09\x6b\x72\x65\x74\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\x20\x3d\x20\x32\
\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x4b\x52\x45\x54\x50\x52\x4f\x42\x45\x28\
\x68\x61\x6e\x64\x6c\x65\x5f\x6b\x72\x65\x74\x70\x72\x6f\x62\x65\x29\0\x09\x75\
\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\x20\x3d\x20\x33\x3b\0\x09\x75\x72\x65\x74\
\x70\x72\x6f\x62\x65\x5f\x72\x65\x73\x20\x3d\x20\x34\x3b\0\x2e\x62\x73\x73\0\
\x6c\x69\x63\x65\x6e\x73\x65\0\x6b\x70\x72\x6f\x62\x65\x2f\x73\x79\x73\x5f\x6e\
\x61\x6e\x6f\x73\x6c\x65\x65\x70\0\x6b\x72\x65\x74\x70\x72\x6f\x62\x65\x2f\x73\
\x79\x73\x5f\x6e\x61\x6e\x6f\x73\x6c\x65\x65\x70\0\x75\x70\x72\x6f\x62\x65\x2f\
\x74\x72\x69\x67\x67\x65\x72\x5f\x66\x75\x6e\x63\0\x75\x72\x65\x74\x70\x72\x6f\
\x62\x65\x2f\x74\x72\x69\x67\x67\x65\x72\x5f\x66\x75\x6e\x63\0\0\0\xeb\x9f\x01\
\0\0\0\0\x20\0\0\0\0\0\0\0\x44\0\0\0\x44\0\0\0\xa4\0\0\0\xe8\0\0\0\0\0\0\0\x08\
\0\0\x01\xa6\0\0\0\x01\0\0\0\0\0\0\0\x05\0\0\x01\xbb\0\0\0\x01\0\0\0\0\0\0\0\
\x06\0\0\x01\xd3\0\0\0\x01\0\0\0\0\0\0\0\x07\0\0\x01\xe7\0\0\0\x01\0\0\0\0\0\0\
\0\x08\0\0\0\x10\0\0\x01\xa6\0\0\0\x02\0\0\0\0\0\0\0\xa3\0\0\x01\x20\0\0\x44\
\x0d\0\0\0\x20\0\0\0\xa3\0\0\x01\x31\0\0\x48\x02\0\0\x01\xbb\0\0\0\x02\0\0\0\0\
\0\0\0\xa3\0\0\x01\x3c\0\0\x60\x10\0\0\0\x20\0\0\0\xa3\0\0\x01\x50\0\0\x58\x05\
\0\0\x01\xd3\0\0\0\x02\0\0\0\0\0\0\0\xa3\0\0\x01\x74\0\0\x7c\x0d\0\0\0\x20\0\0\
\0\xa3\0\0\x01\x31\0\0\x80\x02\0\0\x01\xe7\0\0\0\x02\0\0\0\0\0\0\0\xa3\0\0\x01\
\x85\0\0\x98\x10\0\0\0\x20\0\0\0\xa3\0\0\x01\x31\0\0\x9c\x02\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\x20\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\x01\x79\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x01\xc0\0\0\0\0\0\0\x01\x68\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\x28\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\0\x26\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x58\0\0\0\
\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x3e\0\0\0\
\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x88\0\0\0\0\0\0\0\x30\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x52\0\0\0\x01\0\0\0\0\0\
\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\xb8\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x69\0\0\0\x08\0\0\0\0\0\0\0\x03\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x03\xe8\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x04\0\0\0\0\0\0\0\0\0\0\0\x6e\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x03\xe8\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\x01\x03\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\
\xf0\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x03\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\
\0\0\x01\x1c\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\
\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x04\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\
\x38\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x10\0\0\0\0\0\
\0\0\x10\0\0\0\x02\0\0\0\x05\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\x50\0\
\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x20\0\0\0\0\0\0\0\
\x10\0\0\0\x02\0\0\0\x06\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\x6b\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x30\0\0\0\0\0\0\x03\x5e\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x01\x70\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\x90\0\0\0\0\0\0\x01\x08\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct test_attach_probe *test_attach_probe::open(const struct bpf_object_open_opts *opts) { return test_attach_probe__open_opts(opts); }
struct test_attach_probe *test_attach_probe::open_and_load() { return test_attach_probe__open_and_load(); }
int test_attach_probe::load(struct test_attach_probe *skel) { return test_attach_probe__load(skel); }
int test_attach_probe::attach(struct test_attach_probe *skel) { return test_attach_probe__attach(skel); }
void test_attach_probe::detach(struct test_attach_probe *skel) { test_attach_probe__detach(skel); }
void test_attach_probe::destroy(struct test_attach_probe *skel) { test_attach_probe__destroy(skel); }
const void *test_attach_probe::elf_bytes(size_t *sz) { return test_attach_probe__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
test_attach_probe__assert(struct test_attach_probe *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->kprobe_res) == 4, "unexpected size of 'kprobe_res'");
	_Static_assert(sizeof(s->bss->kretprobe_res) == 4, "unexpected size of 'kretprobe_res'");
	_Static_assert(sizeof(s->bss->uprobe_res) == 4, "unexpected size of 'uprobe_res'");
	_Static_assert(sizeof(s->bss->uretprobe_res) == 4, "unexpected size of 'uretprobe_res'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __TEST_ATTACH_PROBE_SKEL_H__ */
