/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TEST_MODULE_ATTACH_SKEL_H__
#define __TEST_MODULE_ATTACH_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct test_module_attach {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *handle_raw_tp;
		struct bpf_program *handle_raw_tp_bare;
		struct bpf_program *handle_raw_tp_writable_bare;
		struct bpf_program *handle_tp_btf;
		struct bpf_program *handle_fentry;
		struct bpf_program *handle_fentry_manual;
		struct bpf_program *handle_fexit;
		struct bpf_program *handle_fexit_ret;
		struct bpf_program *handle_fmod_ret;
	} progs;
	struct {
		struct bpf_link *handle_raw_tp;
		struct bpf_link *handle_raw_tp_bare;
		struct bpf_link *handle_raw_tp_writable_bare;
		struct bpf_link *handle_tp_btf;
		struct bpf_link *handle_fentry;
		struct bpf_link *handle_fentry_manual;
		struct bpf_link *handle_fexit;
		struct bpf_link *handle_fexit_ret;
		struct bpf_link *handle_fmod_ret;
	} links;
	struct test_module_attach__bss {
		__u32 raw_tp_read_sz;
		__u32 raw_tp_bare_write_sz;
		int raw_tp_writable_bare_in_val;
		int raw_tp_writable_bare_early_ret;
		int raw_tp_writable_bare_out_val;
		__u32 tp_btf_read_sz;
		__u32 fentry_read_sz;
		__u32 fentry_manual_read_sz;
		__u32 fexit_read_sz;
		int fexit_ret;
		__u32 fmod_ret_read_sz;
	} *bss;

#ifdef __cplusplus
	static inline struct test_module_attach *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct test_module_attach *open_and_load();
	static inline int load(struct test_module_attach *skel);
	static inline int attach(struct test_module_attach *skel);
	static inline void detach(struct test_module_attach *skel);
	static inline void destroy(struct test_module_attach *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
test_module_attach__destroy(struct test_module_attach *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_module_attach__create_skeleton(struct test_module_attach *obj);

static inline struct test_module_attach *
test_module_attach__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_module_attach *obj;
	int err;

	obj = (struct test_module_attach *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = test_module_attach__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	test_module_attach__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct test_module_attach *
test_module_attach__open(void)
{
	return test_module_attach__open_opts(NULL);
}

static inline int
test_module_attach__load(struct test_module_attach *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_module_attach *
test_module_attach__open_and_load(void)
{
	struct test_module_attach *obj;
	int err;

	obj = test_module_attach__open();
	if (!obj)
		return NULL;
	err = test_module_attach__load(obj);
	if (err) {
		test_module_attach__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
test_module_attach__attach(struct test_module_attach *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_module_attach__detach(struct test_module_attach *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *test_module_attach__elf_bytes(size_t *sz);

static inline int
test_module_attach__create_skeleton(struct test_module_attach *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "test_module_attach";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 1;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "test_mod.bss";
	s->maps[0].map = &obj->maps.bss;
	s->maps[0].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 9;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "handle_raw_tp";
	s->progs[0].prog = &obj->progs.handle_raw_tp;
	s->progs[0].link = &obj->links.handle_raw_tp;

	s->progs[1].name = "handle_raw_tp_bare";
	s->progs[1].prog = &obj->progs.handle_raw_tp_bare;
	s->progs[1].link = &obj->links.handle_raw_tp_bare;

	s->progs[2].name = "handle_raw_tp_writable_bare";
	s->progs[2].prog = &obj->progs.handle_raw_tp_writable_bare;
	s->progs[2].link = &obj->links.handle_raw_tp_writable_bare;

	s->progs[3].name = "handle_tp_btf";
	s->progs[3].prog = &obj->progs.handle_tp_btf;
	s->progs[3].link = &obj->links.handle_tp_btf;

	s->progs[4].name = "handle_fentry";
	s->progs[4].prog = &obj->progs.handle_fentry;
	s->progs[4].link = &obj->links.handle_fentry;

	s->progs[5].name = "handle_fentry_manual";
	s->progs[5].prog = &obj->progs.handle_fentry_manual;
	s->progs[5].link = &obj->links.handle_fentry_manual;

	s->progs[6].name = "handle_fexit";
	s->progs[6].prog = &obj->progs.handle_fexit;
	s->progs[6].link = &obj->links.handle_fexit;

	s->progs[7].name = "handle_fexit_ret";
	s->progs[7].prog = &obj->progs.handle_fexit_ret;
	s->progs[7].link = &obj->links.handle_fexit_ret;

	s->progs[8].name = "handle_fmod_ret";
	s->progs[8].prog = &obj->progs.handle_fmod_ret;
	s->progs[8].link = &obj->links.handle_fmod_ret;

	s->data = (void *)test_module_attach__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *test_module_attach__elf_bytes(size_t *sz)
{
	*sz = 10440;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\xc8\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x18\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x72\x61\x77\
\x5f\x74\x70\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\
\x74\x5f\x72\x65\x61\x64\0\x72\x61\x77\x5f\x74\x70\x2f\x62\x70\x66\x5f\x74\x65\
\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x77\x72\x69\x74\x65\x5f\x62\x61\
\x72\x65\0\x72\x61\x77\x5f\x74\x70\x2e\x77\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\
\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x77\x72\x69\x74\x61\x62\x6c\x65\x5f\x62\
\x61\x72\x65\0\x74\x70\x5f\x62\x74\x66\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\
\x6f\x64\x5f\x74\x65\x73\x74\x5f\x72\x65\x61\x64\0\x66\x65\x6e\x74\x72\x79\x2f\
\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x72\x65\
\x61\x64\0\x66\x65\x6e\x74\x72\x79\x2f\x70\x6c\x61\x63\x65\x68\x6f\x6c\x64\x65\
\x72\0\x66\x65\x78\x69\x74\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\
\x74\x65\x73\x74\x5f\x72\x65\x61\x64\0\x66\x65\x78\x69\x74\x2f\x62\x70\x66\x5f\
\x74\x65\x73\x74\x6d\x6f\x64\x5f\x72\x65\x74\x75\x72\x6e\x5f\x70\x74\x72\0\x66\
\x6d\x6f\x64\x5f\x72\x65\x74\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\
\x5f\x74\x65\x73\x74\x5f\x72\x65\x61\x64\0\x2e\x62\x73\x73\0\x6c\x69\x63\x65\
\x6e\x73\x65\0\x74\x65\x73\x74\x5f\x6d\x6f\x64\x75\x6c\x65\x5f\x61\x74\x74\x61\
\x63\x68\x2e\x63\0\x4c\x42\x42\x32\x5f\x32\0\x68\x61\x6e\x64\x6c\x65\x5f\x72\
\x61\x77\x5f\x74\x70\0\x72\x61\x77\x5f\x74\x70\x5f\x72\x65\x61\x64\x5f\x73\x7a\
\0\x68\x61\x6e\x64\x6c\x65\x5f\x72\x61\x77\x5f\x74\x70\x5f\x62\x61\x72\x65\0\
\x72\x61\x77\x5f\x74\x70\x5f\x62\x61\x72\x65\x5f\x77\x72\x69\x74\x65\x5f\x73\
\x7a\0\x68\x61\x6e\x64\x6c\x65\x5f\x72\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\x74\
\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\0\x72\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\
\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\x5f\x69\x6e\x5f\x76\x61\x6c\0\x72\x61\
\x77\x5f\x74\x70\x5f\x77\x72\x69\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\x5f\
\x65\x61\x72\x6c\x79\x5f\x72\x65\x74\0\x72\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\
\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\x5f\x6f\x75\x74\x5f\x76\x61\x6c\0\x68\
\x61\x6e\x64\x6c\x65\x5f\x74\x70\x5f\x62\x74\x66\0\x74\x70\x5f\x62\x74\x66\x5f\
\x72\x65\x61\x64\x5f\x73\x7a\0\x68\x61\x6e\x64\x6c\x65\x5f\x66\x65\x6e\x74\x72\
\x79\0\x66\x65\x6e\x74\x72\x79\x5f\x72\x65\x61\x64\x5f\x73\x7a\0\x68\x61\x6e\
\x64\x6c\x65\x5f\x66\x65\x6e\x74\x72\x79\x5f\x6d\x61\x6e\x75\x61\x6c\0\x66\x65\
\x6e\x74\x72\x79\x5f\x6d\x61\x6e\x75\x61\x6c\x5f\x72\x65\x61\x64\x5f\x73\x7a\0\
\x68\x61\x6e\x64\x6c\x65\x5f\x66\x65\x78\x69\x74\0\x66\x65\x78\x69\x74\x5f\x72\
\x65\x74\0\x66\x65\x78\x69\x74\x5f\x72\x65\x61\x64\x5f\x73\x7a\0\x68\x61\x6e\
\x64\x6c\x65\x5f\x66\x65\x78\x69\x74\x5f\x72\x65\x74\0\x68\x61\x6e\x64\x6c\x65\
\x5f\x66\x6d\x6f\x64\x5f\x72\x65\x74\0\x66\x6d\x6f\x64\x5f\x72\x65\x74\x5f\x72\
\x65\x61\x64\x5f\x73\x7a\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\
\x72\x61\x77\x5f\x74\x70\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\
\x74\x65\x73\x74\x5f\x72\x65\x61\x64\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\x70\
\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x77\
\x72\x69\x74\x65\x5f\x62\x61\x72\x65\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\x70\
\x2e\x77\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\
\x5f\x77\x72\x69\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\0\x2e\x72\x65\x6c\x74\
\x70\x5f\x62\x74\x66\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\
\x65\x73\x74\x5f\x72\x65\x61\x64\0\x2e\x72\x65\x6c\x66\x65\x6e\x74\x72\x79\x2f\
\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x72\x65\
\x61\x64\0\x2e\x72\x65\x6c\x66\x65\x6e\x74\x72\x79\x2f\x70\x6c\x61\x63\x65\x68\
\x6f\x6c\x64\x65\x72\0\x2e\x72\x65\x6c\x66\x65\x78\x69\x74\x2f\x62\x70\x66\x5f\
\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x72\x65\x61\x64\0\x2e\x72\
\x65\x6c\x66\x6d\x6f\x64\x5f\x72\x65\x74\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\
\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x72\x65\x61\x64\0\x2e\x42\x54\x46\0\x2e\
\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x01\x2b\x04\0\xff\xf1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x04\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\
\x40\0\0\0\x05\0\0\0\0\0\0\0\x58\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x06\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x03\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x09\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x0a\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x03\0\0\x0b\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x47\x12\0\0\x03\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x68\0\0\x01\x55\x11\0\0\x0c\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x04\0\0\x01\x64\x12\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x68\0\0\x01\x77\
\x11\0\0\x0c\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x04\0\0\x01\x8c\x12\0\0\x05\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x90\0\0\x01\xa8\x11\0\0\x0c\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\x04\0\0\x01\xc4\x11\0\0\x0c\0\0\0\0\0\0\0\x0c\0\0\0\0\0\0\0\x04\0\0\x01\
\xe3\x11\0\0\x0c\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x04\0\0\x02\0\x12\0\0\x06\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x38\0\0\x02\x0e\x11\0\0\x0c\0\0\0\0\0\0\0\x14\0\0\0\
\0\0\0\0\x04\0\0\x02\x1d\x12\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\x02\
\x2b\x11\0\0\x0c\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x04\0\0\x02\x3a\x12\0\0\x08\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\x02\x4f\x11\0\0\x0c\0\0\0\0\0\0\0\x1c\0\0\
\0\0\0\0\0\x04\0\0\x02\x65\x12\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x50\0\0\
\x02\x72\x11\0\0\x0c\0\0\0\0\0\0\0\x24\0\0\0\0\0\0\0\x04\0\0\x02\x7c\x11\0\0\
\x0c\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x04\0\0\x02\x8a\x12\0\0\x0a\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x90\0\0\x02\x9b\x12\0\0\x0b\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\
\0\0\x02\xab\x11\0\0\x0c\0\0\0\0\0\0\0\x28\0\0\0\0\0\0\0\x04\0\0\x02\xbc\x11\0\
\0\x0d\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\xb7\x20\0\0\0\0\0\x10\x79\x31\0\x08\0\
\0\0\0\x0f\x32\0\0\0\0\0\0\xbf\x1a\0\0\0\0\0\0\x07\x10\0\0\xff\xff\xff\xf8\xb7\
\x20\0\0\0\0\0\x08\x85\0\0\0\0\0\0\x71\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\
\x2a\xff\xf8\0\0\0\0\x63\x12\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\
\xb7\x20\0\0\0\0\0\x10\x79\x31\0\x08\0\0\0\0\x0f\x32\0\0\0\0\0\0\xbf\x1a\0\0\0\
\0\0\0\x07\x10\0\0\xff\xff\xff\xf8\xb7\x20\0\0\0\0\0\x08\x85\0\0\0\0\0\0\x71\
\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x2a\xff\xf8\0\0\0\0\x63\x12\0\0\0\0\0\
\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x11\0\0\0\0\0\0\x61\x21\0\x04\0\0\0\
\0\x18\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x32\0\0\0\0\0\0\x18\x20\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x61\x32\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x01\x55\x30\0\x01\0\0\0\
\0\xb7\x20\0\0\0\0\0\0\x73\x12\0\0\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x61\x22\0\0\0\0\0\0\x63\x12\0\x04\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\
\x79\x11\0\x08\0\0\0\0\x79\x11\0\x10\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x63\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x11\0\x28\0\0\0\
\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\
\x95\0\0\0\0\0\0\0\x79\x11\0\x28\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x63\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x21\0\x28\0\0\0\0\
\x79\x11\0\x30\0\0\0\0\x18\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x31\0\0\0\0\0\0\
\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\
\0\0\0\0\0\0\0\x79\x61\0\x08\0\0\0\0\xb7\x10\0\0\0\0\0\0\x7b\xa1\xff\xf8\0\0\0\
\0\xbf\x7a\0\0\0\0\0\0\x07\x70\0\0\xff\xff\xff\xf8\xbf\x17\0\0\0\0\0\0\xb7\x20\
\0\0\0\0\0\x08\xbf\x36\0\0\0\0\0\0\x85\0\0\0\0\0\0\x71\xbf\x36\0\0\0\0\0\0\x07\
\x30\0\0\0\0\x01\0\xbf\x17\0\0\0\0\0\0\xb7\x20\0\0\0\0\0\x08\x85\0\0\0\0\0\0\
\x71\x79\x16\0\0\0\0\0\0\x61\x16\0\x44\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\
\0\0\x79\x11\0\x28\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x21\0\0\0\0\
\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\
\x38\0\0\0\x0d\0\0\0\x01\0\0\0\0\0\0\0\x38\0\0\0\x0f\0\0\0\x01\0\0\0\0\0\0\0\
\x10\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x28\0\0\0\x12\0\0\0\x01\0\0\0\0\0\0\0\
\x60\0\0\0\x13\0\0\0\x01\0\0\0\0\0\0\0\x10\0\0\0\x15\0\0\0\x01\0\0\0\0\0\0\0\
\x08\0\0\0\x17\0\0\0\x01\0\0\0\0\0\0\0\x08\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\0\
\x10\0\0\0\x1b\0\0\0\x01\0\0\0\0\0\0\0\x28\0\0\0\x1c\0\0\0\x01\0\0\0\0\0\0\0\
\x08\0\0\0\x1f\0\0\0\x01\xeb\x9f\x01\0\0\0\0\x18\0\0\0\0\0\0\x08\xdc\0\0\x08\
\xdc\0\0\x0a\x60\0\0\0\0\x02\0\0\0\0\0\0\x02\0\0\0\x01\x01\0\0\0\0\0\0\x08\0\0\
\0\x40\0\0\0\0\x0d\0\0\x01\0\0\0\x04\0\0\0\x14\0\0\0\x01\0\0\0\x18\x01\0\0\0\0\
\0\0\x04\x01\0\0\x20\0\0\0\x1c\x0c\0\0\x01\0\0\0\x03\0\0\0\x2a\x04\0\0\x03\0\0\
\0\x18\0\0\0\x44\0\0\0\x07\0\0\0\0\0\0\0\x48\0\0\0\x09\0\0\0\x40\0\0\0\x4c\0\0\
\0\x0c\0\0\0\x80\0\0\0\0\x02\0\0\0\0\0\0\x08\0\0\0\x50\x01\0\0\0\0\0\0\x01\x01\
\0\0\x08\0\0\0\x55\x08\0\0\0\0\0\0\x0a\0\0\0\x5c\x08\0\0\0\0\0\0\x0b\0\0\0\x6c\
\x01\0\0\0\0\0\0\x08\x01\0\0\x40\0\0\0\x76\x08\0\0\0\0\0\0\x0d\0\0\0\x7d\x08\0\
\0\0\0\0\0\x0e\0\0\0\x8d\x01\0\0\0\0\0\0\x08\0\0\0\x40\0\0\0\x9b\x0c\0\0\x01\0\
\0\0\x03\0\0\0\xae\x04\0\0\x03\0\0\0\x18\0\0\0\x44\0\0\0\x07\0\0\0\0\0\0\0\x48\
\0\0\0\x09\0\0\0\x40\0\0\0\x4c\0\0\0\x0c\0\0\0\x80\0\0\0\xc9\x0c\0\0\x01\0\0\0\
\x03\0\0\0\xe5\x0c\0\0\x01\0\0\0\x03\0\0\0\xf3\x0c\0\0\x01\0\0\0\x03\0\0\x01\
\x01\x0c\0\0\x01\0\0\0\x03\0\0\x01\x16\x0c\0\0\x01\0\0\0\x03\0\0\x01\x23\x0c\0\
\0\x01\0\0\0\x03\0\0\x01\x34\x04\0\0\x14\0\0\0\xe8\0\0\x01\x39\0\0\0\x18\0\0\0\
\0\0\0\x01\x3d\0\0\0\x1f\0\0\0\x80\0\0\x01\x44\0\0\0\x22\0\0\x01\0\0\0\x01\x4c\
\0\0\0\x23\0\0\x01\x40\0\0\x01\x51\0\0\0\x25\0\0\x01\x80\0\0\x01\x58\0\0\0\x2b\
\0\0\x01\xc0\0\0\x01\x60\0\0\0\x30\0\0\x02\0\0\0\x01\x68\0\0\0\x31\0\0\x02\x20\
\0\0\x01\x6f\0\0\0\x32\0\0\x02\x40\0\0\x01\x7a\0\0\0\x09\0\0\x03\x40\0\0\x01\
\x80\0\0\0\x39\0\0\x03\x80\0\0\x01\x88\0\0\0\x44\0\0\x04\x80\0\0\x01\x8f\0\0\0\
\x46\0\0\x04\xc0\0\0\x01\x94\0\0\0\x47\0\0\x05\xc0\0\0\x01\x9e\0\0\0\x49\0\0\
\x06\0\0\0\x01\xa9\0\0\0\x49\0\0\x06\x40\0\0\x01\xb6\0\0\0\x4a\0\0\x06\x80\0\0\
\x01\xbb\0\0\0\x4b\0\0\x06\xc0\0\0\x01\xc5\0\0\0\x4c\0\0\x07\0\0\0\x01\xce\0\0\
\0\x4c\0\0\x07\x20\0\0\0\0\x05\0\0\x02\0\0\0\x10\0\0\x01\xd7\0\0\0\x19\0\0\0\0\
\0\0\x01\xe0\0\0\0\x1b\0\0\0\0\0\0\x01\xeb\x04\0\0\x01\0\0\0\x08\0\0\x01\xf6\0\
\0\0\x1a\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\x19\0\0\x01\xfb\x04\0\0\x02\0\0\0\x10\
\0\0\x01\xf6\0\0\0\x1c\0\0\0\0\0\0\x02\x09\0\0\0\x1d\0\0\0\x40\0\0\0\0\x02\0\0\
\0\0\0\0\x1b\0\0\0\0\x02\0\0\0\0\0\0\x1e\0\0\0\0\x0d\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\x1c\0\0\x02\x0e\x04\0\0\x02\0\0\0\x10\0\0\x02\x13\0\0\0\x20\0\0\0\0\0\0\
\x02\x17\0\0\0\x21\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x62\0\0\0\0\x02\0\0\0\0\0\
\0\x61\0\0\0\0\x02\0\0\0\0\0\0\x60\0\0\0\0\x02\0\0\0\0\0\0\x24\0\0\0\0\x0a\0\0\
\0\0\0\0\x5e\0\0\x02\x1e\x08\0\0\0\0\0\0\x26\0\0\x02\x29\x04\0\0\x01\0\0\0\x04\
\0\0\0\0\0\0\0\x27\0\0\0\0\0\0\0\0\x05\0\0\x01\0\0\0\x04\0\0\x02\x32\0\0\0\x28\
\0\0\0\0\0\0\x02\x38\x04\0\0\x01\0\0\0\x04\0\0\x02\x45\0\0\0\x29\0\0\0\0\0\0\
\x02\x4e\x08\0\0\0\0\0\0\x2a\0\0\0\0\x04\0\0\x01\0\0\0\x04\0\0\x02\x5e\0\0\0\
\x04\0\0\0\0\0\0\x02\x63\x08\0\0\0\0\0\0\x2c\0\0\x02\x71\x08\0\0\0\0\0\0\x2d\0\
\0\0\0\x04\0\0\x01\0\0\0\x08\0\0\x02\x7c\0\0\0\x2e\0\0\0\0\0\0\x02\x84\x08\0\0\
\0\0\0\0\x2f\0\0\x02\x88\x08\0\0\0\0\0\0\x0b\0\0\x02\x8e\x01\0\0\0\0\0\0\x04\0\
\0\0\x20\0\0\x02\x9b\x08\0\0\0\0\0\0\x30\0\0\x02\xa3\x04\0\0\x04\0\0\0\x20\0\0\
\x02\xa9\0\0\0\x2b\0\0\0\0\0\0\x02\xaf\0\0\0\x33\0\0\0\x40\0\0\x02\xb9\0\0\0\
\x34\0\0\0\x60\0\0\x02\xbd\0\0\0\x37\0\0\0\x80\0\0\x02\xc7\x08\0\0\0\0\0\0\x28\
\0\0\x02\xd6\x04\0\0\x01\0\0\0\x04\0\0\x02\xec\0\0\0\x35\0\0\0\0\0\0\x02\xf1\
\x08\0\0\0\0\0\0\x36\0\0\0\0\x04\0\0\x01\0\0\0\x04\0\0\x02\x7c\0\0\0\x04\0\0\0\
\0\0\0\x02\xfa\x04\0\0\x02\0\0\0\x10\0\0\x01\xf6\0\0\0\x38\0\0\0\0\0\0\x03\x04\
\0\0\0\x38\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x37\0\0\x03\x09\x04\0\0\x06\0\0\0\
\x20\0\0\x02\x5e\0\0\0\x3a\0\0\0\0\0\0\x03\x15\0\0\0\x3e\0\0\0\x40\0\0\x03\x19\
\0\0\0\x3f\0\0\0\x80\0\0\x03\x22\0\0\0\x40\0\0\0\xa0\0\0\x03\x26\0\0\0\x40\0\0\
\0\xc0\0\0\x03\x2b\0\0\0\x04\0\0\0\xe0\0\0\x03\x32\x08\0\0\0\0\0\0\x3b\0\0\0\0\
\x04\0\0\x01\0\0\0\x08\0\0\x02\x45\0\0\0\x3c\0\0\0\0\0\0\x03\x3b\x08\0\0\0\0\0\
\0\x3d\0\0\0\0\x04\0\0\x02\0\0\0\x08\0\0\x03\x49\0\0\0\x04\0\0\0\0\0\0\x03\x4e\
\0\0\0\x29\0\0\0\x20\0\0\0\0\x02\0\0\0\0\0\0\x65\0\0\x03\x19\x06\0\0\x05\0\0\0\
\x04\0\0\x03\x53\0\0\0\0\0\0\x03\x5f\0\0\0\x01\0\0\x03\x6c\0\0\0\x02\0\0\x03\
\x79\0\0\0\x03\0\0\x03\x85\0\0\0\x04\0\0\x03\x91\x08\0\0\0\0\0\0\x41\0\0\0\0\
\x04\0\0\x01\0\0\0\x04\0\0\x03\x98\0\0\0\x42\0\0\0\0\0\0\x03\x9c\x08\0\0\0\0\0\
\0\x43\0\0\x03\xa2\x08\0\0\0\0\0\0\x30\0\0\0\0\x02\0\0\0\0\0\0\x45\0\0\0\0\x0a\
\0\0\0\0\0\0\x64\0\0\x03\xb3\x04\0\0\x06\0\0\0\x20\0\0\x03\xc1\0\0\0\x0e\0\0\0\
\0\0\0\x03\xc7\0\0\0\x30\0\0\0\x40\0\0\x03\xcc\0\0\0\x30\0\0\0\x60\0\0\x03\xd7\
\0\0\0\x30\0\0\0\x80\0\0\x03\xe0\0\0\0\x30\0\0\0\xa0\0\0\x03\xea\0\0\0\x09\0\0\
\0\xc0\0\0\x03\xf3\x08\0\0\0\0\0\0\x48\0\0\x03\xf7\x08\0\0\0\0\0\0\x02\0\0\0\0\
\x02\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\x63\0\0\0\0\x02\0\0\0\0\0\0\x5f\0\0\
\x03\xfd\x08\0\0\0\0\0\0\x4d\0\0\x04\x06\x08\0\0\0\0\0\0\x4e\0\0\x04\x0a\x08\0\
\0\0\0\0\0\x30\0\0\x04\x10\x0c\0\0\x01\0\0\0\x03\0\0\x04\x20\x0e\0\0\0\0\0\0\
\x4e\0\0\0\x01\0\0\x04\x2f\x0e\0\0\0\0\0\0\x4e\0\0\0\x01\0\0\x04\x44\x0e\0\0\0\
\0\0\0\x04\0\0\0\x01\0\0\x04\x60\x0e\0\0\0\0\0\0\x04\0\0\0\x01\0\0\x04\x7f\x0e\
\0\0\0\0\0\0\x04\0\0\0\x01\0\0\x04\x9c\x0e\0\0\0\0\0\0\x4e\0\0\0\x01\0\0\x04\
\xab\x0e\0\0\0\0\0\0\x4e\0\0\0\x01\0\0\x04\xba\x0e\0\0\0\0\0\0\x4e\0\0\0\x01\0\
\0\x04\xd0\x0e\0\0\0\0\0\0\x4e\0\0\0\x01\0\0\x04\xde\x0e\0\0\0\0\0\0\x04\0\0\0\
\x01\0\0\x04\xe8\x0e\0\0\0\0\0\0\x4e\0\0\0\x01\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\x5c\0\0\0\x04\0\0\x04\xf9\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\x05\x0d\
\x0e\0\0\0\0\0\0\x5b\0\0\0\x01\0\0\x05\x16\x07\0\0\0\0\0\0\0\0\0\x05\x26\x07\0\
\0\0\0\0\0\0\0\0\x05\x34\x07\0\0\0\0\0\0\0\0\0\x02\x17\x07\0\0\0\0\0\0\0\0\0\
\x05\x3a\x07\0\0\0\0\0\0\0\0\0\x05\x43\x07\0\0\0\0\0\0\0\0\0\x05\x4e\x07\0\0\0\
\0\0\0\0\0\0\x03\x15\x07\0\0\0\0\0\0\0\0\0\x09\x46\x0f\0\0\x0b\0\0\0\x2c\0\0\0\
\x50\0\0\0\0\0\0\0\x04\0\0\0\x51\0\0\0\x04\0\0\0\x04\0\0\0\x52\0\0\0\x08\0\0\0\
\x04\0\0\0\x53\0\0\0\x0c\0\0\0\x04\0\0\0\x54\0\0\0\x10\0\0\0\x04\0\0\0\x55\0\0\
\0\x14\0\0\0\x04\0\0\0\x56\0\0\0\x18\0\0\0\x04\0\0\0\x57\0\0\0\x1c\0\0\0\x04\0\
\0\0\x58\0\0\0\x20\0\0\0\x04\0\0\0\x59\0\0\0\x24\0\0\0\x04\0\0\0\x5a\0\0\0\x28\
\0\0\0\x04\0\0\x09\x4b\x0f\0\0\x01\0\0\0\x04\0\0\0\x5d\0\0\0\0\0\0\0\x04\0\x75\
\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x63\x74\
\x78\0\x69\x6e\x74\0\x68\x61\x6e\x64\x6c\x65\x5f\x72\x61\x77\x5f\x74\x70\0\x62\
\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x72\x65\x61\
\x64\x5f\x63\x74\x78\0\x62\x75\x66\0\x6f\x66\x66\0\x6c\x65\x6e\0\x63\x68\x61\
\x72\0\x6c\x6f\x66\x66\x5f\x74\0\x5f\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x6c\x6f\
\x66\x66\x5f\x74\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x73\x69\x7a\x65\x5f\
\x74\0\x5f\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x69\x7a\x65\x5f\x74\0\x75\x6e\
\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\0\x68\x61\x6e\x64\x6c\x65\x5f\x72\
\x61\x77\x5f\x74\x70\x5f\x62\x61\x72\x65\0\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\
\x6f\x64\x5f\x74\x65\x73\x74\x5f\x77\x72\x69\x74\x65\x5f\x63\x74\x78\0\x68\x61\
\x6e\x64\x6c\x65\x5f\x72\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\x74\x61\x62\x6c\
\x65\x5f\x62\x61\x72\x65\0\x68\x61\x6e\x64\x6c\x65\x5f\x74\x70\x5f\x62\x74\x66\
\0\x68\x61\x6e\x64\x6c\x65\x5f\x66\x65\x6e\x74\x72\x79\0\x68\x61\x6e\x64\x6c\
\x65\x5f\x66\x65\x6e\x74\x72\x79\x5f\x6d\x61\x6e\x75\x61\x6c\0\x68\x61\x6e\x64\
\x6c\x65\x5f\x66\x65\x78\x69\x74\0\x68\x61\x6e\x64\x6c\x65\x5f\x66\x65\x78\x69\
\x74\x5f\x72\x65\x74\0\x66\x69\x6c\x65\0\x66\x5f\x75\0\x66\x5f\x70\x61\x74\x68\
\0\x66\x5f\x69\x6e\x6f\x64\x65\0\x66\x5f\x6f\x70\0\x66\x5f\x6c\x6f\x63\x6b\0\
\x66\x5f\x63\x6f\x75\x6e\x74\0\x66\x5f\x66\x6c\x61\x67\x73\0\x66\x5f\x6d\x6f\
\x64\x65\0\x66\x5f\x70\x6f\x73\x5f\x6c\x6f\x63\x6b\0\x66\x5f\x70\x6f\x73\0\x66\
\x5f\x6f\x77\x6e\x65\x72\0\x66\x5f\x63\x72\x65\x64\0\x66\x5f\x72\x61\0\x66\x5f\
\x76\x65\x72\x73\x69\x6f\x6e\0\x66\x5f\x73\x65\x63\x75\x72\x69\x74\x79\0\x70\
\x72\x69\x76\x61\x74\x65\x5f\x64\x61\x74\x61\0\x66\x5f\x65\x70\0\x66\x5f\x6d\
\x61\x70\x70\x69\x6e\x67\0\x66\x5f\x77\x62\x5f\x65\x72\x72\0\x66\x5f\x73\x62\
\x5f\x65\x72\x72\0\x66\x75\x5f\x6c\x6c\x69\x73\x74\0\x66\x75\x5f\x72\x63\x75\
\x68\x65\x61\x64\0\x6c\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\0\x6e\x65\x78\x74\0\
\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x68\x65\x61\x64\0\x66\x75\x6e\x63\0\x70\
\x61\x74\x68\0\x6d\x6e\x74\0\x64\x65\x6e\x74\x72\x79\0\x73\x70\x69\x6e\x6c\x6f\
\x63\x6b\x5f\x74\0\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\x72\x6c\x6f\x63\x6b\0\x72\
\x61\x77\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\x72\x61\x77\x5f\x6c\x6f\x63\x6b\
\0\x61\x72\x63\x68\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x6c\x6f\x63\
\x6b\0\x61\x74\x6f\x6d\x69\x63\x5f\x6c\x6f\x6e\x67\x5f\x74\0\x61\x74\x6f\x6d\
\x69\x63\x36\x34\x5f\x74\0\x63\x6f\x75\x6e\x74\x65\x72\0\x73\x36\x34\0\x5f\x5f\
\x73\x36\x34\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x66\x6d\x6f\
\x64\x65\x5f\x74\0\x6d\x75\x74\x65\x78\0\x6f\x77\x6e\x65\x72\0\x77\x61\x69\x74\
\x5f\x6c\x6f\x63\x6b\0\x6f\x73\x71\0\x77\x61\x69\x74\x5f\x6c\x69\x73\x74\0\x72\
\x61\x77\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x6f\x70\x74\x69\x6d\x69\
\x73\x74\x69\x63\x5f\x73\x70\x69\x6e\x5f\x71\x75\x65\x75\x65\0\x74\x61\x69\x6c\
\0\x61\x74\x6f\x6d\x69\x63\x5f\x74\0\x6c\x69\x73\x74\x5f\x68\x65\x61\x64\0\x70\
\x72\x65\x76\0\x66\x6f\x77\x6e\x5f\x73\x74\x72\x75\x63\x74\0\x70\x69\x64\0\x70\
\x69\x64\x5f\x74\x79\x70\x65\0\x75\x69\x64\0\x65\x75\x69\x64\0\x73\x69\x67\x6e\
\x75\x6d\0\x72\x77\x6c\x6f\x63\x6b\x5f\x74\0\x61\x72\x63\x68\x5f\x72\x77\x6c\
\x6f\x63\x6b\x5f\x74\0\x63\x6e\x74\x73\0\x77\x61\x69\x74\0\x50\x49\x44\x54\x59\
\x50\x45\x5f\x50\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x54\x47\x49\x44\0\
\x50\x49\x44\x54\x59\x50\x45\x5f\x50\x47\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\
\x5f\x53\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x4d\x41\x58\0\x6b\x75\x69\
\x64\x5f\x74\0\x76\x61\x6c\0\x75\x69\x64\x5f\x74\0\x5f\x5f\x6b\x65\x72\x6e\x65\
\x6c\x5f\x75\x69\x64\x33\x32\x5f\x74\0\x66\x69\x6c\x65\x5f\x72\x61\x5f\x73\x74\
\x61\x74\x65\0\x73\x74\x61\x72\x74\0\x73\x69\x7a\x65\0\x61\x73\x79\x6e\x63\x5f\
\x73\x69\x7a\x65\0\x72\x61\x5f\x70\x61\x67\x65\x73\0\x6d\x6d\x61\x70\x5f\x6d\
\x69\x73\x73\0\x70\x72\x65\x76\x5f\x70\x6f\x73\0\x75\x36\x34\0\x5f\x5f\x75\x36\
\x34\0\x65\x72\x72\x73\x65\x71\x5f\x74\0\x75\x33\x32\0\x5f\x5f\x75\x33\x32\0\
\x68\x61\x6e\x64\x6c\x65\x5f\x66\x6d\x6f\x64\x5f\x72\x65\x74\0\x72\x61\x77\x5f\
\x74\x70\x5f\x72\x65\x61\x64\x5f\x73\x7a\0\x72\x61\x77\x5f\x74\x70\x5f\x62\x61\
\x72\x65\x5f\x77\x72\x69\x74\x65\x5f\x73\x7a\0\x72\x61\x77\x5f\x74\x70\x5f\x77\
\x72\x69\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\x5f\x69\x6e\x5f\x76\x61\x6c\0\
\x72\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\
\x65\x5f\x65\x61\x72\x6c\x79\x5f\x72\x65\x74\0\x72\x61\x77\x5f\x74\x70\x5f\x77\
\x72\x69\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\x5f\x6f\x75\x74\x5f\x76\x61\
\x6c\0\x74\x70\x5f\x62\x74\x66\x5f\x72\x65\x61\x64\x5f\x73\x7a\0\x66\x65\x6e\
\x74\x72\x79\x5f\x72\x65\x61\x64\x5f\x73\x7a\0\x66\x65\x6e\x74\x72\x79\x5f\x6d\
\x61\x6e\x75\x61\x6c\x5f\x72\x65\x61\x64\x5f\x73\x7a\0\x66\x65\x78\x69\x74\x5f\
\x72\x65\x61\x64\x5f\x73\x7a\0\x66\x65\x78\x69\x74\x5f\x72\x65\x74\0\x66\x6d\
\x6f\x64\x5f\x72\x65\x74\x5f\x72\x65\x61\x64\x5f\x73\x7a\0\x5f\x5f\x41\x52\x52\
\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x5f\x6c\x69\x63\x65\
\x6e\x73\x65\0\x66\x69\x6c\x65\x5f\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x73\0\
\x61\x64\x64\x72\x65\x73\x73\x5f\x73\x70\x61\x63\x65\0\x69\x6e\x6f\x64\x65\0\
\x76\x66\x73\x6d\x6f\x75\x6e\x74\0\x68\x6c\x69\x73\x74\x5f\x68\x65\x61\x64\0\
\x63\x72\x65\x64\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\
\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\
\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\
\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\
\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\
\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x74\x65\x73\x74\x5f\
\x6d\x6f\x64\x75\x6c\x65\x5f\x61\x74\x74\x61\x63\x68\x2e\x63\0\x69\x6e\x74\x20\
\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\x5f\x72\x61\x77\
\x5f\x74\x70\x2c\0\x09\x72\x61\x77\x5f\x74\x70\x5f\x72\x65\x61\x64\x5f\x73\x7a\
\x20\x3d\x20\x42\x50\x46\x5f\x43\x4f\x52\x45\x5f\x52\x45\x41\x44\x28\x72\x65\
\x61\x64\x5f\x63\x74\x78\x2c\x20\x6c\x65\x6e\x29\x3b\0\x69\x6e\x74\x20\x42\x50\
\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\x5f\x72\x61\x77\x5f\x74\
\x70\x5f\x62\x61\x72\x65\x2c\0\x09\x72\x61\x77\x5f\x74\x70\x5f\x62\x61\x72\x65\
\x5f\x77\x72\x69\x74\x65\x5f\x73\x7a\x20\x3d\x20\x42\x50\x46\x5f\x43\x4f\x52\
\x45\x5f\x52\x45\x41\x44\x28\x77\x72\x69\x74\x65\x5f\x63\x74\x78\x2c\x20\x6c\
\x65\x6e\x29\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\
\x6e\x64\x6c\x65\x5f\x72\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\x74\x61\x62\x6c\
\x65\x5f\x62\x61\x72\x65\x2c\0\x09\x72\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\x74\
\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\x5f\x69\x6e\x5f\x76\x61\x6c\x20\x3d\x20\
\x77\x72\x69\x74\x61\x62\x6c\x65\x2d\x3e\x76\x61\x6c\x3b\0\x09\x77\x72\x69\x74\
\x61\x62\x6c\x65\x2d\x3e\x65\x61\x72\x6c\x79\x5f\x72\x65\x74\x20\x3d\x20\x72\
\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\
\x5f\x65\x61\x72\x6c\x79\x5f\x72\x65\x74\x3b\0\x09\x77\x72\x69\x74\x61\x62\x6c\
\x65\x2d\x3e\x76\x61\x6c\x20\x3d\x20\x72\x61\x77\x5f\x74\x70\x5f\x77\x72\x69\
\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\x5f\x6f\x75\x74\x5f\x76\x61\x6c\x3b\0\
\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\
\x5f\x74\x70\x5f\x62\x74\x66\x2c\0\x09\x74\x70\x5f\x62\x74\x66\x5f\x72\x65\x61\
\x64\x5f\x73\x7a\x20\x3d\x20\x72\x65\x61\x64\x5f\x63\x74\x78\x2d\x3e\x6c\x65\
\x6e\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\
\x6c\x65\x5f\x66\x65\x6e\x74\x72\x79\x2c\0\x09\x66\x65\x6e\x74\x72\x79\x5f\x72\
\x65\x61\x64\x5f\x73\x7a\x20\x3d\x20\x6c\x65\x6e\x3b\0\x69\x6e\x74\x20\x42\x50\
\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\x5f\x66\x65\x6e\x74\x72\
\x79\x5f\x6d\x61\x6e\x75\x61\x6c\x2c\0\x09\x66\x65\x6e\x74\x72\x79\x5f\x6d\x61\
\x6e\x75\x61\x6c\x5f\x72\x65\x61\x64\x5f\x73\x7a\x20\x3d\x20\x6c\x65\x6e\x3b\0\
\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\
\x5f\x66\x65\x78\x69\x74\x2c\0\x09\x66\x65\x78\x69\x74\x5f\x72\x65\x74\x20\x3d\
\x20\x72\x65\x74\x3b\0\x09\x66\x65\x78\x69\x74\x5f\x72\x65\x61\x64\x5f\x73\x7a\
\x20\x3d\x20\x6c\x65\x6e\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\
\x28\x68\x61\x6e\x64\x6c\x65\x5f\x66\x65\x78\x69\x74\x5f\x72\x65\x74\x2c\x20\
\x69\x6e\x74\x20\x61\x72\x67\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x66\x69\x6c\
\x65\x20\x2a\x72\x65\x74\x29\0\x09\x6c\x6f\x6e\x67\x20\x62\x75\x66\x20\x3d\x20\
\x30\x3b\0\x09\x62\x70\x66\x5f\x70\x72\x6f\x62\x65\x5f\x72\x65\x61\x64\x5f\x6b\
\x65\x72\x6e\x65\x6c\x28\x26\x62\x75\x66\x2c\x20\x38\x2c\x20\x72\x65\x74\x29\
\x3b\0\x09\x62\x70\x66\x5f\x70\x72\x6f\x62\x65\x5f\x72\x65\x61\x64\x5f\x6b\x65\
\x72\x6e\x65\x6c\x28\x26\x62\x75\x66\x2c\x20\x38\x2c\x20\x28\x63\x68\x61\x72\
\x20\x2a\x29\x72\x65\x74\x20\x2b\x20\x32\x35\x36\x29\x3b\0\x09\x2a\x28\x76\x6f\
\x6c\x61\x74\x69\x6c\x65\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\x20\x2a\x29\
\x72\x65\x74\x3b\0\x09\x2a\x28\x76\x6f\x6c\x61\x74\x69\x6c\x65\x20\x69\x6e\x74\
\x20\x2a\x29\x26\x72\x65\x74\x2d\x3e\x66\x5f\x6d\x6f\x64\x65\x3b\0\x69\x6e\x74\
\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\x5f\x66\x6d\
\x6f\x64\x5f\x72\x65\x74\x2c\0\x09\x66\x6d\x6f\x64\x5f\x72\x65\x74\x5f\x72\x65\
\x61\x64\x5f\x73\x7a\x20\x3d\x20\x6c\x65\x6e\x3b\0\x30\x3a\x32\0\x30\x3a\x37\0\
\x2e\x62\x73\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x72\x61\x77\x5f\x74\x70\x2f\
\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x72\x65\
\x61\x64\0\x72\x61\x77\x5f\x74\x70\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\
\x64\x5f\x74\x65\x73\x74\x5f\x77\x72\x69\x74\x65\x5f\x62\x61\x72\x65\0\x72\x61\
\x77\x5f\x74\x70\x2e\x77\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\
\x74\x65\x73\x74\x5f\x77\x72\x69\x74\x61\x62\x6c\x65\x5f\x62\x61\x72\x65\0\x74\
\x70\x5f\x62\x74\x66\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\
\x65\x73\x74\x5f\x72\x65\x61\x64\0\x66\x65\x6e\x74\x72\x79\x2f\x62\x70\x66\x5f\
\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\x5f\x72\x65\x61\x64\0\x66\x65\
\x6e\x74\x72\x79\x2f\x70\x6c\x61\x63\x65\x68\x6f\x6c\x64\x65\x72\0\x66\x65\x78\
\x69\x74\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\x74\
\x5f\x72\x65\x61\x64\0\x66\x65\x78\x69\x74\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\
\x6d\x6f\x64\x5f\x72\x65\x74\x75\x72\x6e\x5f\x70\x74\x72\0\x66\x6d\x6f\x64\x5f\
\x72\x65\x74\x2f\x62\x70\x66\x5f\x74\x65\x73\x74\x6d\x6f\x64\x5f\x74\x65\x73\
\x74\x5f\x72\x65\x61\x64\0\0\0\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x94\0\
\0\0\x94\0\0\x03\x6c\0\0\x04\0\0\0\0\x4c\0\0\0\x08\0\0\x09\x53\0\0\0\x01\0\0\0\
\0\0\0\0\x05\0\0\x09\x70\0\0\0\x01\0\0\0\0\0\0\0\x0f\0\0\x09\x93\0\0\0\x01\0\0\
\0\0\0\0\0\x11\0\0\x09\xbb\0\0\0\x01\0\0\0\0\0\0\0\x12\0\0\x09\xd8\0\0\0\x01\0\
\0\0\0\0\0\0\x13\0\0\x09\xf5\0\0\0\x01\0\0\0\0\0\0\0\x14\0\0\x0a\x08\0\0\0\x01\
\0\0\0\0\0\0\0\x15\0\0\x0a\x24\0\0\0\x01\0\0\0\0\0\0\0\x16\0\0\x0a\x41\0\0\0\
\x01\0\0\0\0\0\0\0\x4f\0\0\0\x10\0\0\x09\x53\0\0\0\x08\0\0\0\0\0\0\x05\x53\0\0\
\x05\xd1\0\0\x34\0\0\0\0\x08\0\0\x05\x53\0\0\x05\xd1\0\0\x34\x05\0\0\0\x20\0\0\
\x05\x53\0\0\0\0\0\0\0\0\0\0\0\x28\0\0\x05\x53\0\0\x05\xed\0\0\x40\x13\0\0\0\
\x38\0\0\x05\x53\0\0\x05\xed\0\0\x40\x11\0\0\0\x48\0\0\x05\x53\0\0\x05\xed\0\0\
\x40\x13\0\0\0\x50\0\0\x05\x53\0\0\x05\xed\0\0\x40\x11\0\0\0\x58\0\0\x05\x53\0\
\0\x05\xd1\0\0\x34\x05\0\0\x09\x70\0\0\0\x08\0\0\0\0\0\0\x05\x53\0\0\x06\x1d\0\
\0\x5c\0\0\0\0\x08\0\0\x05\x53\0\0\x06\x1d\0\0\x5c\x05\0\0\0\x20\0\0\x05\x53\0\
\0\0\0\0\0\0\0\0\0\0\x28\0\0\x05\x53\0\0\x06\x3e\0\0\x68\x19\0\0\0\x38\0\0\x05\
\x53\0\0\x06\x3e\0\0\x68\x17\0\0\0\x48\0\0\x05\x53\0\0\x06\x3e\0\0\x68\x19\0\0\
\0\x50\0\0\x05\x53\0\0\x06\x3e\0\0\x68\x17\0\0\0\x58\0\0\x05\x53\0\0\x06\x1d\0\
\0\x5c\x05\0\0\x09\x93\0\0\0\x08\0\0\0\0\0\0\x05\x53\0\0\x06\x75\0\0\x8c\x05\0\
\0\0\x08\0\0\x05\x53\0\0\x06\x9f\0\0\x98\x2a\0\0\0\x10\0\0\x05\x53\0\0\x06\x9f\
\0\0\x98\x1e\0\0\0\x28\0\0\x05\x53\0\0\x06\xcd\0\0\x9c\x18\0\0\0\x58\0\0\x05\
\x53\0\0\x06\xcd\0\0\x9c\x16\0\0\0\x60\0\0\x05\x53\0\0\x07\x04\0\0\xa0\x12\0\0\
\0\x78\0\0\x05\x53\0\0\x07\x04\0\0\xa0\x10\0\0\0\x80\0\0\x05\x53\0\0\x06\x75\0\
\0\x8c\x05\0\0\x09\xbb\0\0\0\x04\0\0\0\0\0\0\x05\x53\0\0\x07\x33\0\0\xbc\x05\0\
\0\0\x08\0\0\x05\x53\0\0\x07\x4f\0\0\xc8\x1d\0\0\0\x10\0\0\x05\x53\0\0\x07\x4f\
\0\0\xc8\x11\0\0\0\x28\0\0\x05\x53\0\0\x07\x33\0\0\xbc\x05\0\0\x09\xd8\0\0\0\
\x03\0\0\0\0\0\0\x05\x53\0\0\x07\x70\0\0\xe4\x05\0\0\0\x08\0\0\x05\x53\0\0\x07\
\x8c\0\0\xf4\x11\0\0\0\x20\0\0\x05\x53\0\0\x07\x70\0\0\xe4\x05\0\0\x09\xf5\0\0\
\0\x03\0\0\0\0\0\0\x05\x53\0\0\x07\xa3\0\x01\x10\x05\0\0\0\x08\0\0\x05\x53\0\0\
\x07\xc6\0\x01\x20\x18\0\0\0\x20\0\0\x05\x53\0\0\x07\xa3\0\x01\x10\x05\0\0\x0a\
\x08\0\0\0\x04\0\0\0\0\0\0\x05\x53\0\0\x07\xe4\0\x01\x40\x05\0\0\0\x10\0\0\x05\
\x53\0\0\x07\xff\0\x01\x58\x0c\0\0\0\x28\0\0\x05\x53\0\0\x08\x11\0\x01\x54\x10\
\0\0\0\x40\0\0\x05\x53\0\0\x07\xe4\0\x01\x40\x05\0\0\x0a\x24\0\0\0\x09\0\0\0\0\
\0\0\x05\x53\0\0\x08\x27\0\x01\x6c\x05\0\0\0\x10\0\0\x05\x53\0\0\x08\x61\0\x01\
\x74\x07\0\0\0\x20\0\0\x05\x53\0\0\0\0\0\0\0\0\0\0\0\x28\0\0\x05\x53\0\0\x08\
\x70\0\x01\x7c\x02\0\0\0\x48\0\0\x05\x53\0\0\x08\x96\0\x01\x80\x2d\0\0\0\x58\0\
\0\x05\x53\0\0\x08\x96\0\x01\x80\x02\0\0\0\x70\0\0\x05\x53\0\0\x08\xca\0\x01\
\x84\x02\0\0\0\x78\0\0\x05\x53\0\0\x08\xe7\0\x01\x88\x02\0\0\0\x80\0\0\x05\x53\
\0\0\x08\x27\0\x01\x6c\x05\0\0\x0a\x41\0\0\0\x03\0\0\0\0\0\0\x05\x53\0\0\x09\
\x07\0\x01\xa4\x05\0\0\0\x08\0\0\x05\x53\0\0\x09\x25\0\x01\xb4\x13\0\0\0\x20\0\
\0\x05\x53\0\0\x09\x07\0\x01\xa4\x05\0\0\0\x10\0\0\x09\x53\0\0\0\x01\0\0\0\0\0\
\0\0\x06\0\0\x09\x3e\0\0\0\0\0\0\x09\x70\0\0\0\x01\0\0\0\0\0\0\0\x10\0\0\x09\
\x3e\0\0\0\0\0\0\x0a\x24\0\0\0\x01\0\0\0\x78\0\0\0\x17\0\0\x09\x42\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\
\0\0\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\x03\xe3\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x28\0\0\0\0\0\0\x03\x18\0\0\0\x01\0\0\0\0\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x07\x40\0\0\0\0\0\0\0\x68\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\
\0\0\0\0\0\0\0\0\0\0\0\x2e\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x07\xa8\0\0\0\0\0\0\0\x68\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\0\0\0\0\x51\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x10\0\
\0\0\0\0\0\0\x90\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x79\0\
\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\xa0\0\0\0\0\0\0\0\
\x38\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x96\0\0\0\x01\0\0\
\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\xd8\0\0\0\0\0\0\0\x30\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\xb3\0\0\0\x01\0\0\0\0\0\0\0\x06\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\x08\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\xc6\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x09\x38\0\0\0\0\0\0\0\x50\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0\0\0\0\xe2\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x09\x88\0\0\0\0\0\0\0\x90\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\0\xff\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x18\0\0\0\
\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x01\x1e\0\0\
\0\x08\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x48\0\0\0\0\0\0\0\x2c\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\x01\x23\0\0\0\x01\0\0\0\
\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x48\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\xc5\0\0\0\x09\0\0\0\0\0\0\0\x40\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x50\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x03\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x02\xe6\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x0a\x60\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x04\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x03\x0d\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x0a\x70\0\0\0\0\0\0\0\x30\0\0\0\x02\0\0\0\x05\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\x03\x39\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x0a\xa0\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x06\0\0\0\0\0\0\0\x08\0\
\0\0\0\0\0\0\x10\0\0\x03\x5a\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x0a\xb0\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x07\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\x10\0\0\x03\x7b\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x0a\xc0\0\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x08\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x10\0\0\x03\x92\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\
\xd0\0\0\0\0\0\0\0\x20\0\0\0\x02\0\0\0\x09\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\
\0\0\x03\xb2\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xf0\0\
\0\0\0\0\0\0\x10\0\0\0\x02\0\0\0\x0b\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\
\x03\xd5\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0b\0\0\0\0\0\0\
\0\x13\x54\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x03\xda\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1e\x58\0\0\0\0\0\0\x04\x6c\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct test_module_attach *test_module_attach::open(const struct bpf_object_open_opts *opts) { return test_module_attach__open_opts(opts); }
struct test_module_attach *test_module_attach::open_and_load() { return test_module_attach__open_and_load(); }
int test_module_attach::load(struct test_module_attach *skel) { return test_module_attach__load(skel); }
int test_module_attach::attach(struct test_module_attach *skel) { return test_module_attach__attach(skel); }
void test_module_attach::detach(struct test_module_attach *skel) { test_module_attach__detach(skel); }
void test_module_attach::destroy(struct test_module_attach *skel) { test_module_attach__destroy(skel); }
const void *test_module_attach::elf_bytes(size_t *sz) { return test_module_attach__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
test_module_attach__assert(struct test_module_attach *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->raw_tp_read_sz) == 4, "unexpected size of 'raw_tp_read_sz'");
	_Static_assert(sizeof(s->bss->raw_tp_bare_write_sz) == 4, "unexpected size of 'raw_tp_bare_write_sz'");
	_Static_assert(sizeof(s->bss->raw_tp_writable_bare_in_val) == 4, "unexpected size of 'raw_tp_writable_bare_in_val'");
	_Static_assert(sizeof(s->bss->raw_tp_writable_bare_early_ret) == 4, "unexpected size of 'raw_tp_writable_bare_early_ret'");
	_Static_assert(sizeof(s->bss->raw_tp_writable_bare_out_val) == 4, "unexpected size of 'raw_tp_writable_bare_out_val'");
	_Static_assert(sizeof(s->bss->tp_btf_read_sz) == 4, "unexpected size of 'tp_btf_read_sz'");
	_Static_assert(sizeof(s->bss->fentry_read_sz) == 4, "unexpected size of 'fentry_read_sz'");
	_Static_assert(sizeof(s->bss->fentry_manual_read_sz) == 4, "unexpected size of 'fentry_manual_read_sz'");
	_Static_assert(sizeof(s->bss->fexit_read_sz) == 4, "unexpected size of 'fexit_read_sz'");
	_Static_assert(sizeof(s->bss->fexit_ret) == 4, "unexpected size of 'fexit_ret'");
	_Static_assert(sizeof(s->bss->fmod_ret_read_sz) == 4, "unexpected size of 'fmod_ret_read_sz'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __TEST_MODULE_ATTACH_SKEL_H__ */
