/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TEST_XDP_SKEL_H__
#define __TEST_XDP_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct test_xdp {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *rxcnt;
		struct bpf_map *vip2tnl;
	} maps;
	struct {
		struct bpf_program *_xdp_tx_iptunnel;
	} progs;
	struct {
		struct bpf_link *_xdp_tx_iptunnel;
	} links;

#ifdef __cplusplus
	static inline struct test_xdp *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct test_xdp *open_and_load();
	static inline int load(struct test_xdp *skel);
	static inline int attach(struct test_xdp *skel);
	static inline void detach(struct test_xdp *skel);
	static inline void destroy(struct test_xdp *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
test_xdp__destroy(struct test_xdp *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_xdp__create_skeleton(struct test_xdp *obj);

static inline struct test_xdp *
test_xdp__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_xdp *obj;
	int err;

	obj = (struct test_xdp *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = test_xdp__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	test_xdp__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct test_xdp *
test_xdp__open(void)
{
	return test_xdp__open_opts(NULL);
}

static inline int
test_xdp__load(struct test_xdp *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_xdp *
test_xdp__open_and_load(void)
{
	struct test_xdp *obj;
	int err;

	obj = test_xdp__open();
	if (!obj)
		return NULL;
	err = test_xdp__load(obj);
	if (err) {
		test_xdp__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
test_xdp__attach(struct test_xdp *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_xdp__detach(struct test_xdp *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *test_xdp__elf_bytes(size_t *sz);

static inline int
test_xdp__create_skeleton(struct test_xdp *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "test_xdp";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 2;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "rxcnt";
	s->maps[0].map = &obj->maps.rxcnt;

	s->maps[1].name = "vip2tnl";
	s->maps[1].map = &obj->maps.vip2tnl;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "_xdp_tx_iptunnel";
	s->progs[0].prog = &obj->progs._xdp_tx_iptunnel;
	s->progs[0].link = &obj->links._xdp_tx_iptunnel;

	s->data = (void *)test_xdp__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *test_xdp__elf_bytes(size_t *sz)
{
	*sz = 8728;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1f\xd8\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x09\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x78\x64\x70\
\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x6d\x61\x70\x73\0\x74\x65\x73\x74\x5f\x78\
\x64\x70\x2e\x63\0\x4c\x42\x42\x30\x5f\x33\x30\0\x4c\x42\x42\x30\x5f\x31\x36\0\
\x4c\x42\x42\x30\x5f\x37\0\x4c\x42\x42\x30\x5f\x39\0\x4c\x42\x42\x30\x5f\x38\0\
\x4c\x42\x42\x30\x5f\x32\x30\0\x4c\x42\x42\x30\x5f\x32\x32\0\x4c\x42\x42\x30\
\x5f\x32\x31\0\x4c\x42\x42\x30\x5f\x32\x39\0\x4c\x42\x42\x30\x5f\x32\x38\0\x5f\
\x78\x64\x70\x5f\x74\x78\x5f\x69\x70\x74\x75\x6e\x6e\x65\x6c\0\x76\x69\x70\x32\
\x74\x6e\x6c\0\x72\x78\x63\x6e\x74\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\
\x65\x6c\x78\x64\x70\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x23\x04\0\xff\
\xf1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x2e\0\0\0\x03\0\0\0\0\0\0\x08\x28\0\0\0\0\0\0\0\0\0\0\0\x36\0\
\0\0\x03\0\0\0\0\0\0\0\xf8\0\0\0\0\0\0\0\0\0\0\0\x3e\0\0\0\x03\0\0\0\0\0\0\x01\
\x68\0\0\0\0\0\0\0\0\0\0\0\x45\0\0\0\x03\0\0\0\0\0\0\x01\x90\0\0\0\0\0\0\0\0\0\
\0\0\x4c\0\0\0\x03\0\0\0\0\0\0\x01\x88\0\0\0\0\0\0\0\0\0\0\0\x53\0\0\0\x03\0\0\
\0\0\0\0\x04\xc8\0\0\0\0\0\0\0\0\0\0\0\x5b\0\0\0\x03\0\0\0\0\0\0\x04\xf0\0\0\0\
\0\0\0\0\0\0\0\0\x63\0\0\0\x03\0\0\0\0\0\0\x04\xe8\0\0\0\0\0\0\0\0\0\0\0\x6b\0\
\0\0\x03\0\0\0\0\0\0\x08\x20\0\0\0\0\0\0\0\0\0\0\0\x73\0\0\0\x03\0\0\0\0\0\0\
\x08\x08\0\0\0\0\0\0\0\0\0\0\0\x7b\x12\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\
\x38\0\0\0\x8c\x11\0\0\x05\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x20\0\0\0\x94\x11\0\
\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\0\0\0\x9a\x11\0\0\x04\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x04\xbf\x61\0\0\0\0\0\0\xb7\x70\0\0\0\0\0\x01\x61\x26\0\x04\0\0\
\0\0\x61\x16\0\0\0\0\0\0\xbf\x31\0\0\0\0\0\0\x07\x30\0\0\0\0\0\x0e\x2d\x32\0\
\xfe\0\0\0\0\x71\x41\0\x0d\0\0\0\0\x71\x31\0\x0c\0\0\0\0\x67\x30\0\0\0\0\0\x08\
\x4f\x34\0\0\0\0\0\0\x15\x30\0\x13\0\0\x86\xdd\x55\x30\0\xf8\0\0\x08\0\xb7\x30\
\0\0\0\0\0\0\x63\xa3\xff\xf0\0\0\0\0\x63\xa3\xff\xec\0\0\0\0\x63\xa3\xff\xe8\0\
\0\0\0\x63\xa3\xff\xe4\0\0\0\0\x63\xa3\xff\xf4\0\0\0\0\xbf\x41\0\0\0\0\0\0\x07\
\x40\0\0\0\0\0\x22\xb7\x70\0\0\0\0\0\x01\x2d\x42\0\xee\0\0\0\0\x71\x41\0\x17\0\
\0\0\0\x15\x40\0\x14\0\0\0\x11\x55\x40\0\x18\0\0\0\x06\xbf\x31\0\0\0\0\0\0\x07\
\x30\0\0\0\0\0\x36\xb7\x70\0\0\0\0\0\x01\x2d\x32\0\xe7\0\0\0\0\x05\0\0\x12\0\0\
\0\0\xb7\x30\0\0\0\0\0\0\x63\xa3\xff\xf4\0\0\0\0\xbf\x41\0\0\0\0\0\0\x07\x40\0\
\0\0\0\0\x36\xb7\x70\0\0\0\0\0\x01\x2d\x42\0\xe0\0\0\0\0\x71\x41\0\x14\0\0\0\0\
\x15\x40\0\x72\0\0\0\x11\x55\x40\0\x76\0\0\0\x06\xbf\x31\0\0\0\0\0\0\x07\x30\0\
\0\0\0\0\x4a\xb7\x70\0\0\0\0\0\x01\x2d\x32\0\xd9\0\0\0\0\x05\0\0\x70\0\0\0\0\
\xbf\x31\0\0\0\0\0\0\x07\x30\0\0\0\0\0\x2a\xb7\x70\0\0\0\0\0\x01\x2d\x32\0\xd4\
\0\0\0\0\x69\x31\0\x24\0\0\0\0\x73\xa4\xff\xf4\0\0\0\0\xb7\x70\0\0\0\0\0\x02\
\x6b\xa7\xff\xf2\0\0\0\0\x61\x21\0\x1e\0\0\0\0\x6b\xa3\xff\xf0\0\0\0\0\x63\xa2\
\xff\xe0\0\0\0\0\x69\x91\0\x10\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\
\xff\xe0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x01\xbf\x80\0\0\0\
\0\0\0\x15\x80\0\xc5\0\0\0\0\x69\x18\0\x20\0\0\0\0\x55\x10\0\xc3\0\0\0\x02\xbf\
\x16\0\0\0\0\0\0\x18\x20\0\0\xff\xff\xff\xec\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\
\x2c\xb7\x70\0\0\0\0\0\x01\x55\0\0\xbd\0\0\0\0\x61\x16\0\0\0\0\0\0\x61\x26\0\
\x04\0\0\0\0\xbf\x31\0\0\0\0\0\0\x07\x30\0\0\0\0\0\x0e\xb7\x70\0\0\0\0\0\x01\
\x2d\x32\0\xb7\0\0\0\0\xbf\x31\0\0\0\0\0\0\x07\x30\0\0\0\0\0\x22\xb7\x70\0\0\0\
\0\0\x01\x2d\x32\0\xb3\0\0\0\0\x71\x21\0\x19\0\0\0\0\x73\x12\0\x0b\0\0\0\0\x71\
\x21\0\x18\0\0\0\0\x73\x12\0\x0a\0\0\0\0\x71\x21\0\x17\0\0\0\0\x73\x12\0\x09\0\
\0\0\0\x71\x21\0\x16\0\0\0\0\x73\x12\0\x08\0\0\0\0\x71\x21\0\x15\0\0\0\0\x73\
\x12\0\x07\0\0\0\0\x71\x21\0\x14\0\0\0\0\x73\x12\0\x06\0\0\0\0\x71\x28\0\x26\0\
\0\0\0\x71\x38\0\x27\0\0\0\0\x71\x48\0\x22\0\0\0\0\x71\x58\0\x23\0\0\0\0\x71\
\x08\0\x24\0\0\0\0\x71\x68\0\x25\0\0\0\0\xb7\x70\0\0\0\0\0\x04\x73\x17\0\x17\0\
\0\0\0\xb7\x70\0\0\0\0\x45\0\x6b\x17\0\x0e\0\0\0\0\xb7\x70\0\0\0\0\0\0\x6b\x17\
\0\x14\0\0\0\0\x6b\x17\0\x18\0\0\0\0\x73\x17\0\x0d\0\0\0\0\x73\x16\0\x03\0\0\0\
\0\x73\x10\0\x02\0\0\0\0\x73\x15\0\x01\0\0\0\0\x73\x14\0\0\0\0\0\0\x73\x13\0\
\x05\0\0\0\0\x73\x12\0\x04\0\0\0\0\x07\x90\0\0\0\0\0\x14\x6b\x19\0\x10\0\0\0\0\
\xb7\x30\0\0\0\0\0\x08\x73\x13\0\x0c\0\0\0\0\x61\x28\0\x10\0\0\0\0\x63\x12\0\
\x1e\0\0\0\0\x61\x48\0\0\0\0\0\0\x73\x13\0\x16\0\0\0\0\x63\x14\0\x1a\0\0\0\0\
\x57\x90\0\0\0\0\xff\xff\x69\x31\0\x12\0\0\0\0\x0f\x93\0\0\0\0\0\0\x69\x31\0\
\x16\0\0\0\0\x0f\x93\0\0\0\0\0\0\xbf\x34\0\0\0\0\0\0\x77\x30\0\0\0\0\0\x10\x0f\
\x93\0\0\0\0\0\0\x57\x40\0\0\0\0\xff\xff\x0f\x94\0\0\0\0\0\0\xbf\x32\0\0\0\0\0\
\0\x77\x30\0\0\0\0\0\x10\x0f\x93\0\0\0\0\0\0\x57\x20\0\0\0\0\xff\xff\x0f\x92\0\
\0\0\0\0\0\x07\x90\0\0\0\0\x45\0\xbf\x29\0\0\0\0\0\0\x77\x20\0\0\0\0\0\x10\x0f\
\x29\0\0\0\0\0\0\xa7\x20\0\0\xff\xff\xff\xff\x6b\x12\0\x18\0\0\0\0\x71\x1a\xff\
\xf4\0\0\0\0\x63\xa1\xff\xfc\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\
\xff\xfc\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x01\x15\0\0\x6c\0\
\0\0\0\x05\0\0\x68\0\0\0\0\xbf\x31\0\0\0\0\0\0\x07\x30\0\0\0\0\0\x3e\xb7\x70\0\
\0\0\0\0\x01\x2d\x32\0\x68\0\0\0\0\x69\x31\0\x38\0\0\0\0\xb7\x20\0\0\0\0\0\x0a\
\x6b\xa2\xff\xf2\0\0\0\0\x73\xa4\xff\xf4\0\0\0\0\x61\x21\0\x32\0\0\0\0\x61\x41\
\0\x2e\0\0\0\0\x61\x51\0\x2a\0\0\0\0\x61\x01\0\x26\0\0\0\0\x6b\xa3\xff\xf0\0\0\
\0\0\x67\0\0\0\0\0\0\x20\x4f\x05\0\0\0\0\0\0\x7b\xa0\xff\xe0\0\0\0\0\x67\x40\0\
\0\0\0\0\x20\x4f\x42\0\0\0\0\0\0\x7b\xa4\xff\xe8\0\0\0\0\x69\x91\0\x12\0\0\0\0\
\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xe0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x85\0\0\0\0\0\0\x01\xbf\x80\0\0\0\0\0\0\xb7\x70\0\0\0\0\0\x02\x15\x80\0\
\x50\0\0\0\0\x69\x18\0\x20\0\0\0\0\x55\x10\0\x4e\0\0\0\x0a\xbf\x16\0\0\0\0\0\0\
\x18\x20\0\0\xff\xff\xff\xd8\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x2c\xb7\x70\0\0\0\
\0\0\x01\x55\0\0\x48\0\0\0\0\x61\x16\0\0\0\0\0\0\x61\x26\0\x04\0\0\0\0\xbf\x31\
\0\0\0\0\0\0\x07\x30\0\0\0\0\0\x0e\xb7\x70\0\0\0\0\0\x01\x2d\x32\0\x42\0\0\0\0\
\xbf\x31\0\0\0\0\0\0\x07\x30\0\0\0\0\0\x36\xb7\x70\0\0\0\0\0\x01\x2d\x32\0\x3e\
\0\0\0\0\x71\x21\0\x2d\0\0\0\0\x73\x12\0\x0b\0\0\0\0\x71\x21\0\x2c\0\0\0\0\x73\
\x12\0\x0a\0\0\0\0\x71\x21\0\x2b\0\0\0\0\x73\x12\0\x09\0\0\0\0\x71\x21\0\x2a\0\
\0\0\0\x73\x12\0\x08\0\0\0\0\x71\x21\0\x29\0\0\0\0\x73\x12\0\x07\0\0\0\0\x71\
\x21\0\x28\0\0\0\0\x73\x12\0\x06\0\0\0\0\x71\x28\0\x26\0\0\0\0\x71\x38\0\x27\0\
\0\0\0\x71\x48\0\x22\0\0\0\0\x71\x58\0\x23\0\0\0\0\x71\x08\0\x24\0\0\0\0\x71\
\x68\0\x25\0\0\0\0\xb7\x70\0\0\0\0\0\x86\x73\x17\0\x0c\0\0\0\0\xb7\x70\0\0\0\0\
\0\xdd\x73\x17\0\x0d\0\0\0\0\xb7\x70\0\0\x60\0\0\0\x63\x17\0\x0e\0\0\0\0\xb7\
\x70\0\0\0\0\x29\x08\x6b\x17\0\x14\0\0\0\0\x07\x90\0\0\0\0\0\x28\x6b\x19\0\x12\
\0\0\0\0\x73\x16\0\x03\0\0\0\0\x73\x10\0\x02\0\0\0\0\x73\x15\0\x01\0\0\0\0\x73\
\x14\0\0\0\0\0\0\x73\x13\0\x05\0\0\0\0\x73\x12\0\x04\0\0\0\0\x61\x28\0\x08\0\0\
\0\0\x63\x12\0\x1e\0\0\0\0\x61\x28\0\x0c\0\0\0\0\x63\x12\0\x22\0\0\0\0\x61\x28\
\0\0\0\0\0\0\x63\x12\0\x16\0\0\0\0\x61\x28\0\x04\0\0\0\0\x63\x12\0\x1a\0\0\0\0\
\x61\x28\0\x1c\0\0\0\0\x63\x12\0\x32\0\0\0\0\x61\x28\0\x18\0\0\0\0\x63\x12\0\
\x2e\0\0\0\0\x61\x28\0\x14\0\0\0\0\x63\x12\0\x2a\0\0\0\0\x61\x28\0\x10\0\0\0\0\
\x63\x12\0\x26\0\0\0\0\x71\x1a\xff\xf4\0\0\0\0\x63\xa1\xff\xfc\0\0\0\0\xbf\x2a\
\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xfc\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x85\0\0\0\0\0\0\x01\x15\0\0\x03\0\0\0\0\x79\x10\0\0\0\0\0\0\x07\x10\0\0\0\0\0\
\x01\x7b\x01\0\0\0\0\0\0\xb7\x70\0\0\0\0\0\x03\xbf\x07\0\0\0\0\0\0\x95\0\0\0\0\
\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x01\xd8\0\0\0\x0e\0\0\0\x01\0\0\0\0\0\0\x04\xa0\0\0\0\x0f\0\0\0\
\x01\0\0\0\0\0\0\x05\x78\0\0\0\x0e\0\0\0\x01\0\0\0\0\0\0\x07\xe8\0\0\0\x0f\0\0\
\0\x01\xeb\x9f\x01\0\0\0\0\x18\0\0\0\0\0\0\x03\x84\0\0\x03\x84\0\0\x09\x90\0\0\
\0\0\x02\0\0\0\0\0\0\x03\0\0\0\x01\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\0\x03\
\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x06\0\0\0\x05\x01\0\0\0\0\0\0\x04\0\0\
\0\x20\0\0\0\0\x02\0\0\0\0\0\0\x06\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\
\x04\0\0\x01\0\0\0\0\0\x02\0\0\0\0\0\0\x08\0\0\0\x19\x08\0\0\0\0\0\0\x09\0\0\0\
\x1f\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\x02\0\0\0\0\0\0\x0b\0\0\0\x2c\x08\0\
\0\0\0\0\0\x0c\0\0\0\x32\x01\0\0\0\0\0\0\x08\0\0\0\x40\0\0\0\0\x04\0\0\x04\0\0\
\0\x20\0\0\0\x45\0\0\0\x01\0\0\0\0\0\0\0\x4a\0\0\0\x05\0\0\0\x40\0\0\0\x56\0\0\
\0\x07\0\0\0\x80\0\0\0\x5a\0\0\0\x0a\0\0\0\xc0\0\0\0\x60\x0e\0\0\0\0\0\0\x0d\0\
\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x10\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\
\x04\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x12\0\0\0\x66\x04\0\0\x04\0\0\0\x18\0\0\
\0\x6a\0\0\0\x13\0\0\0\0\0\0\0\x70\0\0\0\x15\0\0\0\x80\0\0\0\x76\0\0\0\x15\0\0\
\0\x90\0\0\0\x7d\0\0\0\x17\0\0\0\xa0\0\0\0\0\x05\0\0\x02\0\0\0\x10\0\0\0\x86\0\
\0\0\x14\0\0\0\0\0\0\0\x89\0\0\0\x08\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\x04\0\0\0\x04\0\0\0\x8c\x08\0\0\0\0\0\0\x16\0\0\0\x92\x01\0\0\0\0\0\
\0\x02\0\0\0\x10\0\0\0\xa1\x08\0\0\0\0\0\0\x18\0\0\0\xa6\x01\0\0\0\0\0\0\x01\0\
\0\0\x08\0\0\0\0\x02\0\0\0\0\0\0\x1a\0\0\0\xb4\x04\0\0\x04\0\0\0\x28\0\0\0\xbf\
\0\0\0\x13\0\0\0\0\0\0\0\x6a\0\0\0\x13\0\0\0\x80\0\0\0\x76\0\0\0\x15\0\0\x01\0\
\0\0\0\xc5\0\0\0\x1b\0\0\x01\x10\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x17\0\0\0\x04\
\0\0\0\x06\0\0\0\0\x04\0\0\x04\0\0\0\x20\0\0\0\x45\0\0\0\x0f\0\0\0\0\0\0\0\x4a\
\0\0\0\x05\0\0\0\x40\0\0\0\x56\0\0\0\x11\0\0\0\x80\0\0\0\x5a\0\0\0\x19\0\0\0\
\xc0\0\0\0\xca\x0e\0\0\0\0\0\0\x1c\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x1f\0\0\0\
\xd2\x04\0\0\x06\0\0\0\x18\0\0\0\xd9\0\0\0\x08\0\0\0\0\0\0\0\xde\0\0\0\x08\0\0\
\0\x20\0\0\0\xe7\0\0\0\x08\0\0\0\x40\0\0\0\xf1\0\0\0\x08\0\0\0\x60\0\0\x01\x01\
\0\0\0\x08\0\0\0\x80\0\0\x01\x10\0\0\0\x08\0\0\0\xa0\0\0\0\0\x0d\0\0\x01\0\0\0\
\x02\0\0\x01\x1f\0\0\0\x1e\0\0\x01\x23\x0c\0\0\x01\0\0\0\x20\0\0\x01\x34\x01\0\
\0\0\0\0\0\x01\x01\0\0\x08\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x04\0\0\0\
\x04\0\0\x01\x39\x0e\0\0\0\0\0\0\x23\0\0\0\x01\0\0\x09\x82\x0f\0\0\x01\0\0\0\
\x04\0\0\0\x24\0\0\0\0\0\0\0\x04\0\0\x09\x8a\x0f\0\0\x02\0\0\0\x40\0\0\0\x0e\0\
\0\0\0\0\0\0\x20\0\0\0\x1d\0\0\0\x20\0\0\0\x20\0\x69\x6e\x74\0\x5f\x5f\x41\x52\
\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x5f\x5f\x75\x33\
\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x75\x36\x34\0\
\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x74\
\x79\x70\x65\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\0\x6b\x65\x79\0\x76\
\x61\x6c\x75\x65\0\x72\x78\x63\x6e\x74\0\x76\x69\x70\0\x64\x61\x64\x64\x72\0\
\x64\x70\x6f\x72\x74\0\x66\x61\x6d\x69\x6c\x79\0\x70\x72\x6f\x74\x6f\x63\x6f\
\x6c\0\x76\x36\0\x76\x34\0\x5f\x5f\x75\x31\x36\0\x75\x6e\x73\x69\x67\x6e\x65\
\x64\x20\x73\x68\x6f\x72\x74\0\x5f\x5f\x75\x38\0\x75\x6e\x73\x69\x67\x6e\x65\
\x64\x20\x63\x68\x61\x72\0\x69\x70\x74\x6e\x6c\x5f\x69\x6e\x66\x6f\0\x73\x61\
\x64\x64\x72\0\x64\x6d\x61\x63\0\x76\x69\x70\x32\x74\x6e\x6c\0\x78\x64\x70\x5f\
\x6d\x64\0\x64\x61\x74\x61\0\x64\x61\x74\x61\x5f\x65\x6e\x64\0\x64\x61\x74\x61\
\x5f\x6d\x65\x74\x61\0\x69\x6e\x67\x72\x65\x73\x73\x5f\x69\x66\x69\x6e\x64\x65\
\x78\0\x72\x78\x5f\x71\x75\x65\x75\x65\x5f\x69\x6e\x64\x65\x78\0\x65\x67\x72\
\x65\x73\x73\x5f\x69\x66\x69\x6e\x64\x65\x78\0\x78\x64\x70\0\x5f\x78\x64\x70\
\x5f\x74\x78\x5f\x69\x70\x74\x75\x6e\x6e\x65\x6c\0\x63\x68\x61\x72\0\x5f\x6c\
\x69\x63\x65\x6e\x73\x65\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\
\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\
\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\x2d\x35\
\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2e\x73\x33\x39\x30\x78\
\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\
\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x74\x65\x73\
\x74\x5f\x78\x64\x70\x2e\x63\0\x69\x6e\x74\x20\x5f\x78\x64\x70\x5f\x74\x78\x5f\
\x69\x70\x74\x75\x6e\x6e\x65\x6c\x28\x73\x74\x72\x75\x63\x74\x20\x78\x64\x70\
\x5f\x6d\x64\x20\x2a\x78\x64\x70\x29\0\x09\x76\x6f\x69\x64\x20\x2a\x64\x61\x74\
\x61\x5f\x65\x6e\x64\x20\x3d\x20\x28\x76\x6f\x69\x64\x20\x2a\x29\x28\x6c\x6f\
\x6e\x67\x29\x78\x64\x70\x2d\x3e\x64\x61\x74\x61\x5f\x65\x6e\x64\x3b\0\x09\x76\
\x6f\x69\x64\x20\x2a\x64\x61\x74\x61\x20\x3d\x20\x28\x76\x6f\x69\x64\x20\x2a\
\x29\x28\x6c\x6f\x6e\x67\x29\x78\x64\x70\x2d\x3e\x64\x61\x74\x61\x3b\0\x09\x69\
\x66\x20\x28\x65\x74\x68\x20\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\
\x6e\x64\x29\0\x09\x68\x5f\x70\x72\x6f\x74\x6f\x20\x3d\x20\x65\x74\x68\x2d\x3e\
\x68\x5f\x70\x72\x6f\x74\x6f\x3b\0\x09\x69\x66\x20\x28\x68\x5f\x70\x72\x6f\x74\
\x6f\x20\x3d\x3d\x20\x62\x70\x66\x5f\x68\x74\x6f\x6e\x73\x28\x45\x54\x48\x5f\
\x50\x5f\x49\x50\x29\x29\0\x09\x73\x74\x72\x75\x63\x74\x20\x76\x69\x70\x20\x76\
\x69\x70\x20\x3d\x20\x7b\x7d\x3b\0\x09\x69\x66\x20\x28\x69\x70\x68\x20\x2b\x20\
\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\x29\0\x09\x64\x70\x6f\x72\x74\
\x20\x3d\x20\x67\x65\x74\x5f\x64\x70\x6f\x72\x74\x28\x69\x70\x68\x20\x2b\x20\
\x31\x2c\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\x2c\x20\x69\x70\x68\x2d\x3e\x70\
\x72\x6f\x74\x6f\x63\x6f\x6c\x29\x3b\0\x09\x73\x77\x69\x74\x63\x68\x20\x28\x70\
\x72\x6f\x74\x6f\x63\x6f\x6c\x29\x20\x7b\0\x09\x09\x69\x66\x20\x28\x74\x68\x20\
\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\x29\0\x09\x69\x66\x20\
\x28\x69\x70\x36\x68\x20\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\
\x64\x29\0\x09\x64\x70\x6f\x72\x74\x20\x3d\x20\x67\x65\x74\x5f\x64\x70\x6f\x72\
\x74\x28\x69\x70\x36\x68\x20\x2b\x20\x31\x2c\x20\x64\x61\x74\x61\x5f\x65\x6e\
\x64\x2c\x20\x69\x70\x36\x68\x2d\x3e\x6e\x65\x78\x74\x68\x64\x72\x29\x3b\0\x09\
\x09\x69\x66\x20\x28\x75\x68\x20\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\
\x65\x6e\x64\x29\0\x09\x76\x69\x70\x2e\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x3d\
\x20\x69\x70\x68\x2d\x3e\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3b\0\x09\x76\x69\x70\
\x2e\x66\x61\x6d\x69\x6c\x79\x20\x3d\x20\x41\x46\x5f\x49\x4e\x45\x54\x3b\0\x09\
\x76\x69\x70\x2e\x64\x61\x64\x64\x72\x2e\x76\x34\x20\x3d\x20\x69\x70\x68\x2d\
\x3e\x64\x61\x64\x64\x72\x3b\0\x09\x76\x69\x70\x2e\x64\x70\x6f\x72\x74\x20\x3d\
\x20\x64\x70\x6f\x72\x74\x3b\0\x09\x70\x61\x79\x6c\x6f\x61\x64\x5f\x6c\x65\x6e\
\x20\x3d\x20\x62\x70\x66\x5f\x6e\x74\x6f\x68\x73\x28\x69\x70\x68\x2d\x3e\x74\
\x6f\x74\x5f\x6c\x65\x6e\x29\x3b\0\x09\x74\x6e\x6c\x20\x3d\x20\x62\x70\x66\x5f\
\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x76\x69\
\x70\x32\x74\x6e\x6c\x2c\x20\x26\x76\x69\x70\x29\x3b\0\x09\x69\x66\x20\x28\x21\
\x74\x6e\x6c\x20\x7c\x7c\x20\x74\x6e\x6c\x2d\x3e\x66\x61\x6d\x69\x6c\x79\x20\
\x21\x3d\x20\x41\x46\x5f\x49\x4e\x45\x54\x29\0\x09\x69\x66\x20\x28\x62\x70\x66\
\x5f\x78\x64\x70\x5f\x61\x64\x6a\x75\x73\x74\x5f\x68\x65\x61\x64\x28\x78\x64\
\x70\x2c\x20\x30\x20\x2d\x20\x28\x69\x6e\x74\x29\x73\x69\x7a\x65\x6f\x66\x28\
\x73\x74\x72\x75\x63\x74\x20\x69\x70\x68\x64\x72\x29\x29\x29\0\x09\x64\x61\x74\
\x61\x20\x3d\x20\x28\x76\x6f\x69\x64\x20\x2a\x29\x28\x6c\x6f\x6e\x67\x29\x78\
\x64\x70\x2d\x3e\x64\x61\x74\x61\x3b\0\x09\x64\x61\x74\x61\x5f\x65\x6e\x64\x20\
\x3d\x20\x28\x76\x6f\x69\x64\x20\x2a\x29\x28\x6c\x6f\x6e\x67\x29\x78\x64\x70\
\x2d\x3e\x64\x61\x74\x61\x5f\x65\x6e\x64\x3b\0\x09\x69\x66\x20\x28\x6e\x65\x77\
\x5f\x65\x74\x68\x20\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\
\x20\x7c\x7c\0\x09\x6d\x65\x6d\x63\x70\x79\x28\x6e\x65\x77\x5f\x65\x74\x68\x2d\
\x3e\x68\x5f\x73\x6f\x75\x72\x63\x65\x2c\x20\x6f\x6c\x64\x5f\x65\x74\x68\x2d\
\x3e\x68\x5f\x64\x65\x73\x74\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\x6e\x65\x77\
\x5f\x65\x74\x68\x2d\x3e\x68\x5f\x73\x6f\x75\x72\x63\x65\x29\x29\x3b\0\x09\x6d\
\x65\x6d\x63\x70\x79\x28\x6e\x65\x77\x5f\x65\x74\x68\x2d\x3e\x68\x5f\x64\x65\
\x73\x74\x2c\x20\x74\x6e\x6c\x2d\x3e\x64\x6d\x61\x63\x2c\x20\x73\x69\x7a\x65\
\x6f\x66\x28\x6e\x65\x77\x5f\x65\x74\x68\x2d\x3e\x68\x5f\x64\x65\x73\x74\x29\
\x29\x3b\0\x09\x69\x70\x68\x2d\x3e\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x3d\x20\
\x49\x50\x50\x52\x4f\x54\x4f\x5f\x49\x50\x49\x50\x3b\0\x09\x69\x70\x68\x2d\x3e\
\x69\x68\x6c\x20\x3d\x20\x73\x69\x7a\x65\x6f\x66\x28\x2a\x69\x70\x68\x29\x20\
\x3e\x3e\x20\x32\x3b\0\x09\x69\x70\x68\x2d\x3e\x66\x72\x61\x67\x5f\x6f\x66\x66\
\x20\x3d\x09\x30\x3b\0\x09\x69\x70\x68\x2d\x3e\x63\x68\x65\x63\x6b\x20\x3d\x20\
\x30\x3b\0\x09\x6e\x65\x77\x5f\x65\x74\x68\x2d\x3e\x68\x5f\x70\x72\x6f\x74\x6f\
\x20\x3d\x20\x68\x5f\x70\x72\x6f\x74\x6f\x3b\0\x09\x69\x70\x68\x2d\x3e\x74\x6f\
\x74\x5f\x6c\x65\x6e\x20\x3d\x20\x62\x70\x66\x5f\x68\x74\x6f\x6e\x73\x28\x70\
\x61\x79\x6c\x6f\x61\x64\x5f\x6c\x65\x6e\x20\x2b\x20\x73\x69\x7a\x65\x6f\x66\
\x28\x2a\x69\x70\x68\x29\x29\x3b\0\x09\x69\x70\x68\x2d\x3e\x64\x61\x64\x64\x72\
\x20\x3d\x20\x74\x6e\x6c\x2d\x3e\x64\x61\x64\x64\x72\x2e\x76\x34\x3b\0\x09\x69\
\x70\x68\x2d\x3e\x73\x61\x64\x64\x72\x20\x3d\x20\x74\x6e\x6c\x2d\x3e\x73\x61\
\x64\x64\x72\x2e\x76\x34\x3b\0\x09\x69\x70\x68\x2d\x3e\x74\x74\x6c\x20\x3d\x20\
\x38\x3b\0\x09\x09\x63\x73\x75\x6d\x20\x2b\x3d\x20\x2a\x6e\x65\x78\x74\x5f\x69\
\x70\x68\x2b\x2b\x3b\0\x09\x69\x70\x68\x2d\x3e\x63\x68\x65\x63\x6b\x20\x3d\x20\
\x7e\x28\x28\x63\x73\x75\x6d\x20\x26\x20\x30\x78\x66\x66\x66\x66\x29\x20\x2b\
\x20\x28\x63\x73\x75\x6d\x20\x3e\x3e\x20\x31\x36\x29\x29\x3b\0\x09\x63\x6f\x75\
\x6e\x74\x5f\x74\x78\x28\x76\x69\x70\x2e\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x29\
\x3b\0\x09\x72\x78\x63\x6e\x74\x5f\x63\x6f\x75\x6e\x74\x20\x3d\x20\x62\x70\x66\
\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x72\
\x78\x63\x6e\x74\x2c\x20\x26\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x29\x3b\0\x09\x69\
\x66\x20\x28\x72\x78\x63\x6e\x74\x5f\x63\x6f\x75\x6e\x74\x29\0\x09\x76\x69\x70\
\x2e\x66\x61\x6d\x69\x6c\x79\x20\x3d\x20\x41\x46\x5f\x49\x4e\x45\x54\x36\x3b\0\
\x09\x76\x69\x70\x2e\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x3d\x20\x69\x70\x36\
\x68\x2d\x3e\x6e\x65\x78\x74\x68\x64\x72\x3b\0\x09\x6d\x65\x6d\x63\x70\x79\x28\
\x76\x69\x70\x2e\x64\x61\x64\x64\x72\x2e\x76\x36\x2c\x20\x69\x70\x36\x68\x2d\
\x3e\x64\x61\x64\x64\x72\x2e\x73\x36\x5f\x61\x64\x64\x72\x33\x32\x2c\x20\x73\
\x69\x7a\x65\x6f\x66\x28\x76\x69\x70\x2e\x64\x61\x64\x64\x72\x29\x29\x3b\0\x09\
\x70\x61\x79\x6c\x6f\x61\x64\x5f\x6c\x65\x6e\x20\x3d\x20\x69\x70\x36\x68\x2d\
\x3e\x70\x61\x79\x6c\x6f\x61\x64\x5f\x6c\x65\x6e\x3b\0\x09\x69\x66\x20\x28\x21\
\x74\x6e\x6c\x20\x7c\x7c\x20\x74\x6e\x6c\x2d\x3e\x66\x61\x6d\x69\x6c\x79\x20\
\x21\x3d\x20\x41\x46\x5f\x49\x4e\x45\x54\x36\x29\0\x09\x69\x66\x20\x28\x62\x70\
\x66\x5f\x78\x64\x70\x5f\x61\x64\x6a\x75\x73\x74\x5f\x68\x65\x61\x64\x28\x78\
\x64\x70\x2c\x20\x30\x20\x2d\x20\x28\x69\x6e\x74\x29\x73\x69\x7a\x65\x6f\x66\
\x28\x73\x74\x72\x75\x63\x74\x20\x69\x70\x76\x36\x68\x64\x72\x29\x29\x29\0\x09\
\x69\x66\x20\x28\x6e\x65\x77\x5f\x65\x74\x68\x20\x2b\x20\x31\x20\x3e\x20\x64\
\x61\x74\x61\x5f\x65\x6e\x64\x20\x7c\x7c\x20\x6f\x6c\x64\x5f\x65\x74\x68\x20\
\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\x20\x7c\x7c\0\x09\x69\
\x70\x36\x68\x2d\x3e\x70\x72\x69\x6f\x72\x69\x74\x79\x20\x3d\x20\x30\x3b\0\x09\
\x69\x70\x36\x68\x2d\x3e\x6e\x65\x78\x74\x68\x64\x72\x20\x3d\x20\x49\x50\x50\
\x52\x4f\x54\x4f\x5f\x49\x50\x56\x36\x3b\0\x09\x69\x70\x36\x68\x2d\x3e\x70\x61\
\x79\x6c\x6f\x61\x64\x5f\x6c\x65\x6e\x20\x3d\x20\x62\x70\x66\x5f\x68\x74\x6f\
\x6e\x73\x28\x62\x70\x66\x5f\x6e\x74\x6f\x68\x73\x28\x70\x61\x79\x6c\x6f\x61\
\x64\x5f\x6c\x65\x6e\x29\x20\x2b\x20\x73\x69\x7a\x65\x6f\x66\x28\x2a\x69\x70\
\x36\x68\x29\x29\x3b\0\x09\x6d\x65\x6d\x63\x70\x79\x28\x69\x70\x36\x68\x2d\x3e\
\x73\x61\x64\x64\x72\x2e\x73\x36\x5f\x61\x64\x64\x72\x33\x32\x2c\x20\x74\x6e\
\x6c\x2d\x3e\x73\x61\x64\x64\x72\x2e\x76\x36\x2c\x20\x73\x69\x7a\x65\x6f\x66\
\x28\x74\x6e\x6c\x2d\x3e\x73\x61\x64\x64\x72\x2e\x76\x36\x29\x29\x3b\0\x09\x6d\
\x65\x6d\x63\x70\x79\x28\x69\x70\x36\x68\x2d\x3e\x64\x61\x64\x64\x72\x2e\x73\
\x36\x5f\x61\x64\x64\x72\x33\x32\x2c\x20\x74\x6e\x6c\x2d\x3e\x64\x61\x64\x64\
\x72\x2e\x76\x36\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\x74\x6e\x6c\x2d\x3e\x64\
\x61\x64\x64\x72\x2e\x76\x36\x29\x29\x3b\0\x7d\0\x6c\x69\x63\x65\x6e\x73\x65\0\
\x2e\x6d\x61\x70\x73\0\0\0\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x14\0\0\0\
\x14\0\0\x07\x1c\0\0\x07\x30\0\0\0\0\0\0\0\x08\0\0\x01\x1f\0\0\0\x01\0\0\0\0\0\
\0\0\x21\0\0\0\x10\0\0\x01\x1f\0\0\0\x71\0\0\0\0\0\0\x01\x42\0\0\x01\xb6\0\x03\
\x50\0\0\0\0\x10\0\0\x01\x42\0\0\x01\xdf\0\x03\x58\x26\0\0\0\x18\0\0\x01\x42\0\
\0\x02\x0e\0\x03\x5c\x22\0\0\0\x20\0\0\x01\x42\0\0\x02\x35\0\x03\x6c\x0a\0\0\0\
\x30\0\0\x01\x42\0\0\x02\x35\0\x03\x6c\x06\0\0\0\x38\0\0\x01\x42\0\0\x02\x4e\0\
\x03\x78\x11\0\0\0\x58\0\0\x01\x42\0\0\x02\x67\0\x03\x80\x06\0\0\0\x70\0\0\x01\
\x42\0\0\x02\x8c\0\x01\x60\x0d\0\0\0\x98\0\0\x01\x42\0\0\x02\xa2\0\x01\x74\x0a\
\0\0\0\xb0\0\0\x01\x42\0\0\x02\xa2\0\x01\x74\x06\0\0\0\xb8\0\0\x01\x42\0\0\x02\
\xbb\0\x01\x80\x2c\0\0\0\xc0\0\0\x01\x42\0\0\x02\xf1\0\0\xd0\x02\0\0\0\xd0\0\0\
\x01\x42\0\0\x03\x06\0\0\xdc\x0a\0\0\0\xe8\0\0\x01\x42\0\0\x03\x06\0\0\xdc\x07\
\0\0\x01\0\0\0\x01\x42\0\0\x02\x8c\0\x02\x80\x0d\0\0\x01\x08\0\0\x01\x42\0\0\
\x03\x1f\0\x02\x8c\x0b\0\0\x01\x20\0\0\x01\x42\0\0\x03\x1f\0\x02\x8c\x06\0\0\
\x01\x28\0\0\x01\x42\0\0\x03\x39\0\x02\x98\x2e\0\0\x01\x30\0\0\x01\x42\0\0\x02\
\xf1\0\0\xd0\x02\0\0\x01\x40\0\0\x01\x42\0\0\x03\x06\0\0\xdc\x0a\0\0\x01\x58\0\
\0\x01\x42\0\0\x03\x06\0\0\xdc\x07\0\0\x01\x68\0\0\x01\x42\0\0\x03\x70\0\0\xf0\
\x0a\0\0\x01\x80\0\0\x01\x42\0\0\x03\x70\0\0\xf0\x07\0\0\x01\x88\0\0\x01\x42\0\
\0\0\0\0\0\0\0\0\0\x01\x90\0\0\x01\x42\0\0\x03\x89\0\x01\x90\x0f\0\0\x01\xa0\0\
\0\x01\x42\0\0\x03\xa8\0\x01\x94\x0d\0\0\x01\xa8\0\0\x01\x42\0\0\x03\xbf\0\x01\
\x98\x16\0\0\x01\xb0\0\0\x01\x42\0\0\x03\xdb\0\x01\x9c\x0c\0\0\x01\xb8\0\0\x01\
\x42\0\0\x03\xbf\0\x01\x98\x0f\0\0\x01\xc0\0\0\x01\x42\0\0\x03\xef\0\x01\xa0\
\x10\0\0\x01\xd0\0\0\x01\x42\0\0\0\0\0\0\0\0\0\0\x01\xd8\0\0\x01\x42\0\0\x04\
\x17\0\x01\xa8\x08\0\0\x01\xf8\0\0\x01\x42\0\0\x04\x43\0\x01\xb0\x0b\0\0\x02\0\
\0\0\x01\x42\0\0\x04\x43\0\x01\xb0\x13\0\0\x02\x08\0\0\x01\x42\0\0\x04\x43\0\
\x01\xb0\x06\0\0\x02\x10\0\0\x01\x42\0\0\x04\x68\0\x01\xbc\x06\0\0\x02\x38\0\0\
\x01\x42\0\0\x04\x68\0\x01\xbc\x06\0\0\x02\x40\0\0\x01\x42\0\0\x04\xa6\0\x01\
\xc8\x1c\0\0\x02\x48\0\0\x01\x42\0\0\x04\xc7\0\x01\xcc\x20\0\0\x02\x50\0\0\x01\
\x42\0\0\x04\xf0\0\x01\xe4\x0e\0\0\x02\x68\0\0\x01\x42\0\0\x04\xf0\0\x01\xe4\
\x1d\0\0\x02\x90\0\0\x01\x42\0\0\x05\x0f\0\x01\x24\x02\0\0\x02\xf0\0\0\x01\x42\
\0\0\x05\x57\0\x01\x28\x02\0\0\x03\x28\0\0\x01\x42\0\0\x05\x95\0\x02\x0c\x10\0\
\0\x03\x38\0\0\x01\x42\0\0\x05\xb4\0\x02\x04\x0b\0\0\x03\x48\0\0\x01\x42\0\0\
\x05\xd3\0\x02\x08\x10\0\0\x03\x50\0\0\x01\x42\0\0\x05\xe7\0\x02\x10\x0d\0\0\
\x03\x58\0\0\x01\x42\0\0\x05\xf8\0\x01\x2c\x13\0\0\x03\x60\0\0\x01\x42\0\0\x05\
\x57\0\x01\x28\x02\0\0\x03\x90\0\0\x01\x42\0\0\x06\x15\0\x02\x18\x11\0\0\x03\
\x98\0\0\x01\x42\0\0\x06\x15\0\x02\x18\x0f\0\0\x03\xa8\0\0\x01\x42\0\0\x05\xf8\
\0\x01\x2c\x13\0\0\x03\xb0\0\0\x01\x42\0\0\x06\x4c\0\x02\x1c\x1a\0\0\x03\xb8\0\
\0\x01\x42\0\0\x06\x4c\0\x02\x1c\x0d\0\0\x03\xc0\0\0\x01\x42\0\0\x06\x69\0\x02\
\x20\x1a\0\0\x03\xc8\0\0\x01\x42\0\0\x06\x86\0\x02\x24\x0b\0\0\x03\xd0\0\0\x01\
\x42\0\0\x06\x69\0\x02\x20\x0d\0\0\x03\xd8\0\0\x01\x42\0\0\x06\x95\0\x02\x38\
\x0b\0\0\x03\xe8\0\0\x01\x42\0\0\x06\x95\0\x02\x38\x08\0\0\x03\xf0\0\0\x01\x42\
\0\0\x06\x95\0\x02\x38\x0b\0\0\x03\xf8\0\0\x01\x42\0\0\x06\x95\0\x02\x38\x08\0\
\0\x04\0\0\0\x01\x42\0\0\x06\x95\0\x02\x38\x0b\0\0\x04\x10\0\0\x01\x42\0\0\x06\
\x95\0\x02\x38\x08\0\0\x04\x18\0\0\x01\x42\0\0\x06\x95\0\x02\x38\x0b\0\0\x04\
\x20\0\0\x01\x42\0\0\x06\x95\0\x02\x38\x08\0\0\x04\x28\0\0\x01\x42\0\0\x06\x95\
\0\x02\x38\x0b\0\0\x04\x38\0\0\x01\x42\0\0\x06\x95\0\x02\x38\x08\0\0\x04\x40\0\
\0\x01\x42\0\0\x06\x95\0\x02\x38\x0b\0\0\x04\x48\0\0\x01\x42\0\0\x06\x95\0\x02\
\x38\x08\0\0\x04\x58\0\0\x01\x42\0\0\x06\xac\0\x02\x40\x29\0\0\x04\x68\0\0\x01\
\x42\0\0\x06\xac\0\x02\x40\x21\0\0\x04\x70\0\0\x01\x42\0\0\x06\xac\0\x02\x40\
\x0f\0\0\x04\x78\0\0\x01\x42\0\0\x06\xac\0\x02\x40\x0d\0\0\x04\x80\0\0\x01\x42\
\0\0\x06\xdd\0\x02\x48\x0f\0\0\x04\x98\0\0\x01\x42\0\0\0\0\0\0\0\0\0\0\x04\xa0\
\0\0\x01\x42\0\0\x06\xf6\0\0\xa4\x10\0\0\x04\xb8\0\0\x01\x42\0\0\x07\x2d\0\0\
\xa8\x06\0\0\x04\xc8\0\0\x01\x42\0\0\x03\x70\0\0\xf0\x0a\0\0\x04\xe0\0\0\x01\
\x42\0\0\x03\x70\0\0\xf0\x07\0\0\x04\xe8\0\0\x01\x42\0\0\0\0\0\0\0\0\0\0\x04\
\xf8\0\0\x01\x42\0\0\x07\x3f\0\x02\xac\x0d\0\0\x05\0\0\0\x01\x42\0\0\x07\x57\0\
\x02\xa8\x0f\0\0\x05\x08\0\0\x01\x42\0\0\x07\x76\0\x02\xb0\x02\0\0\x05\x28\0\0\
\x01\x42\0\0\x03\xdb\0\x02\xb4\x0c\0\0\x05\x30\0\0\x01\x42\0\0\x07\x76\0\x02\
\xb0\x02\0\0\x05\x60\0\0\x01\x42\0\0\x07\xb7\0\x02\xb8\x16\0\0\x05\x70\0\0\x01\
\x42\0\0\0\0\0\0\0\0\0\0\x05\x78\0\0\x01\x42\0\0\x04\x17\0\x02\xc0\x08\0\0\x05\
\xa0\0\0\x01\x42\0\0\x07\xd9\0\x02\xc8\x0b\0\0\x05\xa8\0\0\x01\x42\0\0\x07\xd9\
\0\x02\xc8\x13\0\0\x05\xb0\0\0\x01\x42\0\0\x07\xd9\0\x02\xc8\x06\0\0\x05\xb8\0\
\0\x01\x42\0\0\x07\xff\0\x02\xd4\x06\0\0\x05\xe0\0\0\x01\x42\0\0\x07\xff\0\x02\
\xd4\x06\0\0\x05\xe8\0\0\x01\x42\0\0\x04\xa6\0\x02\xe0\x1c\0\0\x05\xf0\0\0\x01\
\x42\0\0\x04\xc7\0\x02\xe4\x20\0\0\x05\xf8\0\0\x01\x42\0\0\x08\x3f\0\x02\xfc\
\x0e\0\0\x06\x10\0\0\x01\x42\0\0\x08\x3f\0\x02\xfc\x1d\0\0\x06\x38\0\0\x01\x42\
\0\0\x05\x0f\0\x01\x24\x02\0\0\x06\x98\0\0\x01\x42\0\0\x05\x57\0\x01\x28\x02\0\
\0\x06\xd0\0\0\x01\x42\0\0\x05\xf8\0\x01\x2c\x13\0\0\x06\xf0\0\0\x01\x42\0\0\
\x08\x78\0\x03\x18\x11\0\0\x07\0\0\0\x01\x42\0\0\x08\x8d\0\x03\x24\x10\0\0\x07\
\x08\0\0\x01\x42\0\0\x08\xac\0\x03\x20\x16\0\0\x07\x10\0\0\x01\x42\0\0\x08\xac\
\0\x03\x20\x14\0\0\x07\x18\0\0\x01\x42\0\0\x05\x57\0\x01\x28\x02\0\0\x07\x48\0\
\0\x01\x42\0\0\x08\xf4\0\x03\x2c\x02\0\0\x07\x88\0\0\x01\x42\0\0\x09\x3a\0\x03\
\x30\x02\0\0\x07\xc8\0\0\x01\x42\0\0\x06\xdd\0\x03\x38\x0f\0\0\x07\xe0\0\0\x01\
\x42\0\0\0\0\0\0\0\0\0\0\x07\xe8\0\0\x01\x42\0\0\x06\xf6\0\0\xa4\x10\0\0\x08\0\
\0\0\x01\x42\0\0\x07\x2d\0\0\xa8\x06\0\0\x08\x08\0\0\x01\x42\0\0\0\0\0\0\0\0\0\
\0\x08\x28\0\0\x01\x42\0\0\x09\x80\0\x03\x9c\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x40\0\0\0\0\0\0\0\xb9\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\
\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\0\0\0\0\x01\x98\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\
\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x98\0\0\0\0\0\
\0\x08\x38\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x15\0\0\0\
\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xd0\0\0\0\0\0\0\0\x04\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x1d\0\0\0\x01\0\0\0\0\0\
\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xd8\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\xa3\0\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x0b\x18\0\0\0\0\0\0\0\x40\0\0\0\x02\0\0\0\x03\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\xab\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x0b\x58\0\0\0\0\0\0\x0d\x2c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0\0\0\0\xb0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x18\x88\0\0\0\0\0\0\x07\x50\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct test_xdp *test_xdp::open(const struct bpf_object_open_opts *opts) { return test_xdp__open_opts(opts); }
struct test_xdp *test_xdp::open_and_load() { return test_xdp__open_and_load(); }
int test_xdp::load(struct test_xdp *skel) { return test_xdp__load(skel); }
int test_xdp::attach(struct test_xdp *skel) { return test_xdp__attach(skel); }
void test_xdp::detach(struct test_xdp *skel) { test_xdp__detach(skel); }
void test_xdp::destroy(struct test_xdp *skel) { test_xdp__destroy(skel); }
const void *test_xdp::elf_bytes(size_t *sz) { return test_xdp__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
test_xdp__assert(struct test_xdp *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __TEST_XDP_SKEL_H__ */
