/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TEST_XDP_LINK_SKEL_H__
#define __TEST_XDP_LINK_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct test_xdp_link {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_program *xdp_handler;
		struct bpf_program *tc_handler;
	} progs;
	struct {
		struct bpf_link *xdp_handler;
		struct bpf_link *tc_handler;
	} links;

#ifdef __cplusplus
	static inline struct test_xdp_link *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct test_xdp_link *open_and_load();
	static inline int load(struct test_xdp_link *skel);
	static inline int attach(struct test_xdp_link *skel);
	static inline void detach(struct test_xdp_link *skel);
	static inline void destroy(struct test_xdp_link *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
test_xdp_link__destroy(struct test_xdp_link *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_xdp_link__create_skeleton(struct test_xdp_link *obj);

static inline struct test_xdp_link *
test_xdp_link__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_xdp_link *obj;
	int err;

	obj = (struct test_xdp_link *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = test_xdp_link__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	test_xdp_link__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct test_xdp_link *
test_xdp_link__open(void)
{
	return test_xdp_link__open_opts(NULL);
}

static inline int
test_xdp_link__load(struct test_xdp_link *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_xdp_link *
test_xdp_link__open_and_load(void)
{
	struct test_xdp_link *obj;
	int err;

	obj = test_xdp_link__open();
	if (!obj)
		return NULL;
	err = test_xdp_link__load(obj);
	if (err) {
		test_xdp_link__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
test_xdp_link__attach(struct test_xdp_link *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_xdp_link__detach(struct test_xdp_link *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *test_xdp_link__elf_bytes(size_t *sz);

static inline int
test_xdp_link__create_skeleton(struct test_xdp_link *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "test_xdp_link";
	s->obj = &obj->obj;

	/* programs */
	s->prog_cnt = 2;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "xdp_handler";
	s->progs[0].prog = &obj->progs.xdp_handler;
	s->progs[0].link = &obj->links.xdp_handler;

	s->progs[1].name = "tc_handler";
	s->progs[1].prog = &obj->progs.tc_handler;
	s->progs[1].link = &obj->links.tc_handler;

	s->data = (void *)test_xdp_link__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *test_xdp_link__elf_bytes(size_t *sz)
{
	*sz = 2608;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x30\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x08\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x78\x64\x70\
\0\x74\x63\0\x6c\x69\x63\x65\x6e\x73\x65\0\x74\x65\x73\x74\x5f\x78\x64\x70\x5f\
\x6c\x69\x6e\x6b\x2e\x63\0\x78\x64\x70\x5f\x68\x61\x6e\x64\x6c\x65\x72\0\x74\
\x63\x5f\x68\x61\x6e\x64\x6c\x65\x72\0\x4c\x49\x43\x45\x4e\x53\x45\0\x2e\x42\
\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\x04\0\xff\xf1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x04\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\x12\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x10\0\0\0\x3c\x12\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x10\0\0\0\x47\x11\0\0\
\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb7\
\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\xeb\x9f\x01\0\0\0\0\x18\
\0\0\0\0\0\0\x03\xa4\0\0\x03\xa4\0\0\x02\x8c\0\0\0\0\x02\0\0\0\0\0\0\x02\0\0\0\
\x01\x04\0\0\x06\0\0\0\x18\0\0\0\x08\0\0\0\x03\0\0\0\0\0\0\0\x0d\0\0\0\x03\0\0\
\0\x20\0\0\0\x16\0\0\0\x03\0\0\0\x40\0\0\0\x20\0\0\0\x03\0\0\0\x60\0\0\0\x30\0\
\0\0\x03\0\0\0\x80\0\0\0\x3f\0\0\0\x03\0\0\0\xa0\0\0\0\x4e\x08\0\0\0\0\0\0\x04\
\0\0\0\x54\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\x0d\0\0\x01\0\0\0\x06\0\0\0\
\x61\0\0\0\x01\0\0\0\x65\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\x69\x0c\0\0\x01\
\0\0\0\x05\0\0\0\0\x02\0\0\0\0\0\0\x09\0\0\0\x75\x04\0\0\x22\0\0\0\xc0\0\0\0\
\x7f\0\0\0\x03\0\0\0\0\0\0\0\x83\0\0\0\x03\0\0\0\x20\0\0\0\x8c\0\0\0\x03\0\0\0\
\x40\0\0\0\x91\0\0\0\x03\0\0\0\x60\0\0\0\x9f\0\0\0\x03\0\0\0\x80\0\0\0\xa8\0\0\
\0\x03\0\0\0\xa0\0\0\0\xb5\0\0\0\x03\0\0\0\xc0\0\0\0\xbe\0\0\0\x03\0\0\0\xe0\0\
\0\0\xc9\0\0\0\x03\0\0\x01\0\0\0\0\x20\0\0\0\x03\0\0\x01\x20\0\0\0\xd2\0\0\0\
\x03\0\0\x01\x40\0\0\0\xda\0\0\0\x03\0\0\x01\x60\0\0\0\xe3\0\0\0\x0a\0\0\x01\
\x80\0\0\0\xe6\0\0\0\x03\0\0\x02\x20\0\0\0\xeb\0\0\0\x03\0\0\x02\x40\0\0\0\x08\
\0\0\0\x03\0\0\x02\x60\0\0\0\x0d\0\0\0\x03\0\0\x02\x80\0\0\0\xf6\0\0\0\x03\0\0\
\x02\xa0\0\0\0\xfe\0\0\0\x03\0\0\x02\xc0\0\0\x01\x05\0\0\0\x03\0\0\x02\xe0\0\0\
\x01\x10\0\0\0\x03\0\0\x03\0\0\0\x01\x1a\0\0\0\x0c\0\0\x03\x20\0\0\x01\x25\0\0\
\0\x0c\0\0\x03\xa0\0\0\x01\x2f\0\0\0\x03\0\0\x04\x20\0\0\x01\x3b\0\0\0\x03\0\0\
\x04\x40\0\0\0\x16\0\0\0\x03\0\0\x04\x60\0\0\0\0\0\0\0\x0d\0\0\x04\x80\0\0\x01\
\x46\0\0\0\x0f\0\0\x04\xc0\0\0\x01\x4d\0\0\0\x03\0\0\x05\0\0\0\x01\x56\0\0\0\
\x03\0\0\x05\x20\0\0\0\0\0\0\0\x11\0\0\x05\x40\0\0\x01\x5f\0\0\0\x03\0\0\x05\
\x80\0\0\x01\x68\0\0\0\x13\0\0\x05\xa0\0\0\x01\x74\0\0\0\x0f\0\0\x05\xc0\0\0\0\
\0\x03\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x0b\0\0\0\x05\0\0\x01\x7d\x01\0\0\0\0\0\0\
\x04\0\0\0\x20\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x0b\0\0\0\x04\0\0\0\0\
\x05\0\0\x01\0\0\0\x08\0\0\x01\x91\0\0\0\x0e\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\
\x1a\0\0\x01\x9b\x08\0\0\0\0\0\0\x10\0\0\x01\xa1\x01\0\0\0\0\0\0\x08\0\0\0\x40\
\0\0\0\0\x05\0\0\x01\0\0\0\x08\0\0\x01\xb4\0\0\0\x12\0\0\0\0\0\0\0\0\x02\0\0\0\
\0\0\0\x1b\0\0\x01\xb7\x08\0\0\0\0\0\0\x14\0\0\x01\xbc\x01\0\0\0\0\0\0\x01\0\0\
\0\x08\0\0\0\0\x0d\0\0\x01\0\0\0\x06\0\0\x01\xca\0\0\0\x08\0\0\x01\xce\x0c\0\0\
\x01\0\0\0\x15\0\0\x01\xd9\x01\0\0\0\0\0\0\x01\x01\0\0\x08\0\0\0\0\x03\0\0\0\0\
\0\0\0\0\0\0\x17\0\0\0\x0b\0\0\0\x04\0\0\x01\xde\x0e\0\0\0\0\0\0\x18\0\0\0\x01\
\0\0\x01\xe6\x07\0\0\0\0\0\0\0\0\0\x01\xf4\x07\0\0\0\0\0\0\0\0\0\x02\x81\x0f\0\
\0\x01\0\0\0\x04\0\0\0\x19\0\0\0\0\0\0\0\x04\0\x78\x64\x70\x5f\x6d\x64\0\x64\
\x61\x74\x61\0\x64\x61\x74\x61\x5f\x65\x6e\x64\0\x64\x61\x74\x61\x5f\x6d\x65\
\x74\x61\0\x69\x6e\x67\x72\x65\x73\x73\x5f\x69\x66\x69\x6e\x64\x65\x78\0\x72\
\x78\x5f\x71\x75\x65\x75\x65\x5f\x69\x6e\x64\x65\x78\0\x65\x67\x72\x65\x73\x73\
\x5f\x69\x66\x69\x6e\x64\x65\x78\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\
\x6e\x65\x64\x20\x69\x6e\x74\0\x78\x64\x70\0\x69\x6e\x74\0\x78\x64\x70\x5f\x68\
\x61\x6e\x64\x6c\x65\x72\0\x5f\x5f\x73\x6b\x5f\x62\x75\x66\x66\0\x6c\x65\x6e\0\
\x70\x6b\x74\x5f\x74\x79\x70\x65\0\x6d\x61\x72\x6b\0\x71\x75\x65\x75\x65\x5f\
\x6d\x61\x70\x70\x69\x6e\x67\0\x70\x72\x6f\x74\x6f\x63\x6f\x6c\0\x76\x6c\x61\
\x6e\x5f\x70\x72\x65\x73\x65\x6e\x74\0\x76\x6c\x61\x6e\x5f\x74\x63\x69\0\x76\
\x6c\x61\x6e\x5f\x70\x72\x6f\x74\x6f\0\x70\x72\x69\x6f\x72\x69\x74\x79\0\x69\
\x66\x69\x6e\x64\x65\x78\0\x74\x63\x5f\x69\x6e\x64\x65\x78\0\x63\x62\0\x68\x61\
\x73\x68\0\x74\x63\x5f\x63\x6c\x61\x73\x73\x69\x64\0\x6e\x61\x70\x69\x5f\x69\
\x64\0\x66\x61\x6d\x69\x6c\x79\0\x72\x65\x6d\x6f\x74\x65\x5f\x69\x70\x34\0\x6c\
\x6f\x63\x61\x6c\x5f\x69\x70\x34\0\x72\x65\x6d\x6f\x74\x65\x5f\x69\x70\x36\0\
\x6c\x6f\x63\x61\x6c\x5f\x69\x70\x36\0\x72\x65\x6d\x6f\x74\x65\x5f\x70\x6f\x72\
\x74\0\x6c\x6f\x63\x61\x6c\x5f\x70\x6f\x72\x74\0\x74\x73\x74\x61\x6d\x70\0\x77\
\x69\x72\x65\x5f\x6c\x65\x6e\0\x67\x73\x6f\x5f\x73\x65\x67\x73\0\x67\x73\x6f\
\x5f\x73\x69\x7a\x65\0\x74\x73\x74\x61\x6d\x70\x5f\x74\x79\x70\x65\0\x68\x77\
\x74\x73\x74\x61\x6d\x70\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\
\x54\x59\x50\x45\x5f\x5f\0\x66\x6c\x6f\x77\x5f\x6b\x65\x79\x73\0\x5f\x5f\x75\
\x36\x34\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\
\x67\0\x73\x6b\0\x5f\x5f\x75\x38\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x63\x68\
\x61\x72\0\x73\x6b\x62\0\x74\x63\x5f\x68\x61\x6e\x64\x6c\x65\x72\0\x63\x68\x61\
\x72\0\x4c\x49\x43\x45\x4e\x53\x45\0\x62\x70\x66\x5f\x66\x6c\x6f\x77\x5f\x6b\
\x65\x79\x73\0\x62\x70\x66\x5f\x73\x6f\x63\x6b\0\x2f\x62\x75\x69\x6c\x64\x64\
\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\
\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\
\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\
\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\
\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\
\x67\x73\x2f\x74\x65\x73\x74\x5f\x78\x64\x70\x5f\x6c\x69\x6e\x6b\x2e\x63\0\x09\
\x72\x65\x74\x75\x72\x6e\x20\x30\x3b\0\x6c\x69\x63\x65\x6e\x73\x65\0\x74\x63\0\
\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x24\0\0\0\x24\0\0\0\x34\0\0\0\x58\0\0\0\
\0\0\0\0\x08\0\0\0\x61\0\0\0\x01\0\0\0\0\0\0\0\x07\0\0\x02\x89\0\0\0\x01\0\0\0\
\0\0\0\0\x16\0\0\0\x10\0\0\0\x61\0\0\0\x01\0\0\0\0\0\0\x01\xfd\0\0\x02\x76\0\0\
\x2c\x02\0\0\x02\x89\0\0\0\x01\0\0\0\0\0\0\x01\xfd\0\0\x02\x76\0\0\x44\x02\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\
\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x5d\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\xa0\0\0\0\0\0\0\0\xa8\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x08\0\
\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x01\x48\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\0\0\0\0\x15\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x58\0\
\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x18\0\
\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x68\0\0\0\0\0\0\0\
\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x4f\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x70\0\0\0\0\0\0\x06\x48\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x54\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\xb8\0\0\0\0\0\0\0\x78\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct test_xdp_link *test_xdp_link::open(const struct bpf_object_open_opts *opts) { return test_xdp_link__open_opts(opts); }
struct test_xdp_link *test_xdp_link::open_and_load() { return test_xdp_link__open_and_load(); }
int test_xdp_link::load(struct test_xdp_link *skel) { return test_xdp_link__load(skel); }
int test_xdp_link::attach(struct test_xdp_link *skel) { return test_xdp_link__attach(skel); }
void test_xdp_link::detach(struct test_xdp_link *skel) { test_xdp_link__detach(skel); }
void test_xdp_link::destroy(struct test_xdp_link *skel) { test_xdp_link__destroy(skel); }
const void *test_xdp_link::elf_bytes(size_t *sz) { return test_xdp_link__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
test_xdp_link__assert(struct test_xdp_link *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __TEST_XDP_LINK_SKEL_H__ */
