/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __SYSCALL_SKEL_H__
#define __SYSCALL_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct syscall {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *data;
		struct bpf_map *rodata;
	} maps;
	struct {
		struct bpf_program *bpf_prog;
	} progs;
	struct {
		struct bpf_link *bpf_prog;
	} links;
	struct syscall__data {
	} *data;
	struct syscall__rodata {
	} *rodata;

#ifdef __cplusplus
	static inline struct syscall *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct syscall *open_and_load();
	static inline int load(struct syscall *skel);
	static inline int attach(struct syscall *skel);
	static inline void detach(struct syscall *skel);
	static inline void destroy(struct syscall *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
syscall__destroy(struct syscall *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
syscall__create_skeleton(struct syscall *obj);

static inline struct syscall *
syscall__open_opts(const struct bpf_object_open_opts *opts)
{
	struct syscall *obj;
	int err;

	obj = (struct syscall *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = syscall__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	syscall__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct syscall *
syscall__open(void)
{
	return syscall__open_opts(NULL);
}

static inline int
syscall__load(struct syscall *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct syscall *
syscall__open_and_load(void)
{
	struct syscall *obj;
	int err;

	obj = syscall__open();
	if (!obj)
		return NULL;
	err = syscall__load(obj);
	if (err) {
		syscall__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
syscall__attach(struct syscall *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
syscall__detach(struct syscall *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *syscall__elf_bytes(size_t *sz);

static inline int
syscall__create_skeleton(struct syscall *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "syscall";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 2;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "syscall.data";
	s->maps[0].map = &obj->maps.data;
	s->maps[0].mmaped = (void **)&obj->data;

	s->maps[1].name = "syscall.rodata";
	s->maps[1].map = &obj->maps.rodata;
	s->maps[1].mmaped = (void **)&obj->rodata;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "bpf_prog";
	s->progs[0].prog = &obj->progs.bpf_prog;
	s->progs[0].link = &obj->links.bpf_prog;

	s->data = (void *)syscall__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *syscall__elf_bytes(size_t *sz)
{
	*sz = 9184;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x21\x60\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0a\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x73\x79\x73\
\x63\x61\x6c\x6c\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x64\x61\x74\x61\0\x2e\x72\
\x6f\x64\x61\x74\x61\0\x73\x79\x73\x63\x61\x6c\x6c\x2e\x63\0\x62\x74\x66\x5f\
\x6c\x6f\x61\x64\x2e\x62\x74\x66\x5f\x6c\x6f\x61\x64\x5f\x61\x74\x74\x72\0\x4c\
\x42\x42\x30\x5f\x35\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\x6d\x61\x70\x5f\x63\
\x72\x65\x61\x74\x65\x5f\x61\x74\x74\x72\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\
\x70\x72\x6f\x67\x5f\x6c\x6f\x61\x64\x5f\x61\x74\x74\x72\0\x62\x70\x66\x5f\x70\
\x72\x6f\x67\x2e\x6c\x69\x63\x65\x6e\x73\x65\0\x62\x70\x66\x5f\x70\x72\x6f\x67\
\x2e\x69\x6e\x73\x6e\x73\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\x6d\x61\x70\x5f\
\x75\x70\x64\x61\x74\x65\x5f\x61\x74\x74\x72\0\x62\x70\x66\x5f\x70\x72\x6f\x67\
\x2e\x76\x61\x6c\x75\x65\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\x6b\x65\x79\0\
\x62\x70\x66\x5f\x70\x72\x6f\x67\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\
\x65\x6c\x73\x79\x73\x63\x61\x6c\x6c\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\
\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x2f\x04\0\xff\xf1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x03\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x39\x01\0\0\x05\0\0\0\0\0\0\x02\x08\0\0\0\0\
\0\0\0\x90\0\0\0\x50\0\0\0\x03\0\0\0\0\0\0\x02\x90\0\0\0\0\0\0\0\0\0\0\0\x57\
\x01\0\0\x05\0\0\0\0\0\0\0\x48\0\0\0\0\0\0\0\x90\0\0\0\x70\x01\0\0\x05\0\0\0\0\
\0\0\x01\x78\0\0\0\0\0\0\0\x90\0\0\0\x88\x01\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x04\0\0\0\x99\x01\0\0\x05\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x40\0\0\0\xa8\
\x01\0\0\x05\0\0\0\0\0\0\0\xd8\0\0\0\0\0\0\0\x90\0\0\0\xc1\x01\0\0\x05\0\0\0\0\
\0\0\x01\x70\0\0\0\0\0\0\0\x08\0\0\0\xd0\x01\0\0\x05\0\0\0\0\0\0\x01\x68\0\0\0\
\0\0\0\0\x08\0\0\0\0\x03\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdd\x12\
\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x98\0\0\0\xe6\x11\0\0\x04\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x04\xbf\x61\0\0\0\0\0\0\x18\x10\0\0\0\0\x02\x08\0\0\0\0\0\0\
\0\0\xbf\x2a\0\0\0\0\0\0\x07\x20\0\0\xff\xff\xff\xc0\x7b\x12\0\0\0\0\0\0\xb4\
\x10\0\0\0\0\0\0\x63\xa1\xff\xf8\0\0\0\0\x18\x10\0\0\0\0\0\x40\0\0\0\0\0\0\0\
\x08\x7b\xa1\xff\xf0\0\0\0\0\x18\x10\0\0\x01\0\0\x40\0\0\0\0\0\0\0\x08\x7b\xa1\
\xff\xe0\0\0\0\0\xb7\x10\0\0\x01\0\0\0\x7b\xa1\xff\xe8\0\0\0\0\x7b\xa1\xff\xd8\
\0\0\0\0\x18\x10\0\0\0\0\0\x04\0\0\0\0\0\0\0\x20\x7b\xa1\xff\xd0\0\0\0\0\xb7\
\x10\0\0\0\0\0\x20\x7b\xa1\xff\xc8\0\0\0\0\x18\x10\0\0\0\0\0\x18\0\0\0\0\xeb\
\x9f\x01\0\x7b\xa1\xff\xc0\0\0\0\0\xb4\x10\0\0\0\0\0\x12\x18\x20\0\0\0\0\x02\
\x08\0\0\0\0\0\0\0\0\xb4\x30\0\0\0\0\0\x90\x85\0\0\0\0\0\0\xa6\xc6\0\0\x33\0\0\
\0\x01\x63\x60\0\x18\0\0\0\0\x61\x16\0\x0c\0\0\0\0\x18\x20\0\0\0\0\0\x48\0\0\0\
\0\0\0\0\0\x63\x20\0\x30\0\0\0\0\x63\x21\0\x0c\0\0\0\0\x18\x10\0\0\0\0\x01\x78\
\0\0\0\0\0\0\0\0\x18\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x12\0\x10\0\0\0\0\x18\
\x70\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\x7b\x17\0\x08\0\0\0\0\x79\x26\0\0\0\0\0\0\
\x7b\x12\0\x20\0\0\0\0\x61\x26\0\x08\0\0\0\0\xb4\x30\0\0\0\0\0\x01\x63\x13\0\
\x18\0\0\0\0\x63\x12\0\x1c\0\0\0\0\xb4\x10\0\0\0\0\0\0\x18\x20\0\0\0\0\0\x48\0\
\0\0\0\0\0\0\0\xb4\x30\0\0\0\0\0\x90\x85\0\0\0\0\0\0\xa6\xc6\0\0\x19\0\0\0\x01\
\x63\x60\0\x10\0\0\0\0\x18\x10\0\0\0\0\0\xd8\0\0\0\0\0\0\0\0\x18\x20\0\0\0\0\
\x01\x70\0\0\0\0\0\0\0\0\x7b\x12\0\x10\0\0\0\0\x18\x20\0\0\0\0\x01\x68\0\0\0\0\
\0\0\0\0\x7b\x12\0\x08\0\0\0\0\x63\x70\0\x1c\0\0\0\0\x63\x10\0\0\0\0\0\0\xb4\
\x10\0\0\0\0\0\x02\x18\x20\0\0\0\0\0\xd8\0\0\0\0\0\0\0\0\xb4\x30\0\0\0\0\0\x90\
\x85\0\0\0\0\0\0\xa6\xc6\0\0\x08\0\0\0\0\xb4\x10\0\0\0\0\0\x05\x18\x20\0\0\0\0\
\x01\x78\0\0\0\0\0\0\0\0\xb4\x30\0\0\0\0\0\x90\x85\0\0\0\0\0\0\xa6\xc6\0\0\x02\
\0\0\0\x01\x63\x60\0\x14\0\0\0\0\xb4\0\0\0\0\0\0\x01\x95\0\0\0\0\0\0\0\x47\x50\
\x4c\0\0\0\0\0\x47\x50\x4c\0\x7a\xa0\xff\xf8\0\0\0\0\xbf\x2a\0\0\0\0\0\0\x07\
\x20\0\0\xff\xff\xff\xf8\x18\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\
\x01\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\x08\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x01\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x0c\0\0\0\0\0\0\0\x22\0\0\0\x06\0\0\0\x08\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3c\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xeb\x9f\x01\0\0\0\0\x18\0\0\0\0\0\0\0\x20\0\0\0\x20\0\0\0\x04\0\0\0\0\
\x01\0\0\0\0\0\0\x08\x01\0\0\x40\0\0\0\0\x01\0\0\0\0\0\0\x08\0\0\0\x40\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\x0c\0\0\0\x01\0\0\0\0\0\0\0\xd0\0\0\0\x0c\0\0\
\0\x01\0\0\0\0\0\0\x01\x08\0\0\0\x0c\0\0\0\x01\0\0\0\0\0\0\x01\x28\0\0\0\x0c\0\
\0\0\x01\0\0\0\0\0\0\x01\x38\0\0\0\x0c\0\0\0\x01\0\0\0\0\0\0\x01\x50\0\0\0\x0c\
\0\0\0\x01\0\0\0\0\0\0\x01\xa0\0\0\0\x0c\0\0\0\x01\0\0\0\0\0\0\x01\xd0\0\0\0\
\x0c\0\0\0\x01\0\0\0\0\0\0\x01\xe0\0\0\0\x0c\0\0\0\x01\0\0\0\0\0\0\x01\xf8\0\0\
\0\x0c\0\0\0\x01\0\0\0\0\0\0\x02\x28\0\0\0\x0c\0\0\0\x01\0\0\0\0\0\0\x02\x58\0\
\0\0\x0c\0\0\0\x01\xeb\x9f\x01\0\0\0\0\x18\0\0\0\0\0\0\x0b\xac\0\0\x0b\xac\0\0\
\x0a\x56\0\0\0\0\x02\0\0\0\0\0\0\x02\0\0\0\x01\x04\0\0\x06\0\0\0\x20\0\0\0\x06\
\0\0\0\x03\0\0\0\0\0\0\0\x0e\0\0\0\x05\0\0\0\x40\0\0\0\x17\0\0\0\x07\0\0\0\x60\
\0\0\0\x23\0\0\0\x07\0\0\0\x80\0\0\0\x2a\0\0\0\x07\0\0\0\xa0\0\0\0\x32\0\0\0\
\x07\0\0\0\xc0\0\0\0\x39\x08\0\0\0\0\0\0\x04\0\0\0\x3f\x01\0\0\0\0\0\0\x08\0\0\
\0\x40\0\0\0\x52\x08\0\0\0\0\0\0\x06\0\0\0\x58\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\
\0\0\x65\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\0\x0d\0\0\x01\0\0\0\x07\0\0\0\
\x69\0\0\0\x01\0\0\0\x6d\x0c\0\0\x01\0\0\0\x08\0\0\0\x76\x01\0\0\0\0\0\0\x01\
\x01\0\0\x08\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x0a\0\0\0\x0c\0\0\0\x04\0\0\0\x7b\
\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\x8f\x0e\0\0\0\0\0\0\x0b\0\0\0\x01\0\0\0\
\x98\x0e\0\0\0\0\0\0\x0b\0\0\0\0\0\0\0\xa9\x84\0\0\x05\0\0\0\x08\0\0\0\xb2\0\0\
\0\x10\0\0\0\0\0\0\0\xb7\0\0\0\x10\x04\0\0\x08\0\0\0\xbf\0\0\0\x10\x04\0\0\x0c\
\0\0\0\xc7\0\0\0\x12\0\0\0\x10\0\0\0\xcb\0\0\0\x14\0\0\0\x20\0\0\0\xcf\x08\0\0\
\0\0\0\0\x11\0\0\0\xd4\x01\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\xe2\x08\0\0\0\0\0\0\
\x13\0\0\0\xe8\x01\0\0\0\0\0\0\x02\x01\0\0\x10\0\0\0\xee\x08\0\0\0\0\0\0\x07\0\
\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x0f\0\0\0\x0c\0\0\0\x08\0\0\0\xf4\x0e\0\0\0\0\0\
\0\x15\0\0\0\0\0\0\x01\x03\x05\0\0\x13\0\0\0\x90\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\
\0\0\0\0\0\x1a\0\0\0\0\0\0\x01\x0c\0\0\0\x1c\0\0\0\0\0\0\0\0\0\0\0\x1d\0\0\0\0\
\0\0\0\0\0\0\0\x1f\0\0\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\x01\x12\0\0\0\x21\0\0\
\0\0\0\0\0\0\0\0\0\x22\0\0\0\0\0\0\x01\x17\0\0\0\x24\0\0\0\0\0\0\x01\x1c\0\0\0\
\x25\0\0\0\0\0\0\x01\x22\0\0\0\x26\0\0\0\0\0\0\0\0\0\0\0\x27\0\0\0\0\0\0\x01\
\x31\0\0\0\x28\0\0\0\0\0\0\x01\x3f\0\0\0\x29\0\0\0\0\0\0\x01\x4b\0\0\0\x2f\0\0\
\0\0\0\0\x01\x57\0\0\0\x30\0\0\0\0\0\0\x01\x63\0\0\0\x31\0\0\0\0\0\0\x01\x70\0\
\0\0\x32\0\0\0\0\0\0\x01\x7c\0\0\0\x33\0\0\0\0\0\0\0\0\x04\0\0\x0e\0\0\0\x48\0\
\0\x01\x8a\0\0\0\x05\0\0\0\0\0\0\x01\x93\0\0\0\x05\0\0\0\x20\0\0\x01\x9c\0\0\0\
\x05\0\0\0\x40\0\0\0\x17\0\0\0\x05\0\0\0\x60\0\0\x01\xa7\0\0\0\x05\0\0\0\x80\0\
\0\x01\xb1\0\0\0\x05\0\0\0\xa0\0\0\x01\xbe\0\0\0\x05\0\0\0\xc0\0\0\x01\xc8\0\0\
\0\x19\0\0\0\xe0\0\0\x01\xd1\0\0\0\x05\0\0\x01\x60\0\0\0\x32\0\0\0\x05\0\0\x01\
\x80\0\0\x01\xdd\0\0\0\x05\0\0\x01\xa0\0\0\x01\xed\0\0\0\x05\0\0\x01\xc0\0\0\
\x01\xff\0\0\0\x05\0\0\x01\xe0\0\0\x02\x19\0\0\0\x03\0\0\x02\0\0\0\0\0\x03\0\0\
\0\0\0\0\0\0\0\0\x0a\0\0\0\x0c\0\0\0\x10\0\0\0\0\x04\0\0\x04\0\0\0\x20\0\0\0\
\x23\0\0\0\x05\0\0\0\0\0\0\x02\x23\0\0\0\x03\0\0\0\x40\0\0\0\0\0\0\0\x1b\0\0\0\
\x80\0\0\x02\x27\0\0\0\x03\0\0\0\xc0\0\0\0\0\x05\0\0\x02\0\0\0\x08\0\0\x02\x2d\
\0\0\0\x03\0\0\0\0\0\0\x02\x33\0\0\0\x03\0\0\0\0\0\0\0\0\x04\0\0\x08\0\0\0\x38\
\0\0\x02\x3c\0\0\0\x03\0\0\0\0\0\0\x02\x45\0\0\0\x03\0\0\0\x40\0\0\x02\x4f\0\0\
\0\x03\0\0\0\x80\0\0\x02\x54\0\0\0\x03\0\0\0\xc0\0\0\x02\x5b\0\0\0\x05\0\0\x01\
\0\0\0\0\x23\0\0\0\x05\0\0\x01\x20\0\0\x02\x61\0\0\0\x03\0\0\x01\x40\0\0\x02\
\x27\0\0\0\x03\0\0\x01\x80\0\0\0\0\x04\0\0\x19\0\0\0\x90\0\0\x02\x6c\0\0\0\x05\
\0\0\0\0\0\0\x02\x76\0\0\0\x05\0\0\0\x20\0\0\x02\x7f\0\0\0\x03\0\0\0\x40\0\0\
\x02\x85\0\0\0\x03\0\0\0\x80\0\0\x02\x8d\0\0\0\x05\0\0\0\xc0\0\0\0\x0e\0\0\0\
\x05\0\0\0\xe0\0\0\0\x06\0\0\0\x03\0\0\x01\0\0\0\x02\x97\0\0\0\x05\0\0\x01\x40\
\0\0\x02\xa4\0\0\0\x05\0\0\x01\x60\0\0\x02\xaf\0\0\0\x19\0\0\x01\x80\0\0\x02\
\xb9\0\0\0\x05\0\0\x02\0\0\0\x02\xc6\0\0\0\x05\0\0\x02\x20\0\0\x02\xdb\0\0\0\
\x05\0\0\x02\x40\0\0\x02\xe7\0\0\0\x05\0\0\x02\x60\0\0\x02\xfa\0\0\0\x03\0\0\
\x02\x80\0\0\x03\x04\0\0\0\x05\0\0\x02\xc0\0\0\x03\x12\0\0\0\x05\0\0\x02\xe0\0\
\0\x03\x25\0\0\0\x03\0\0\x03\0\0\0\x03\x2f\0\0\0\x05\0\0\x03\x40\0\0\x03\x3d\0\
\0\0\x05\0\0\x03\x60\0\0\0\0\0\0\0\x1e\0\0\x03\x80\0\0\x03\x4b\0\0\0\x05\0\0\
\x03\xa0\0\0\x03\x59\0\0\0\x03\0\0\x03\xc0\0\0\x03\x62\0\0\0\x03\0\0\x04\0\0\0\
\x03\x6d\0\0\0\x05\0\0\x04\x40\0\0\0\0\x05\0\0\x02\0\0\0\x04\0\0\x03\x80\0\0\0\
\x05\0\0\0\0\0\0\x03\x8f\0\0\0\x05\0\0\0\0\0\0\0\0\x04\0\0\x03\0\0\0\x10\0\0\
\x03\xa1\0\0\0\x03\0\0\0\0\0\0\x03\xaa\0\0\0\x05\0\0\0\x40\0\0\x03\xb1\0\0\0\
\x05\0\0\0\x60\0\0\0\0\x04\0\0\x05\0\0\0\x14\0\0\x03\xbc\0\0\0\x05\0\0\0\0\0\0\
\x03\xc6\0\0\0\x05\0\0\0\x20\0\0\x03\xd4\0\0\0\x05\0\0\0\x40\0\0\x03\xe0\0\0\0\
\x05\0\0\0\x60\0\0\x03\xed\0\0\0\x05\0\0\0\x80\0\0\0\0\x04\0\0\x0f\0\0\0\x50\0\
\0\0\x2a\0\0\0\x05\0\0\0\0\0\0\x03\xfc\0\0\0\x05\0\0\0\x20\0\0\x04\x03\0\0\0\
\x05\0\0\0\x40\0\0\x04\x10\0\0\0\x05\0\0\0\x60\0\0\x04\x1e\0\0\0\x03\0\0\0\x80\
\0\0\x04\x26\0\0\0\x03\0\0\0\xc0\0\0\x04\x2f\0\0\0\x05\0\0\x01\0\0\0\x04\x36\0\
\0\0\x05\0\0\x01\x20\0\0\x04\x3f\0\0\0\x05\0\0\x01\x40\0\0\x04\x4b\0\0\0\x05\0\
\0\x01\x60\0\0\x04\x58\0\0\0\x03\0\0\x01\x80\0\0\x04\x5f\0\0\0\x03\0\0\x01\xc0\
\0\0\x02\x27\0\0\0\x05\0\0\x02\0\0\0\x04\x67\0\0\0\x05\0\0\x02\x20\0\0\x04\x6b\
\0\0\0\x05\0\0\x02\x40\0\0\0\0\x04\0\0\x03\0\0\0\x0c\0\0\0\0\0\0\0\x23\0\0\0\0\
\0\0\x04\x76\0\0\0\x05\0\0\0\x20\0\0\x04\x7e\0\0\0\x05\0\0\0\x40\0\0\0\0\x05\0\
\0\x05\0\0\0\x04\0\0\x04\x89\0\0\0\x05\0\0\0\0\0\0\x04\x92\0\0\0\x05\0\0\0\0\0\
\0\x04\x9a\0\0\0\x05\0\0\0\0\0\0\x04\xa1\0\0\0\x05\0\0\0\0\0\0\x04\xa8\0\0\0\
\x05\0\0\0\0\0\0\0\0\x04\0\0\x03\0\0\0\x10\0\0\x03\xaa\0\0\0\x05\0\0\0\0\0\0\
\x04\xb0\0\0\0\x05\0\0\0\x20\0\0\x01\x17\0\0\0\x03\0\0\0\x40\0\0\0\0\x04\0\0\
\x06\0\0\0\x20\0\0\x03\xbc\0\0\0\x05\0\0\0\0\0\0\x03\xd4\0\0\0\x05\0\0\0\x20\0\
\0\x04\xb9\0\0\0\x05\0\0\0\x40\0\0\x03\xe0\0\0\0\x05\0\0\0\x60\0\0\x04\xc5\0\0\
\0\x03\0\0\0\x80\0\0\x04\xce\0\0\0\x05\0\0\0\xc0\0\0\0\0\x04\0\0\x02\0\0\0\x10\
\0\0\x04\xd7\0\0\0\x03\0\0\0\0\0\0\0\x2a\0\0\0\x05\0\0\0\x40\0\0\0\0\x04\0\0\
\x05\0\0\0\x20\0\0\x04\xdc\0\0\0\x03\0\0\0\0\0\0\x04\xe0\0\0\0\x03\0\0\0\x40\0\
\0\x04\xec\0\0\0\x05\0\0\0\x80\0\0\x04\xf5\0\0\0\x05\0\0\0\xa0\0\0\x05\x02\0\0\
\0\x05\0\0\0\xc0\0\0\0\0\x04\0\0\x09\0\0\0\x30\0\0\x05\x10\0\0\0\x05\0\0\0\0\0\
\0\x05\x14\0\0\0\x05\0\0\0\x20\0\0\x02\x27\0\0\0\x05\0\0\0\x40\0\0\x05\x17\0\0\
\0\x05\0\0\0\x60\0\0\x05\x1f\0\0\0\x03\0\0\0\x80\0\0\x04\x92\0\0\0\x05\0\0\0\
\xc0\0\0\x05\x23\0\0\0\x05\0\0\0\xe0\0\0\x05\x2b\0\0\0\x03\0\0\x01\0\0\0\x05\
\x38\0\0\0\x03\0\0\x01\x40\0\0\0\0\x04\0\0\x05\0\0\0\x30\0\0\0\x2a\0\0\0\x05\0\
\0\0\0\0\0\0\0\0\0\0\x2a\0\0\0\x20\0\0\x03\xd4\0\0\0\x05\0\0\0\x40\0\0\x02\x27\
\0\0\0\x05\0\0\0\x60\0\0\0\0\0\0\0\x2b\0\0\0\x80\0\0\0\0\x05\0\0\x02\0\0\0\x04\
\0\0\x03\xbc\0\0\0\x05\0\0\0\0\0\0\x05\x43\0\0\0\x05\0\0\0\0\0\0\0\0\x05\0\0\
\x04\0\0\0\x20\0\0\x05\x52\0\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\x2c\0\0\0\0\0\0\x05\
\x60\0\0\0\x2d\0\0\0\0\0\0\x05\x6b\0\0\0\x2e\0\0\0\0\0\0\0\0\x04\0\0\x02\0\0\0\
\x10\0\0\x05\x78\0\0\0\x03\0\0\0\0\0\0\x05\x82\0\0\0\x05\0\0\0\x40\0\0\0\0\x04\
\0\0\x01\0\0\0\x08\0\0\x05\x90\0\0\0\x03\0\0\0\0\0\0\0\0\x04\0\0\x05\0\0\0\x20\
\0\0\x02\x27\0\0\0\x05\0\0\0\0\0\0\x05\x9b\0\0\0\x05\0\0\0\x20\0\0\x05\x9f\0\0\
\0\x03\0\0\0\x40\0\0\x05\xa4\0\0\0\x03\0\0\0\x80\0\0\x05\xaa\0\0\0\x03\0\0\0\
\xc0\0\0\0\0\x04\0\0\x04\0\0\0\x10\0\0\x05\xb2\0\0\0\x05\0\0\0\0\0\0\x05\xba\0\
\0\0\x05\0\0\0\x20\0\0\x02\x27\0\0\0\x05\0\0\0\x40\0\0\x05\xc6\0\0\0\x05\0\0\0\
\x60\0\0\0\0\x04\0\0\x01\0\0\0\x04\0\0\x05\xb2\0\0\0\x05\0\0\0\0\0\0\0\0\x04\0\
\0\x01\0\0\0\x04\0\0\x05\xd2\0\0\0\x05\0\0\0\0\0\0\0\0\x04\0\0\x02\0\0\0\x08\0\
\0\x05\xb2\0\0\0\x05\0\0\0\0\0\0\x02\x27\0\0\0\x05\0\0\0\x20\0\0\0\0\x04\0\0\
\x03\0\0\0\x0c\0\0\0\x2a\0\0\0\x05\0\0\0\0\0\0\0\x23\0\0\0\x05\0\0\0\x20\0\0\
\x02\x27\0\0\0\x05\0\0\0\x40\0\0\x05\xd7\x0e\0\0\0\0\0\0\x17\0\0\0\0\0\0\x05\
\xf0\x0e\0\0\0\0\0\0\x17\0\0\0\0\0\0\x06\x09\x0e\0\0\0\0\0\0\x03\0\0\0\0\0\0\
\x06\x16\x0e\0\0\0\0\0\0\x03\0\0\0\0\0\0\x06\x25\x0e\0\0\0\0\0\0\x17\0\0\0\0\0\
\0\x06\x3d\x0e\0\0\0\0\0\0\x17\0\0\0\0\0\0\x02\x85\x0f\0\0\x01\0\0\0\x04\0\0\0\
\x0d\0\0\0\0\0\0\0\x04\0\0\x0a\x40\x0f\0\0\x08\0\0\x02\x98\0\0\0\x0e\0\0\0\0\0\
\0\0\x04\0\0\0\x16\0\0\0\x04\0\0\0\x40\0\0\0\x34\0\0\0\x48\0\0\0\x90\0\0\0\x35\
\0\0\0\xd8\0\0\0\x90\0\0\0\x36\0\0\x01\x68\0\0\0\x08\0\0\0\x37\0\0\x01\x70\0\0\
\0\x08\0\0\0\x38\0\0\x01\x78\0\0\0\x90\0\0\0\x39\0\0\x02\x08\0\0\0\x90\0\0\x0a\
\x46\x0f\0\0\0\0\0\0\x3c\0\x61\x72\x67\x73\0\x6c\x6f\x67\x5f\x62\x75\x66\0\x6c\
\x6f\x67\x5f\x73\x69\x7a\x65\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\0\
\x6d\x61\x70\x5f\x66\x64\0\x70\x72\x6f\x67\x5f\x66\x64\0\x62\x74\x66\x5f\x66\
\x64\0\x5f\x5f\x75\x36\x34\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\
\x67\x20\x6c\x6f\x6e\x67\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\
\x64\x20\x69\x6e\x74\0\x69\x6e\x74\0\x63\x74\x78\0\x62\x70\x66\x5f\x70\x72\x6f\
\x67\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\
\x54\x59\x50\x45\x5f\x5f\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x62\x70\x66\x5f\
\x70\x72\x6f\x67\x2e\x6c\x69\x63\x65\x6e\x73\x65\0\x62\x70\x66\x5f\x69\x6e\x73\
\x6e\0\x63\x6f\x64\x65\0\x64\x73\x74\x5f\x72\x65\x67\0\x73\x72\x63\x5f\x72\x65\
\x67\0\x6f\x66\x66\0\x69\x6d\x6d\0\x5f\x5f\x75\x38\0\x75\x6e\x73\x69\x67\x6e\
\x65\x64\x20\x63\x68\x61\x72\0\x5f\x5f\x73\x31\x36\0\x73\x68\x6f\x72\x74\0\x5f\
\x5f\x73\x33\x32\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\x69\x6e\x73\x6e\x73\0\
\x62\x70\x66\x5f\x61\x74\x74\x72\0\x62\x61\x74\x63\x68\0\x74\x65\x73\x74\0\x69\
\x6e\x66\x6f\0\x71\x75\x65\x72\x79\0\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x70\
\x6f\x69\x6e\x74\0\x74\x61\x73\x6b\x5f\x66\x64\x5f\x71\x75\x65\x72\x79\0\x6c\
\x69\x6e\x6b\x5f\x63\x72\x65\x61\x74\x65\0\x6c\x69\x6e\x6b\x5f\x75\x70\x64\x61\
\x74\x65\0\x6c\x69\x6e\x6b\x5f\x64\x65\x74\x61\x63\x68\0\x65\x6e\x61\x62\x6c\
\x65\x5f\x73\x74\x61\x74\x73\0\x69\x74\x65\x72\x5f\x63\x72\x65\x61\x74\x65\0\
\x70\x72\x6f\x67\x5f\x62\x69\x6e\x64\x5f\x6d\x61\x70\0\x6d\x61\x70\x5f\x74\x79\
\x70\x65\0\x6b\x65\x79\x5f\x73\x69\x7a\x65\0\x76\x61\x6c\x75\x65\x5f\x73\x69\
\x7a\x65\0\x6d\x61\x70\x5f\x66\x6c\x61\x67\x73\0\x69\x6e\x6e\x65\x72\x5f\x6d\
\x61\x70\x5f\x66\x64\0\x6e\x75\x6d\x61\x5f\x6e\x6f\x64\x65\0\x6d\x61\x70\x5f\
\x6e\x61\x6d\x65\0\x6d\x61\x70\x5f\x69\x66\x69\x6e\x64\x65\x78\0\x62\x74\x66\
\x5f\x6b\x65\x79\x5f\x74\x79\x70\x65\x5f\x69\x64\0\x62\x74\x66\x5f\x76\x61\x6c\
\x75\x65\x5f\x74\x79\x70\x65\x5f\x69\x64\0\x62\x74\x66\x5f\x76\x6d\x6c\x69\x6e\
\x75\x78\x5f\x76\x61\x6c\x75\x65\x5f\x74\x79\x70\x65\x5f\x69\x64\0\x6d\x61\x70\
\x5f\x65\x78\x74\x72\x61\0\x6b\x65\x79\0\x66\x6c\x61\x67\x73\0\x76\x61\x6c\x75\
\x65\0\x6e\x65\x78\x74\x5f\x6b\x65\x79\0\x69\x6e\x5f\x62\x61\x74\x63\x68\0\x6f\
\x75\x74\x5f\x62\x61\x74\x63\x68\0\x6b\x65\x79\x73\0\x76\x61\x6c\x75\x65\x73\0\
\x63\x6f\x75\x6e\x74\0\x65\x6c\x65\x6d\x5f\x66\x6c\x61\x67\x73\0\x70\x72\x6f\
\x67\x5f\x74\x79\x70\x65\0\x69\x6e\x73\x6e\x5f\x63\x6e\x74\0\x69\x6e\x73\x6e\
\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x6c\x6f\x67\x5f\x6c\x65\x76\x65\x6c\0\x6b\
\x65\x72\x6e\x5f\x76\x65\x72\x73\x69\x6f\x6e\0\x70\x72\x6f\x67\x5f\x66\x6c\x61\
\x67\x73\0\x70\x72\x6f\x67\x5f\x6e\x61\x6d\x65\0\x70\x72\x6f\x67\x5f\x69\x66\
\x69\x6e\x64\x65\x78\0\x65\x78\x70\x65\x63\x74\x65\x64\x5f\x61\x74\x74\x61\x63\
\x68\x5f\x74\x79\x70\x65\0\x70\x72\x6f\x67\x5f\x62\x74\x66\x5f\x66\x64\0\x66\
\x75\x6e\x63\x5f\x69\x6e\x66\x6f\x5f\x72\x65\x63\x5f\x73\x69\x7a\x65\0\x66\x75\
\x6e\x63\x5f\x69\x6e\x66\x6f\0\x66\x75\x6e\x63\x5f\x69\x6e\x66\x6f\x5f\x63\x6e\
\x74\0\x6c\x69\x6e\x65\x5f\x69\x6e\x66\x6f\x5f\x72\x65\x63\x5f\x73\x69\x7a\x65\
\0\x6c\x69\x6e\x65\x5f\x69\x6e\x66\x6f\0\x6c\x69\x6e\x65\x5f\x69\x6e\x66\x6f\
\x5f\x63\x6e\x74\0\x61\x74\x74\x61\x63\x68\x5f\x62\x74\x66\x5f\x69\x64\0\x63\
\x6f\x72\x65\x5f\x72\x65\x6c\x6f\x5f\x63\x6e\x74\0\x66\x64\x5f\x61\x72\x72\x61\
\x79\0\x63\x6f\x72\x65\x5f\x72\x65\x6c\x6f\x73\0\x63\x6f\x72\x65\x5f\x72\x65\
\x6c\x6f\x5f\x72\x65\x63\x5f\x73\x69\x7a\x65\0\x61\x74\x74\x61\x63\x68\x5f\x70\
\x72\x6f\x67\x5f\x66\x64\0\x61\x74\x74\x61\x63\x68\x5f\x62\x74\x66\x5f\x6f\x62\
\x6a\x5f\x66\x64\0\x70\x61\x74\x68\x6e\x61\x6d\x65\0\x62\x70\x66\x5f\x66\x64\0\
\x66\x69\x6c\x65\x5f\x66\x6c\x61\x67\x73\0\x74\x61\x72\x67\x65\x74\x5f\x66\x64\
\0\x61\x74\x74\x61\x63\x68\x5f\x62\x70\x66\x5f\x66\x64\0\x61\x74\x74\x61\x63\
\x68\x5f\x74\x79\x70\x65\0\x61\x74\x74\x61\x63\x68\x5f\x66\x6c\x61\x67\x73\0\
\x72\x65\x70\x6c\x61\x63\x65\x5f\x62\x70\x66\x5f\x66\x64\0\x72\x65\x74\x76\x61\
\x6c\0\x64\x61\x74\x61\x5f\x73\x69\x7a\x65\x5f\x69\x6e\0\x64\x61\x74\x61\x5f\
\x73\x69\x7a\x65\x5f\x6f\x75\x74\0\x64\x61\x74\x61\x5f\x69\x6e\0\x64\x61\x74\
\x61\x5f\x6f\x75\x74\0\x72\x65\x70\x65\x61\x74\0\x64\x75\x72\x61\x74\x69\x6f\
\x6e\0\x63\x74\x78\x5f\x73\x69\x7a\x65\x5f\x69\x6e\0\x63\x74\x78\x5f\x73\x69\
\x7a\x65\x5f\x6f\x75\x74\0\x63\x74\x78\x5f\x69\x6e\0\x63\x74\x78\x5f\x6f\x75\
\x74\0\x63\x70\x75\0\x62\x61\x74\x63\x68\x5f\x73\x69\x7a\x65\0\x6e\x65\x78\x74\
\x5f\x69\x64\0\x6f\x70\x65\x6e\x5f\x66\x6c\x61\x67\x73\0\x73\x74\x61\x72\x74\
\x5f\x69\x64\0\x70\x72\x6f\x67\x5f\x69\x64\0\x6d\x61\x70\x5f\x69\x64\0\x62\x74\
\x66\x5f\x69\x64\0\x6c\x69\x6e\x6b\x5f\x69\x64\0\x69\x6e\x66\x6f\x5f\x6c\x65\
\x6e\0\x71\x75\x65\x72\x79\x5f\x66\x6c\x61\x67\x73\0\x70\x72\x6f\x67\x5f\x69\
\x64\x73\0\x70\x72\x6f\x67\x5f\x63\x6e\x74\0\x6e\x61\x6d\x65\0\x62\x74\x66\0\
\x62\x74\x66\x5f\x6c\x6f\x67\x5f\x62\x75\x66\0\x62\x74\x66\x5f\x73\x69\x7a\x65\
\0\x62\x74\x66\x5f\x6c\x6f\x67\x5f\x73\x69\x7a\x65\0\x62\x74\x66\x5f\x6c\x6f\
\x67\x5f\x6c\x65\x76\x65\x6c\0\x70\x69\x64\0\x66\x64\0\x62\x75\x66\x5f\x6c\x65\
\x6e\0\x62\x75\x66\0\x66\x64\x5f\x74\x79\x70\x65\0\x70\x72\x6f\x62\x65\x5f\x6f\
\x66\x66\x73\x65\x74\0\x70\x72\x6f\x62\x65\x5f\x61\x64\x64\x72\0\x74\x61\x72\
\x67\x65\x74\x5f\x69\x66\x69\x6e\x64\x65\x78\0\x74\x61\x72\x67\x65\x74\x5f\x62\
\x74\x66\x5f\x69\x64\0\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\0\x6b\x70\x72\
\x6f\x62\x65\x5f\x6d\x75\x6c\x74\x69\0\x69\x74\x65\x72\x5f\x69\x6e\x66\x6f\0\
\x69\x74\x65\x72\x5f\x69\x6e\x66\x6f\x5f\x6c\x65\x6e\0\x62\x70\x66\x5f\x63\x6f\
\x6f\x6b\x69\x65\0\x63\x6e\x74\0\x73\x79\x6d\x73\0\x61\x64\x64\x72\x73\0\x63\
\x6f\x6f\x6b\x69\x65\x73\0\x6c\x69\x6e\x6b\x5f\x66\x64\0\x6e\x65\x77\x5f\x70\
\x72\x6f\x67\x5f\x66\x64\0\x6f\x6c\x64\x5f\x70\x72\x6f\x67\x5f\x66\x64\0\x74\
\x79\x70\x65\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\x6d\x61\x70\x5f\x63\x72\x65\
\x61\x74\x65\x5f\x61\x74\x74\x72\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\x6d\x61\
\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x61\x74\x74\x72\0\x62\x70\x66\x5f\x70\x72\
\x6f\x67\x2e\x6b\x65\x79\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\x76\x61\x6c\x75\
\x65\0\x62\x70\x66\x5f\x70\x72\x6f\x67\x2e\x70\x72\x6f\x67\x5f\x6c\x6f\x61\x64\
\x5f\x61\x74\x74\x72\0\x62\x74\x66\x5f\x6c\x6f\x61\x64\x2e\x62\x74\x66\x5f\x6c\
\x6f\x61\x64\x5f\x61\x74\x74\x72\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\
\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\
\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\
\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x32\x31\x34\x2e\x65\x6c\x39\x2e\x73\x33\x39\
\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\
\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x73\
\x79\x73\x63\x61\x6c\x6c\x2e\x63\0\x69\x6e\x74\x20\x62\x70\x66\x5f\x70\x72\x6f\
\x67\x28\x73\x74\x72\x75\x63\x74\x20\x61\x72\x67\x73\x20\x2a\x63\x74\x78\x29\0\
\x09\x62\x74\x66\x5f\x6c\x6f\x61\x64\x5f\x61\x74\x74\x72\x2e\x62\x74\x66\x20\
\x3d\x20\x28\x6c\x6f\x6e\x67\x29\x26\x72\x61\x77\x5f\x62\x74\x66\x3b\0\x09\x7d\
\x20\x72\x61\x77\x5f\x62\x74\x66\x20\x3d\x20\x7b\0\x09\x72\x65\x74\x75\x72\x6e\
\x20\x62\x70\x66\x5f\x73\x79\x73\x5f\x62\x70\x66\x28\x42\x50\x46\x5f\x42\x54\
\x46\x5f\x4c\x4f\x41\x44\x2c\x20\x26\x62\x74\x66\x5f\x6c\x6f\x61\x64\x5f\x61\
\x74\x74\x72\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\x62\x74\x66\x5f\x6c\x6f\x61\
\x64\x5f\x61\x74\x74\x72\x29\x29\x3b\0\x09\x69\x66\x20\x28\x72\x65\x74\x20\x3c\
\x3d\x20\x30\x29\0\x09\x63\x74\x78\x2d\x3e\x62\x74\x66\x5f\x66\x64\x20\x3d\x20\
\x72\x65\x74\x3b\0\x09\x6d\x61\x70\x5f\x63\x72\x65\x61\x74\x65\x5f\x61\x74\x74\
\x72\x2e\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\x20\x3d\x20\x63\x74\x78\
\x2d\x3e\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\x3b\0\x09\x6d\x61\x70\x5f\
\x63\x72\x65\x61\x74\x65\x5f\x61\x74\x74\x72\x2e\x62\x74\x66\x5f\x66\x64\x20\
\x3d\x20\x72\x65\x74\x3b\0\x09\x70\x72\x6f\x67\x5f\x6c\x6f\x61\x64\x5f\x61\x74\
\x74\x72\x2e\x6c\x69\x63\x65\x6e\x73\x65\x20\x3d\x20\x28\x6c\x6f\x6e\x67\x29\
\x20\x6c\x69\x63\x65\x6e\x73\x65\x3b\0\x09\x70\x72\x6f\x67\x5f\x6c\x6f\x61\x64\
\x5f\x61\x74\x74\x72\x2e\x69\x6e\x73\x6e\x73\x20\x3d\x20\x28\x6c\x6f\x6e\x67\
\x29\x20\x69\x6e\x73\x6e\x73\x3b\0\x09\x70\x72\x6f\x67\x5f\x6c\x6f\x61\x64\x5f\
\x61\x74\x74\x72\x2e\x6c\x6f\x67\x5f\x62\x75\x66\x20\x3d\x20\x63\x74\x78\x2d\
\x3e\x6c\x6f\x67\x5f\x62\x75\x66\x3b\0\x09\x70\x72\x6f\x67\x5f\x6c\x6f\x61\x64\
\x5f\x61\x74\x74\x72\x2e\x6c\x6f\x67\x5f\x73\x69\x7a\x65\x20\x3d\x20\x63\x74\
\x78\x2d\x3e\x6c\x6f\x67\x5f\x73\x69\x7a\x65\x3b\0\x09\x70\x72\x6f\x67\x5f\x6c\
\x6f\x61\x64\x5f\x61\x74\x74\x72\x2e\x6c\x6f\x67\x5f\x6c\x65\x76\x65\x6c\x20\
\x3d\x20\x31\x3b\0\x09\x72\x65\x74\x20\x3d\x20\x62\x70\x66\x5f\x73\x79\x73\x5f\
\x62\x70\x66\x28\x42\x50\x46\x5f\x4d\x41\x50\x5f\x43\x52\x45\x41\x54\x45\x2c\
\x20\x26\x6d\x61\x70\x5f\x63\x72\x65\x61\x74\x65\x5f\x61\x74\x74\x72\x2c\x20\
\x73\x69\x7a\x65\x6f\x66\x28\x6d\x61\x70\x5f\x63\x72\x65\x61\x74\x65\x5f\x61\
\x74\x74\x72\x29\x29\x3b\0\x09\x63\x74\x78\x2d\x3e\x6d\x61\x70\x5f\x66\x64\x20\
\x3d\x20\x72\x65\x74\x3b\0\x09\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x61\
\x74\x74\x72\x2e\x6d\x61\x70\x5f\x66\x64\x20\x3d\x20\x72\x65\x74\x3b\0\x09\x6d\
\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x61\x74\x74\x72\x2e\x76\x61\x6c\x75\
\x65\x20\x3d\x20\x28\x6c\x6f\x6e\x67\x29\x20\x26\x76\x61\x6c\x75\x65\x3b\0\x09\
\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x61\x74\x74\x72\x2e\x6b\x65\x79\
\x20\x3d\x20\x28\x6c\x6f\x6e\x67\x29\x20\x26\x6b\x65\x79\x3b\0\x09\x69\x6e\x73\
\x6e\x73\x5b\x33\x5d\x2e\x69\x6d\x6d\x20\x3d\x20\x72\x65\x74\x3b\0\x09\x72\x65\
\x74\x20\x3d\x20\x62\x70\x66\x5f\x73\x79\x73\x5f\x62\x70\x66\x28\x42\x50\x46\
\x5f\x4d\x41\x50\x5f\x55\x50\x44\x41\x54\x45\x5f\x45\x4c\x45\x4d\x2c\x20\x26\
\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x61\x74\x74\x72\x2c\x20\x73\x69\
\x7a\x65\x6f\x66\x28\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x61\x74\x74\
\x72\x29\x29\x3b\0\x09\x69\x66\x20\x28\x72\x65\x74\x20\x3c\x20\x30\x29\0\x09\
\x72\x65\x74\x20\x3d\x20\x62\x70\x66\x5f\x73\x79\x73\x5f\x62\x70\x66\x28\x42\
\x50\x46\x5f\x50\x52\x4f\x47\x5f\x4c\x4f\x41\x44\x2c\x20\x26\x70\x72\x6f\x67\
\x5f\x6c\x6f\x61\x64\x5f\x61\x74\x74\x72\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\
\x70\x72\x6f\x67\x5f\x6c\x6f\x61\x64\x5f\x61\x74\x74\x72\x29\x29\x3b\0\x09\x63\
\x74\x78\x2d\x3e\x70\x72\x6f\x67\x5f\x66\x64\x20\x3d\x20\x72\x65\x74\x3b\0\x7d\
\0\x2e\x64\x61\x74\x61\0\x2e\x72\x6f\x64\x61\x74\x61\0\x73\x79\x73\x63\x61\x6c\
\x6c\0\0\0\0\0\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x14\0\0\0\x14\0\0\x02\
\x1c\0\0\x02\x30\0\0\0\0\0\0\0\x08\0\0\x0a\x4e\0\0\0\x01\0\0\0\0\0\0\0\x09\0\0\
\0\x10\0\0\x0a\x4e\0\0\0\x21\0\0\0\0\0\0\x06\x54\0\0\x06\xc7\0\0\xf4\0\0\0\0\
\x08\0\0\x06\x54\0\0\x06\xe6\0\0\xe0\x14\0\0\0\x20\0\0\x06\x54\0\0\0\0\0\0\0\0\
\0\0\0\x28\0\0\x06\x54\0\0\x06\xe6\0\0\xe0\x14\0\0\0\x38\0\0\x06\x54\0\0\x07\
\x0b\0\0\x90\x04\0\0\0\xc8\0\0\x06\x54\0\0\x07\x1a\0\0\xe4\x09\0\0\0\xf0\0\0\
\x06\x54\0\0\x07\x64\0\x01\x68\x06\0\0\0\xf8\0\0\x06\x54\0\0\x07\x73\0\x01\x74\
\x0e\0\0\x01\0\0\0\x06\x54\0\0\x07\x87\0\x01\x78\x25\0\0\x01\x08\0\0\x06\x54\0\
\0\x07\x87\0\x01\x78\x1e\0\0\x01\x18\0\0\x06\x54\0\0\x07\xb8\0\x01\x7c\x19\0\0\
\x01\x20\0\0\x06\x54\0\0\x07\x87\0\x01\x78\x1e\0\0\x01\x28\0\0\x06\x54\0\0\x07\
\xd7\0\x01\x84\x19\0\0\x01\x50\0\0\x06\x54\0\0\x08\x01\0\x01\x88\x17\0\0\x01\
\x68\0\0\x06\x54\0\0\x08\x27\0\x01\x8c\x20\0\0\x01\x70\0\0\x06\x54\0\0\x08\x27\
\0\x01\x8c\x19\0\0\x01\x78\0\0\x06\x54\0\0\x08\x4f\0\x01\x90\x21\0\0\x01\x88\0\
\0\x06\x54\0\0\x08\x79\0\x01\x94\x1b\0\0\x01\x90\0\0\x06\x54\0\0\x08\x4f\0\x01\
\x90\x1a\0\0\x01\x98\0\0\x06\x54\0\0\x08\x98\0\x01\x9c\x08\0\0\x01\xc0\0\0\x06\
\x54\0\0\x07\x64\0\x01\xa0\x06\0\0\x01\xc8\0\0\x06\x54\0\0\x08\xe7\0\x01\xa8\
\x0e\0\0\x01\xd0\0\0\x06\x54\0\0\x08\xfb\0\x01\xb4\x19\0\0\x01\xe0\0\0\x06\x54\
\0\0\x09\x1a\0\x01\xbc\x18\0\0\x01\xf8\0\0\x06\x54\0\0\x09\x42\0\x01\xb8\x16\0\
\0\x02\x10\0\0\x06\x54\0\0\x09\x66\0\x01\xac\x0f\0\0\x02\x18\0\0\x06\x54\0\0\
\x08\xfb\0\x01\xb4\x19\0\0\x02\x20\0\0\x06\x54\0\0\x09\x7b\0\x01\xc0\x08\0\0\
\x02\x48\0\0\x06\x54\0\0\x09\xcf\0\x01\xc4\x06\0\0\x02\x50\0\0\x06\x54\0\0\x09\
\xdd\0\x01\xd0\x08\0\0\x02\x78\0\0\x06\x54\0\0\x07\x64\0\x01\xd4\x06\0\0\x02\
\x80\0\0\x06\x54\0\0\x0a\x29\0\x01\xdc\x0f\0\0\x02\x90\0\0\x06\x54\0\0\x0a\x3e\
\0\x01\xe4\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\
\0\x03\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\x01\x09\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x50\0\0\0\0\0\0\x01\x68\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\xb8\0\0\0\0\0\0\x02\x98\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x05\x50\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\
\0\0\0\0\0\0\0\0\0\0\x21\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x05\x58\0\0\0\0\0\0\x02\x98\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\0\0\0\0\x27\0\0\0\x01\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\xf0\0\
\0\0\0\0\0\0\x3c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\xef\0\
\0\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x30\0\0\0\0\0\0\0\
\xc0\0\0\0\x02\0\0\0\x03\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\xfb\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\xf0\0\0\0\0\0\0\x16\x1a\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1f\x10\0\0\0\0\0\0\x02\x50\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct syscall *syscall::open(const struct bpf_object_open_opts *opts) { return syscall__open_opts(opts); }
struct syscall *syscall::open_and_load() { return syscall__open_and_load(); }
int syscall::load(struct syscall *skel) { return syscall__load(skel); }
int syscall::attach(struct syscall *skel) { return syscall__attach(skel); }
void syscall::detach(struct syscall *skel) { syscall__detach(skel); }
void syscall::destroy(struct syscall *skel) { syscall__destroy(skel); }
const void *syscall::elf_bytes(size_t *sz) { return syscall__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
syscall__assert(struct syscall *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __SYSCALL_SKEL_H__ */
